@font-face {
  font-family: 'Inter-Nextend';
  font-style: normal;
  font-weight: 400;
  src: url("../fonts/Inter-Medium.woff2") format("woff2");
  font-display: block; }

@font-face {
  font-family: 'Inter-Nextend';
  font-style: normal;
  font-weight: 700;
  src: url("../fonts/Inter-SemiBold.woff2") format("woff2"); }

@font-face {
  font-family: 'SmartSliderIcons';
  src: url("../fonts/SmartSliderIcons.woff2?JC0JNU") format("woff2");
  font-weight: normal;
  font-style: normal; }

.ssi_16,
.ssi_24,
.ssi_32,
.ssi_48,
.ssi_64 {
  /* use !important to prevent issues with browser extensions that change fonts */
  font-family: 'SmartSliderIcons' !important;
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  /* Better Font Rendering =========== */
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale; }

.ssi_16 {
  font-size: 16px !important; }

.ssi_24 {
  font-size: 24px !important; }

.ssi_32 {
  font-size: 32px !important; }

.ssi_48 {
  font-size: 48px !important; }

.ssi_64 {
  font-size: 64px !important; }

.ssi_16--animation::before {
  content: "\E91F"; }

.ssi_16--arrowdown::before {
  content: "\E14B"; }

.ssi_16--arrowright::before {
  content: "\E15E"; }

.ssi_16--bold::before {
  content: "\E601"; }

.ssi_16--breadcrumb::before {
  content: "\E91E"; }

.ssi_16--bringforward::before {
  content: "\E15F"; }

.ssi_16--bringfront::before {
  content: "\E143"; }

.ssi_16--buttonarrow::before {
  content: "\E155"; }

.ssi_16--check::before {
  content: "\E600"; }

.ssi_16--circularremove::before {
  content: "\E62C"; }

.ssi_16--clearanimation::before {
  content: "\E948"; }

.ssi_16--cog::before {
  content: "\E934"; }

.ssi_16--color::before {
  content: "\E144"; }

.ssi_16--column::before {
  content: "\E145"; }

.ssi_16--content::before {
  content: "\E146"; }

.ssi_16--copy::before {
  content: "\E907"; }

.ssi_16--crop::before {
  content: "\E161"; }

.ssi_16--dashboard::before {
  content: "\E149"; }

.ssi_16--data::before {
  content: "\E152"; }

.ssi_16--delete::before {
  content: "\E612"; }

.ssi_16--desktoplandscape::before {
  content: "\E95a"; }

.ssi_16--desktopportrait::before {
  content: "\E925"; }

.ssi_16--divide::before {
  content: "\E639"; }

.ssi_16--download::before {
  content: "\E162"; }

.ssi_16--dummy::before {
  content: "\E15D"; }

.ssi_16--duplicate::before {
  content: "\E611"; }

.ssi_16--edit::before {
  content: "\E154"; }

.ssi_16--eye::before {
  content: "\E60F"; }

.ssi_16--filledcheck::before {
  content: "\E60C"; }

.ssi_16--filledremove::before {
  content: "\E62D"; }

.ssi_16--folderclosed::before {
  content: "\E921"; }

.ssi_16--folderopened::before {
  content: "\E922"; }

.ssi_16--fontresize::before {
  content: "\E650"; }

.ssi_16--fullscreen::before {
  content: "\E163"; }

.ssi_16--grid::before {
  content: "\E164"; }

.ssi_16--group::before {
  content: "\E1B6"; }

.ssi_16--hide::before {
  content: "\E923"; }

.ssi_16--horizontalcenter::before {
  content: "\E646"; }

.ssi_16--horizontalleft::before {
  content: "\E647"; }

.ssi_16--horizontalright::before {
  content: "\E645"; }

.ssi_16--image::before {
  content: "\E14A"; }

.ssi_16--info::before {
  content: "\E620"; }

.ssi_16--italic::before {
  content: "\E615"; }

.ssi_16--keyboard::before {
  content: "\E165"; }

.ssi_16--layer::before {
  content: "\E935"; }

.ssi_16--link::before {
  content: "\E64D"; }

.ssi_16--magnifier::before {
  content: "\E1B9"; }

.ssi_16--miniarrowdown::before {
  content: "\E19E"; }

.ssi_16--miniarrowright::before {
  content: "\E19D"; }

.ssi_16--minidesktopportrait::before {
  content: "\E980"; }

.ssi_16--mobilelandscape::before {
  content: "\E929"; }

.ssi_16--mobileportrait::before {
  content: "\E92A"; }

.ssi_16--mobileportraitlarge::before {
  content: "\E1AB"; }

.ssi_16--more::before {
  content: "\E911"; }

.ssi_16--none::before {
  content: "\E971"; }

.ssi_16--off::before {
  content: "\E19A"; }

.ssi_16--on::before {
  content: "\E199"; }

.ssi_16--order::before {
  content: "\E1B7"; }

.ssi_16--paginatiorarrow::before {
  content: "\E1B8"; }

.ssi_16--paste::before {
  content: "\E908"; }

.ssi_16--pause::before {
  content: "\E606"; }

.ssi_16--play::before {
  content: "\E605"; }

.ssi_16--plus::before {
  content: "\E92F"; }

.ssi_16--position::before {
  content: "\E14E"; }

.ssi_16--remove::before {
  content: "\E90A"; }

.ssi_16--rename::before {
  content: "\E19C"; }

.ssi_16--reset::before {
  content: "\E946"; }

.ssi_16--resize::before {
  content: "\E19F"; }

.ssi_16--row::before {
  content: "\E14F"; }

.ssi_16--save::before {
  content: "\E947"; }

.ssi_16--selectarrow::before {
  content: "\E638"; }

.ssi_16--sendback::before {
  content: "\E166"; }

.ssi_16--sendbackward::before {
  content: "\E167"; }

.ssi_16--shrink::before {
  content: "\E196"; }

.ssi_16--slides::before {
  content: "\E151"; }

.ssi_16--smart::before {
  content: "\E147"; }

.ssi_16--star::before {
  content: "\E603"; }

.ssi_16--stop::before {
  content: "\E607"; }

.ssi_16--style::before {
  content: "\E169"; }

.ssi_16--tabletlandscape::before {
  content: "\E927"; }

.ssi_16--tabletportrait::before {
  content: "\E928"; }

.ssi_16--tabletportraitlarge::before {
  content: "\E1AC"; }

.ssi_16--textcenter::before {
  content: "\E614"; }

.ssi_16--textjustify::before {
  content: "\E60B"; }

.ssi_16--textleft::before {
  content: "\E60A"; }

.ssi_16--textright::before {
  content: "\E604"; }

.ssi_16--underline::before {
  content: "\E602"; }

.ssi_16--unlink::before {
  content: "\E64B"; }

.ssi_16--up::before {
  content: "\E16A"; }

.ssi_16--verticalaround::before {
  content: "\E97B"; }

.ssi_16--verticalbetween::before {
  content: "\E97A"; }

.ssi_16--verticalbottom::before {
  content: "\E97F"; }

.ssi_16--verticalcenter::before {
  content: "\E97E"; }

.ssi_16--verticaltop::before {
  content: "\E97C"; }

.ssi_16--video::before {
  content: "\E153"; }

.ssi_16--wordpress::before {
  content: "\E197"; }

.ssi_24--active::before {
  content: "\D7FD"; }

.ssi_24--animation::before {
  content: "\E115"; }

.ssi_24--attention::before {
  content: "\E195"; }

.ssi_24--bounce::before {
  content: "\E998"; }

.ssi_24--button::before {
  content: "\E192"; }

.ssi_24--check::before {
  content: "\E14C"; }

.ssi_24--circularcheck::before {
  content: "\E129"; }

.ssi_24--circularinfo::before {
  content: "\E11B"; }

.ssi_24--close::before {
  content: "\E116"; }

.ssi_24--cog::before {
  content: "\E15C"; }

.ssi_24--col2::before {
  content: "\E193"; }

.ssi_24--desktop::before {
  content: "\E11A"; }

.ssi_24--desktoplandscape::before {
  content: "\E119"; }

.ssi_24--dummy::before {
  content: "\E17B"; }

.ssi_24--edit::before {
  content: "\E117"; }

.ssi_24--fade::before {
  content: "\E993"; }

.ssi_24--flip::before {
  content: "\E996"; }

.ssi_24--heading::before {
  content: "\E17E"; }

.ssi_24--image::before {
  content: "\E191"; }

.ssi_24--info::before {
  content: "\E14D"; }

.ssi_24--layers::before {
  content: "\E11C"; }

.ssi_24--mobilelandscape::before {
  content: "\E11D"; }

.ssi_24--mobileportrait::before {
  content: "\E11E"; }

.ssi_24--mobileportraitlarge::before {
  content: "\E1AD"; }

.ssi_24--more::before {
  content: "\E17D"; }

.ssi_24--move::before {
  content: "\E995"; }

.ssi_24--newwindow::before {
  content: "\E1A2"; }

.ssi_24--notification::before {
  content: "\E99F"; }

.ssi_24--orientation::before {
  content: "\E1A1"; }

.ssi_24--play::before {
  content: "\E11F"; }

.ssi_24--preview::before {
  content: "\E121"; }

.ssi_24--redo::before {
  content: "\E122"; }

.ssi_24--refresh::before {
  content: "\E194"; }

.ssi_24--remove::before {
  content: "\E16B"; }

.ssi_24--reveal::before {
  content: "\E992"; }

.ssi_24--rotate::before {
  content: "\E999"; }

.ssi_24--scale::before {
  content: "\E994"; }

.ssi_24--smart::before {
  content: "\E16C"; }

.ssi_24--special::before {
  content: "\E997"; }

.ssi_24--star::before {
  content: "\E1A4"; }

.ssi_24--stop::before {
  content: "\E16D"; }

.ssi_24--style::before {
  content: "\E123"; }

.ssi_24--tabletlandscape::before {
  content: "\E124"; }

.ssi_24--tabletportrait::before {
  content: "\E125"; }

.ssi_24--tabletportraitlarge::before {
  content: "\E1AE"; }

.ssi_24--text::before {
  content: "\E17F"; }

.ssi_24--timeline::before {
  content: "\E126"; }

.ssi_24--undo::before {
  content: "\E127"; }

.ssi_32--animatedheading::before {
  content: "\E991"; }

.ssi_32--area::before {
  content: "\E937"; }

.ssi_32--audio::before {
  content: "\E986"; }

.ssi_32--beforeafter::before {
  content: "\E1B4"; }

.ssi_32--button::before {
  content: "\E942"; }

.ssi_32--circlecounter::before {
  content: "\E985"; }

.ssi_32--col1::before {
  content: "\E112"; }

.ssi_32--col2::before {
  content: "\E113"; }

.ssi_32--col3::before {
  content: "\E157"; }

.ssi_32--countdown::before {
  content: "\E1B5"; }

.ssi_32--counter::before {
  content: "\E984"; }

.ssi_32--dummy::before {
  content: "\E15B"; }

.ssi_32--heading::before {
  content: "\E945"; }

.ssi_32--highlightheading::before {
  content: "\E990"; }

.ssi_32--html::before {
  content: "\E93A"; }

.ssi_32--icon::before {
  content: "\E941"; }

.ssi_32--iframe::before {
  content: "\E938"; }

.ssi_32--image::before {
  content: "\E943"; }

.ssi_32--imagearea::before {
  content: "\E950"; }

.ssi_32--imagebox::before {
  content: "\E983"; }

.ssi_32--imagecaption::before {
  content: "\E940"; }

.ssi_32--input::before {
  content: "\E939"; }

.ssi_32--joomla::before {
  content: "\E19B"; }

.ssi_32--list::before {
  content: "\E93E"; }

.ssi_32--plus::before {
  content: "\E114"; }

.ssi_32--progressbar::before {
  content: "\E982"; }

.ssi_32--smart::before {
  content: "\E16E"; }

.ssi_32--text::before {
  content: "\E944"; }

.ssi_32--transition::before {
  content: "\E93F"; }

.ssi_32--video::before {
  content: "\E93B"; }

.ssi_32--vimeo::before {
  content: "\E93C"; }

.ssi_32--youtube::before {
  content: "\E93D"; }

.ssi_48--bug::before {
  content: "\E17C"; }

.ssi_48--camera::before {
  content: "\E141"; }

.ssi_48--convert::before {
  content: "\E134"; }

.ssi_48--data::before {
  content: "\E13E"; }

.ssi_48--delete::before {
  content: "\E135"; }

.ssi_48--doc::before {
  content: "\E13B"; }

.ssi_48--drop::before {
  content: "\E136"; }

.ssi_48--dummy::before {
  content: "\E159"; }

.ssi_48--dynamic::before {
  content: "\E98F"; }

.ssi_48--empty::before {
  content: "\E98E"; }

.ssi_48--error::before {
  content: "\E137"; }

.ssi_48--grid::before {
  content: "\E16F"; }

.ssi_48--group::before {
  content: "\E139"; }

.ssi_48--help::before {
  content: "\E13A"; }

.ssi_48--image::before {
  content: "\E98D"; }

.ssi_48--keyboard::before {
  content: "\E171"; }

.ssi_48--link::before {
  content: "\E13C"; }

.ssi_48--newsletter::before {
  content: "\E13D"; }

.ssi_48--plus::before {
  content: "\D7FE"; }

.ssi_48--post::before {
  content: "\E98B"; }

.ssi_48--protect::before {
  content: "\E133"; }

.ssi_48--remove::before {
  content: "\E156"; }

.ssi_48--review0::before {
  content: "\E13F"; }

.ssi_48--review1::before {
  content: "\E1A5"; }

.ssi_48--review2::before {
  content: "\E1A6"; }

.ssi_48--review3::before {
  content: "\E1A7"; }

.ssi_48--review4::before {
  content: "\E1A9"; }

.ssi_48--review5::before {
  content: "\E1AA"; }

.ssi_48--static::before {
  content: "\E98A"; }

.ssi_48--upgrade::before {
  content: "\E1A3"; }

.ssi_48--video::before {
  content: "\E989"; }

.ssi_64--accordionslider::before {
  content: "\E12A"; }

.ssi_64--auto::before {
  content: "\E17A"; }

.ssi_64--block::before {
  content: "\E12B"; }

.ssi_64--blurfit::before {
  content: "\E172"; }

.ssi_64--carousel::before {
  content: "\E12C"; }

.ssi_64--center::before {
  content: "\E173"; }

.ssi_64--drop::before {
  content: "\E12D"; }

.ssi_64--dummy::before {
  content: "\E15A"; }

.ssi_64--fill::before {
  content: "\E174"; }

.ssi_64--fit::before {
  content: "\E175"; }

.ssi_64--folder::before {
  content: "\E957"; }

.ssi_64--folderup::before {
  content: "\E63E"; }

.ssi_64--fullwidthslider::before {
  content: "\E132"; }

.ssi_64--image::before {
  content: "\E176"; }

.ssi_64--page::before {
  content: "\E12E"; }

.ssi_64--showcase::before {
  content: "\E12F"; }

.ssi_64--slider::before {
  content: "\E131"; }

.ssi_64--stretch::before {
  content: "\E177"; }

.ssi_64--tile::before {
  content: "\E179"; }

.n2_color_picker {
  position: fixed;
  top: 0;
  left: 0;
  z-index: 10000000;
  border: 2px solid #b9c3c9;
  border-radius: 3px;
  background-color: #fff;
  width: min-content;
  display: grid;
  grid-gap: 10px;
  grid-template-columns: auto auto auto auto;
  padding: 10px;
  user-select: none; }

.n2_color_picker.n2_color_picker--has-opacity {
  grid-template-columns: auto auto auto auto auto; }

.n2_color_picker__palette {
  width: min-content;
  display: grid;
  grid-gap: 8px;
  grid-template-columns: 1fr 1fr 1fr 1fr; }

.n2_color_picker__palette_item {
  width: 20px;
  height: 20px;
  overflow: hidden;
  border-radius: 3px;
  cursor: pointer; }

.n2_color_picker__palette_item_color {
  width: 100%;
  height: 100%;
  background-color: var(--palette-item-color);
  box-shadow: 0 0 1px 1px rgba(0, 0, 0, 0.2) inset;
  border-radius: 3px; }

.n2_color_picker__palette_item_alpha {
  display: none; }

.n2_color_picker--has-opacity .n2_color_picker__palette_item_alpha {
  display: block; }

.n2_color_picker__palette_history {
  width: min-content;
  display: grid;
  grid-gap: 8px;
  grid-template-columns: 1fr;
  border-left: 1px solid rgba(0, 0, 0, 0.2);
  border-right: 1px solid rgba(0, 0, 0, 0.2);
  padding: 0 10px; }

.n2_color_picker__palette_history .n2_color_picker__palette_item:last-child {
  display: none; }

.n2_color_picker--has-opacity .n2_color_picker__palette_history .n2_color_picker__palette_item:last-child {
  display: block; }

.n2_color_picker__picker_area {
  padding: 10px;
  width: min-content;
  display: grid;
  grid-template-columns: auto auto auto;
  grid-gap: 10px;
  overflow: hidden; }

.n2_color_picker__picker_canvas {
  align-self: stretch;
  position: relative;
  width: 140px;
  background-color: #ff0000;
  background-image: linear-gradient(to top, #000, rgba(204, 154, 129, 0)), linear-gradient(to right, #fff, rgba(204, 154, 129, 0));
  box-shadow: 0 0 1px 1px rgba(0, 0, 0, 0.2) inset; }

.n2_color_picker__picker_canvas_dot {
  position: absolute;
  left: -5px;
  top: -5px;
  width: 10px;
  height: 10px;
  border-radius: 10px;
  background: #fff;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.4); }

.n2_color_picker__picker_hue {
  align-self: stretch;
  position: relative;
  width: 20px;
  background: linear-gradient(to bottom, #f00 0%, #ff0 17%, #0f0 33%, #0ff 50%, #00f 67%, #f0f 83%, #f00 100%);
  box-shadow: 0 0 1px 1px rgba(0, 0, 0, 0.2) inset; }

.n2_color_picker__picker_hue_dot {
  position: absolute;
  left: -3px;
  top: -3px;
  width: calc(100% + 6px);
  height: 6px;
  border-radius: 5px;
  background: #fff;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.4); }

.n2_color_picker__picker_opacity {
  align-self: stretch;
  display: none;
  width: 20px; }

.n2_color_picker--has-opacity .n2_color_picker__picker_opacity {
  display: block; }

.n2_color_picker__picker_opacity_inner {
  position: relative;
  width: 100%;
  height: 100%;
  box-shadow: 0 0 1px 1px rgba(0, 0, 0, 0.2) inset; }

.n2_color_picker__picker_opacity_dot {
  position: absolute;
  left: -3px;
  top: -3px;
  width: calc(100% + 6px);
  height: 6px;
  border-radius: 5px;
  background: #fff;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.4); }

.n2_checker_box {
  background-image: linear-gradient(45deg, #808080 25%, transparent 25%), linear-gradient(-45deg, #808080 25%, transparent 25%), linear-gradient(45deg, transparent 75%, #808080 75%), linear-gradient(-45deg, transparent 75%, #808080 75%);
  background-size: 10px 10px;
  background-position: 0 0, 0 5px, 5px -5px, -5px 0; }

#dolly {
  display: none !important; }

.toplevel_page_smart-slider3 #wpbody-content {
  padding-bottom: 0 !important; }

.toplevel_page_smart-slider3 #wpfooter, .toplevel_page_smart-slider3 #screen-meta-links {
  display: none; }

#wpbody-content #n2-admin {
  margin: 10px 20px 20px 0; }

html[dir="rtl"] #wpbody-content #n2-admin {
  margin: 10px 0 0 20px; }

#wpbody-content #n2-admin a:focus {
  box-shadow: none; }

/*
  WordPress admin area uses this code:
  @media screen and (max-width: 782px)
  #wpbody select {
      height: 36px;
      font-size: 16px;
  }
  which needs to be overwritten:
  */
.n2 input {
  min-height: initial;
  border-radius: 0; }

.n2 select {
  background: none;
  max-width: initial;
  min-height: 26px;
  height: 26px;
  font-size: 12px;
  -webkit-appearance: menulist;
  -moz-appearance: menulist; }

.n2 select[multiple] {
  height: auto;
  -webkit-appearance: none;
  -moz-appearance: none; }

/*
  Weaker CSS selector is necessary for darkmode background!
   */
.n2_admin .n2_field_select select {
  background: #fff; }

html.n2_html--application-only {
  background: #ffffff; }
  html.n2_html--application-only #wpbody {
    padding: 0 !important; }
  html.n2_html--application-only.wp-toolbar {
    padding: 0; }
  html.n2_html--application-only,
  html.n2_html--application-only body {
    position: relative;
    height: auto;
    min-height: 100vh;
    background: #fff; }
  html.n2_html--application-only #wpadminbar,
  html.n2_html--application-only #adminmenuwrap,
  html.n2_html--application-only #adminmenuback,
  html.n2_html--application-only .update-nag {
    display: none !important; }
  html.n2_html--application-only #wpcontent {
    margin: 0 !important;
    padding-left: 0;
    padding-right: 0; }
  html.n2_html--application-only .updated,
  html.n2_html--application-only .error,
  html.n2_html--application-only .notice-error,
  html.n2_html--application-only .notice-success,
  html.n2_html--application-only .notice-warning,
  html.n2_html--application-only .notice-info,
  html.n2_html--application-only .notice,
  html.n2_html--application-only .wpuf-review-notice,
  html.n2_html--application-only .analytify-review-notice,
  html.n2_html--application-only .prompt-box + .overlay {
    display: none !important; }

.wp-block-nextend-smartslider3 {
  position: relative;
  z-index: 1;
  min-height: 100px; }
  .wp-block-nextend-smartslider3 iframe {
    pointer-events: none; }

.wp-block-nextend-smartslider3__button-container {
  display: inline-grid;
  grid-template-columns: auto auto;
  grid-gap: 10px; }

/**
  For Nimble builder
  @see https://nextendweb.atlassian.net/browse/SSDEV-2137
   */
.wp-customizer .n2_modal {
  z-index: 1000030; }

.wp-customizer a.n2_button, .wp-customizer a.n2_button:HOVER, .wp-customizer a.n2_button:FOCUS {
  color: #FFFFFF; }

/**
  For GS Logo slider
  @see https://nextendweb.atlassian.net/browse/SSDEV-3072
   */
#gslogo-dummy-data-install--notice,
.gslogo-admin-notice,
.gslogo-review-notice {
  display: none !important; }

#a2020-admin-bar-app {
  z-index: 100000; }

.a2020_admin_theme #wpwrap {
  display: block;
  vertical-align: top; }

.a2020_admin_theme #wpbody-content #n2-admin {
  margin: 10px 20px 20px 20px; }

.n2_html--application-only .a2020_admin_theme #a2020-admin-bar-app {
  display: none !important; }

#uip-toolbar {
  display: none; }

html.wp-toolbar[uip-toolbar=true] {
  padding-top: 0px; }

.n2_admin {
  position: relative;
  min-width: 980px; }

.n2_admin__header {
  position: relative;
  z-index: 2000;
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  line-height: 1.3;
  font-size: 16px;
  -webkit-font-smoothing: antialiased; }
  .n2_admin__header a {
    transition: none 0s;
    text-decoration: none;
    box-shadow: none; }

.n2_admin__content {
  border-radius: 0 0 3px 3px;
  border-left: 1px solid #94B2C1;
  border-right: 1px solid #94B2C1;
  border-bottom: 1px solid #94B2C1;
  background-color: #F0F4F7;
  padding-bottom: 40px;
  min-height: calc(100vh - 180px); }

.n2_admin_ui {
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  line-height: 1.3;
  font-size: 16px;
  -webkit-font-smoothing: antialiased; }
  .n2_admin_ui a {
    transition: none 0s;
    text-decoration: none;
    box-shadow: none; }
  .n2_admin_ui a:ACTIVE,
  .n2_admin_ui a:VISITED,
  .n2_admin_ui a:FOCUS,
  .n2_admin_ui a:LINK {
    text-decoration: none; }
  .n2_admin_ui iframe {
    border: 0; }
  .n2_admin_ui [contenteditable=true] {
    -webkit-user-select: text;
    user-select: text; }

.n2_admin--empty {
  margin: 0 !important; }
  .n2_admin--empty.n2_admin {
    min-width: 0; }

.n2_nav_bar {
  position: relative;
  z-index: 11;
  min-height: 70px;
  display: flex;
  background-color: #1375E9;
  border-top-left-radius: 3px;
  border-top-right-radius: 3px; }

.n2_nav_bar__logo {
  flex: 0 1 auto;
  display: flex;
  justify-content: center; }
  .n2_nav_bar__logo a {
    display: inline-flex;
    align-items: center;
    justify-content: center; }
  .n2_nav_bar__logo svg {
    max-width: none; }

.n2_nav_bar__menu {
  position: relative;
  z-index: 2;
  flex: 1 1 auto;
  padding: 0 10px;
  width: 100%;
  box-sizing: border-box;
  display: flex;
  justify-content: flex-end;
  align-items: center;
  margin-left: auto; }

@media only screen and (max-width: 1600px) {
  .n2_nav_bar__menu {
    width: auto; } }

.n2_nav_bar__menuitem {
  margin: 10px; }
  .n2_nav_bar__menuitem > a {
    display: block;
    padding: 0 5px;
    text-overflow: ellipsis;
    overflow: hidden;
    white-space: nowrap;
    max-width: 150px; }
  .n2_nav_bar__menuitem a {
    font-size: 14px;
    line-height: 2; }
    .n2_nav_bar__menuitem a, .n2_nav_bar__menuitem a:HOVER, .n2_nav_bar__menuitem a:FOCUS {
      color: #d0e3fb; }

.n2_breadcrumbs {
  padding: 0 10px;
  white-space: nowrap;
  flex: 1 1 auto;
  width: 100%;
  box-sizing: border-box;
  position: relative;
  z-index: 2;
  display: flex;
  align-items: center; }

@media only screen and (max-width: 1600px) {
  .n2_breadcrumbs {
    width: auto; } }

.n2_breadcrumbs__breadcrumb_button {
  display: flex;
  align-items: center;
  padding: 0 8px;
  font-size: 14px;
  line-height: 2;
  text-transform: capitalize;
  font-weight: bold; }
  .n2_breadcrumbs__breadcrumb_button, .n2_breadcrumbs__breadcrumb_button:HOVER, .n2_breadcrumbs__breadcrumb_button:FOCUS {
    color: #d0e3fb; }
  .n2_breadcrumbs__breadcrumb_button > * {
    margin: 0 2px; }
  .n2_breadcrumbs__breadcrumb_button > span {
    max-width: 150px;
    text-overflow: ellipsis;
    overflow: hidden;
    white-space: nowrap; }
  .n2_breadcrumbs__breadcrumb_button > .ssi_16 {
    margin: 0 3px; }
  .n2_breadcrumbs__breadcrumb--active .n2_breadcrumbs__breadcrumb_button, .n2_breadcrumbs__breadcrumb--active .n2_breadcrumbs__breadcrumb_button:HOVER, .n2_breadcrumbs__breadcrumb--active .n2_breadcrumbs__breadcrumb_button:FOCUS {
    color: #FFFFFF; }

.n2_breadcrumbs__arrow {
  font-size: 16px;
  color: #d0e3fb; }
  .n2_breadcrumbs__arrow .ssi_16 {
    display: block; }
  html[dir="rtl"] .n2_breadcrumbs__arrow {
    transform: rotateZ(180deg); }

.n2-admin-content-with-sidebar {
  display: flex; }

.n2-admin-content-with-sidebar__sidebar {
  flex: 0 0 auto;
  width: 340px;
  margin-left: -1px;
  background-color: #4d5d70;
  border-bottom-left-radius: 3px;
  border-right: 1px solid #212d3a;
  box-sizing: border-box; }

.n2-admin-content-with-sidebar__content {
  position: relative;
  min-height: 1000px; }

.n2_top_bar_main {
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  line-height: 1.3;
  font-size: 16px;
  -webkit-font-smoothing: antialiased;
  z-index: 1020;
  margin-left: -1px;
  margin-right: -1px;
  position: -webkit-sticky;
  position: sticky;
  top: 0;
  display: flex;
  flex-flow: row-reverse;
  background-color: #0C1924;
  padding: 12px 10px; }
  .n2_top_bar_main a {
    transition: none 0s;
    text-decoration: none;
    box-shadow: none; }
  .n2_top_bar_main .n2_top_bar_button_icon {
    font-size: 24px;
    width: 24px;
    height: 24px; }
    .n2_top_bar_main .n2_top_bar_button_icon, .n2_top_bar_main .n2_top_bar_button_icon:HOVER, .n2_top_bar_main .n2_top_bar_button_icon:FOCUS {
      color: #94B2C1; }

.n2_top_bar_main__primary {
  display: flex;
  flex-flow: row-reverse;
  align-items: center; }
  .n2_top_bar_main__primary > * {
    margin: 0 10px; }
  .n2_top_bar_main__primary .n2_button_spacer {
    margin: 0 10px;
    width: 2px;
    height: 32px; }
  .n2_top_bar_main__primary .n2_button_spacer--visible {
    height: 24px;
    background-color: #3A4956;
    border-radius: 1px; }

.n2_top_bar_main__secondary {
  display: flex;
  align-items: center;
  margin-right: auto;
  padding-left: 5px; }
  .n2_top_bar_main__secondary > * {
    margin: 0 5px; }

.n2_top_bar_group--narrow .n2_top_bar_group__inner {
  display: flex;
  flex-flow: row-reverse;
  margin: 0 -5px;
  direction: ltr; }
  .n2_top_bar_group--narrow .n2_top_bar_group__inner > * {
    margin: 0 5px; }

.n2_header {
  position: relative;
  z-index: 990;
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  line-height: 1.3;
  font-size: 16px;
  -webkit-font-smoothing: antialiased;
  background-color: #FFFFFF;
  padding: 30px 28px; }
  .n2_header a {
    transition: none 0s;
    text-decoration: none;
    box-shadow: none; }
  .n2_header.n2_header--has-menu-items {
    padding-top: 50px;
    padding-bottom: 0; }

.n2_header__heading_container {
  margin: 0 12px; }

.n2_header__content {
  display: flex;
  align-items: center; }

.n2_header__heading {
  display: flex;
  align-items: center; }

.n2_header__heading_primary {
  font-size: 32px;
  line-height: 1.25em;
  color: #283F4D; }

.n2_header__heading_after {
  font-size: 24px;
  line-height: 1em;
  color: #94B2C1;
  margin: 0 15px; }

.n2_header__actions {
  margin-left: auto;
  display: flex; }
  .n2_header__actions > * {
    margin: 0 12px; }
  html[dir="rtl"] .n2_header__actions {
    margin-left: 0;
    margin-right: auto; }

.n2_header__menu {
  margin: 0 -8px;
  /** 20px is the side margin + padding of a menuItem **/
  display: flex; }

.n2_header__menu_item {
  margin: 0 20px;
  line-height: 50px;
  font-size: 16px;
  font-weight: bold;
  text-transform: capitalize;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }
  .n2_header__menu_item, .n2_header__menu_item:ACTIVE, .n2_header__menu_item:VISITED, .n2_header__menu_item:FOCUS, .n2_header__menu_item:LINK {
    color: #325C77; }

.n2_header__menu_item--active, .n2_header__menu_item--active:ACTIVE, .n2_header__menu_item--active:VISITED, .n2_header__menu_item--active:FOCUS, .n2_header__menu_item--active:LINK {
  box-shadow: inset 0 -3px 0 0 #1375E9 !important;
  color: #1375E9; }

.n2_notification_center {
  z-index: 9999999999999;
  position: fixed;
  right: 10px;
  bottom: 0;
  display: flex;
  flex-flow: column;
  align-items: flex-end;
  width: auto;
  max-height: 310px;
  padding: 10px;
  overflow-y: auto;
  overflow-x: hidden; }
  html[dir="rtl"] .n2_notification_center {
    left: 10px;
    right: auto; }

.n2_notification_center__message {
  max-width: 500px;
  margin: 10px;
  display: flex;
  align-items: center;
  background-color: #0C1924;
  border-radius: 5px;
  padding: 20px;
  transition: transform 0.5s ease-in-out 0.3s;
  transform: translateX(150%); }
  html[dir="rtl"] .n2_notification_center__message {
    transform: translateX(-150%); }

.n2_notification_center__message--animate {
  transform: translateX(0%); }
  html[dir="rtl"] .n2_notification_center__message--animate {
    transform: translateX(0%); }

.n2_notification_center__message--success {
  min-width: 250px; }

.n2_notification_center__message_icon {
  flex: 0 0 auto;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 48px;
  height: 48px;
  border-radius: 100%;
  color: #fff; }
  .n2_notification_center__message--success .n2_notification_center__message_icon {
    background-color: #04C018; }
    .n2_notification_center__message--success .n2_notification_center__message_icon .ssi_24::before {
      content: "\E14C"; }
  .n2_notification_center__message--notice .n2_notification_center__message_icon {
    background-color: #1D81F9; }
    .n2_notification_center__message--notice .n2_notification_center__message_icon .ssi_24::before {
      content: "\E14D"; }

.n2_notification_center__message_content {
  flex: 1 1 auto;
  padding: 0 10px; }

.n2_notification_center__message_content_label {
  color: #FFFFFF;
  font-size: 14px;
  line-height: 20px;
  text-transform: uppercase; }

.n2_notification_center__message_content_description {
  font-size: 14px;
  line-height: 20px;
  color: #94B2C1; }

.n2_notification_center__message_action {
  flex: 0 0 auto;
  margin: 0 10px;
  background-color: #1D81F9;
  border-radius: 3px;
  padding: 0 10px;
  white-space: nowrap;
  font-size: 11px;
  color: #FFFFFF;
  line-height: 30px;
  cursor: pointer;
  text-transform: uppercase; }
  .n2_notification_center__message_action:HOVER {
    background-color: #338EF9; }

.n2_body--fullscreen-editor-visible {
  overflow: hidden; }

.n2_fullscreen_editor {
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  line-height: 1.3;
  font-size: 16px;
  -webkit-font-smoothing: antialiased;
  z-index: 100002;
  position: fixed;
  left: 0;
  top: 0;
  display: none;
  box-sizing: border-box;
  width: 100%;
  height: 100%;
  padding: 20px;
  background: rgba(28, 41, 51, 0.8); }
  .n2_fullscreen_editor a {
    transition: none 0s;
    text-decoration: none;
    box-shadow: none; }

.n2_fullscreen_editor--visible {
  display: block; }

.n2_fullscreen_editor__overlay {
  z-index: 1;
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  cursor: pointer; }

.n2_fullscreen_editor__window {
  z-index: 2;
  position: relative;
  flex: 1 1 auto;
  height: 100%;
  display: flex;
  flex-flow: column;
  border-radius: 3px;
  box-shadow: 0 1px 5px 1px rgba(55, 77, 88, 0.2);
  overflow: hidden; }
  .n2_fullscreen_editor__window > iframe {
    display: block;
    width: 100%;
    height: 100%; }

.n2_fullscreen_editor__nav_bar {
  position: relative;
  z-index: 2;
  display: flex;
  flex: 0 0 auto;
  background-color: #0c1924; }

.n2_fullscreen_editor__nav_bar_label {
  position: absolute;
  width: 100%;
  z-index: 1;
  line-height: 60px;
  color: #FFFFFF;
  font-size: 22px;
  text-align: center;
  text-transform: capitalize; }

.n2_fullscreen_editor__nav_bar_actions {
  position: relative;
  z-index: 2;
  flex: 1 1 auto;
  display: flex;
  justify-content: flex-end;
  padding: 12px 10px; }
  .n2_fullscreen_editor__nav_bar_actions > * {
    margin: 0 10px; }

.n2_fullscreen_editor__content {
  flex: 1 1 auto;
  display: flex;
  overflow: hidden; }

.n2_fullscreen_editor__content_sidebar {
  position: relative;
  flex: 0 0 340px;
  width: 340px;
  overflow: auto;
  background-color: #3A4956; }

.n2_fullscreen_editor__content_sidebar_top_bar {
  position: -webkit-sticky;
  position: sticky;
  top: 0; }

.n2_fullscreen_editor__save_as_new_container {
  padding: 12px 20px; }
  .n2_fullscreen_editor__save_as_new_container .n2_button {
    text-align: center;
    display: block; }

.n2_fullscreen_editor__visual {
  display: flex;
  align-items: center;
  padding: 0 10px;
  background-color: #2C3A45;
  border-bottom: 1px solid #1e2830; }

.n2_fullscreen_editor__visual--active {
  background-color: #1375E9;
  border-bottom: 1px solid #1375E9; }

.n2_fullscreen_editor__visual_select_tick {
  width: 16px;
  height: 16px;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  border: 2px solid #131C23;
  border-radius: 3px;
  background-color: #2C3A45;
  cursor: pointer; }
  .n2_fullscreen_editor__visual_select_tick .ssi_16 {
    display: none;
    color: #fff; }
  .n2_fullscreen_editor__visual--selected .n2_fullscreen_editor__visual_select_tick {
    background-color: #04C018;
    border-color: #04C018; }
    .n2_fullscreen_editor__visual--selected .n2_fullscreen_editor__visual_select_tick .ssi_16 {
      display: inline-block; }

.n2_fullscreen_editor__visual_label {
  flex: 1 1 auto;
  padding: 0 10px;
  color: #94B2C1;
  font-size: 12px;
  line-height: 44px;
  cursor: pointer; }
  .n2_fullscreen_editor__visual--active .n2_fullscreen_editor__visual_label {
    color: #fff; }

.n2_fullscreen_editor__visual_action {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  padding: 5px;
  font-size: 16px;
  color: #94B2C1;
  cursor: pointer; }
  .n2_fullscreen_editor__visual--active .n2_fullscreen_editor__visual_action {
    color: #fff; }

.n2_fullscreen_editor__content_content {
  position: relative;
  flex: 1 1 auto;
  overflow: auto;
  background-color: #F0F4F7; }

.n2_iframe_application {
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  line-height: 1.3;
  font-size: 16px;
  -webkit-font-smoothing: antialiased;
  display: flex;
  flex-flow: column;
  margin: 0 !important;
  min-width: 0;
  height: 100vh;
  overflow: hidden; }
  .n2_iframe_application a {
    transition: none 0s;
    text-decoration: none;
    box-shadow: none; }

.n2_iframe_application__nav_bar {
  position: relative;
  z-index: 2;
  display: flex;
  flex: 0 0 auto;
  height: 60px;
  background-color: #0c1924; }

.n2_iframe_application__nav_bar_label {
  position: absolute;
  width: 100%;
  z-index: 1;
  line-height: 60px;
  color: #FFFFFF;
  font-size: 22px;
  text-align: center; }

.n2_iframe_application__nav_bar_actions {
  position: relative;
  z-index: 2;
  flex: 1 1 auto;
  display: flex;
  justify-content: flex-end;
  padding: 12px 10px; }
  .n2_iframe_application__nav_bar_actions > * {
    margin: 0 10px; }
  .n2_iframe_application__nav_bar_actions .n2_button_spacer {
    margin: 0 10px;
    width: 2px;
    height: 32px; }
  .n2_iframe_application__nav_bar_actions .n2_button_spacer--visible {
    height: 24px;
    background-color: #3A4956;
    border-radius: 1px; }
  .n2_iframe_application__nav_bar_actions .n2_button_plain_icon {
    margin: 0 5px; }
    .n2_iframe_application__nav_bar_actions .n2_button_plain_icon, .n2_iframe_application__nav_bar_actions .n2_button_plain_icon:HOVER, .n2_iframe_application__nav_bar_actions .n2_button_plain_icon:FOCUS {
      color: #94B2C1; }

.n2_iframe_application__content {
  position: relative;
  flex: 1 1 auto;
  overflow: auto;
  background-color: #F0F4F7; }
  .n2_iframe_application__content .n2_form__table[data-field="table-shapedivider"] .n2_field__label .ssi_16--minidesktopportrait {
    color: #325c77; }

.n2_admin_editor {
  margin: 0 !important;
  min-width: 0; }

.n2_admin_editor_overlay {
  z-index: 10;
  position: fixed;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  display: flex;
  flex-flow: column;
  visibility: hidden; }

.n2_admin_editor_overlay__top {
  position: relative;
  z-index: 10;
  flex: 0 0 auto; }

.n2_admin_editor_overlay__top_bar_main {
  position: static;
  visibility: visible; }
  .n2_admin_editor_overlay__top_bar_main .n2_breadcrumbs {
    margin: 0 -8px;
    padding: 0; }
  .n2_admin_editor_overlay__top_bar_main .n2_breadcrumbs__breadcrumb_button {
    color: #94b2c1; }
    .n2_admin_editor_overlay__top_bar_main .n2_breadcrumbs__breadcrumb_button, .n2_admin_editor_overlay__top_bar_main .n2_breadcrumbs__breadcrumb_button:HOVER, .n2_admin_editor_overlay__top_bar_main .n2_breadcrumbs__breadcrumb_button:FOCUS {
      color: #94b2c1; }
  .n2_admin_editor_overlay__top_bar_main .n2_breadcrumbs__arrow {
    color: #94b2c1; }

.n2_admin_editor__ui_slide_manager.n2_slide_manager {
  visibility: visible;
  position: absolute;
  left: 0;
  top: 60px;
  width: 100%;
  height: calc(100vh - 60px); }
  .n2_admin_editor__ui_slide_manager.n2_slide_manager .n2_slide_manager__inner {
    overflow: auto;
    max-height: 100%; }

.n2_admin_editor__content {
  display: flex;
  position: relative;
  box-sizing: border-box;
  width: 100%;
  height: 100vh;
  padding-top: 75px;
  padding-left: 65px;
  background: #f0f4f7; }
  .n2_body--show-add-more .n2_admin_editor__content,
  .n2_body--attached-layer-list .n2_admin_editor__content {
    padding-bottom: 0 !important; }

.n2_admin_editor__content_inner {
  position: relative;
  flex: 1 1 auto;
  background-color: #f0f4f7;
  overflow: auto; }

.n2_admin_editor_overlay--show-layer-navigation:not(.n2_admin_editor_overlay--show-add-more):not(.n2_admin_editor_overlay--attached-layer-list) .n2_slide_editor_timeline_toggle--show {
  display: none; }

.n2_admin_editor_overlay--show-layer-navigation.n2_admin_editor_overlay--attached-layer-list .n2_slide_editor_timeline_toggle--show {
  pointer-events: none; }

.n2_admin_editor_overlay--show-slides .n2_admin_editor_overlay__top_bar_main .n2_top_bar_main__primary {
  opacity: 0.5;
  pointer-events: none; }

.n2_top_bar_main__logo {
  flex: 1 1 auto;
  overflow: hidden;
  display: flex;
  align-items: center;
  justify-content: center; }
  .n2_top_bar_main__logo a {
    display: inline-block;
    padding: 0 10px; }
  .n2_top_bar_main__logo svg {
    vertical-align: top;
    display: inline-block; }

.n2_admin__banner {
  background-color: #1C2933;
  z-index: 2;
  position: relative;
  color: #fff;
  align-items: center; }
  .n2_admin__banner .n2_admin__banner_inner {
    max-width: 500px;
    text-align: center;
    margin: 0 auto;
    padding: 40px; }
    .n2_admin__banner .n2_admin__banner_inner .n2_admin__banner_inner_title {
      font-size: 22px;
      line-height: 32px; }
    .n2_admin__banner .n2_admin__banner_inner .n2_admin__banner_inner_description {
      font-size: 14px;
      color: #94B2C1;
      line-height: 24px; }
    .n2_admin__banner .n2_admin__banner_inner .n2_admin__banner_inner_button {
      margin-top: 20px; }
  .n2_admin__banner .n2_admin__banner_close {
    margin: 10px;
    width: 36px;
    height: 36px;
    display: flex;
    align-items: center;
    justify-content: center;
    background-color: #6B7986;
    border-radius: 100%;
    color: #FFFFFF;
    font-size: 16px;
    cursor: pointer;
    position: absolute;
    top: 0;
    right: 0; }
    .n2_admin__banner .n2_admin__banner_close:HOVER {
      background-color: #8694A2; }

.n2_free_need_more {
  padding: 40px 0;
  display: flex;
  flex-flow: column;
  align-items: center;
  text-align: center; }

.n2_free_need_more__logo img {
  display: block;
  width: 64px; }

.n2_free_need_more__title {
  margin-top: 10px;
  font-size: 16px;
  line-height: 28px;
  font-weight: bold;
  color: #FFFFFF; }
  .n2_modal .n2_free_need_more__title {
    color: #283F4D; }

.n2_free_need_more__paragraph {
  max-width: 270px;
  line-height: 24px;
  font-size: 14px;
  color: #BDCFD9; }
  .n2_modal .n2_free_need_more__paragraph {
    color: #325C77; }

.n2_free_need_more__button {
  margin-top: 10px;
  padding: 0 25px;
  background-color: #1D81F9;
  border-radius: 3px;
  font-size: 12px;
  line-height: 36px;
  font-weight: bold;
  text-transform: uppercase; }
  .n2_free_need_more__button, .n2_free_need_more__button:HOVER, .n2_free_need_more__button:FOCUS {
    color: #FFFFFF; }
  .n2_free_need_more__button:HOVER {
    background-color: #338ef9; }

.n2_body--inherit-cursor * {
  cursor: inherit !important; }

.n2_modal {
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  line-height: 1.3;
  font-size: 16px;
  -webkit-font-smoothing: antialiased;
  z-index: 100003;
  position: fixed;
  left: 0;
  top: 0;
  display: none;
  box-sizing: border-box;
  width: 100%;
  height: 100%;
  padding: 20px;
  background: rgba(28, 41, 51, 0.8);
  align-items: center;
  justify-content: center; }
  .n2_modal a {
    transition: none 0s;
    text-decoration: none;
    box-shadow: none; }

.n2_modal--visible {
  display: flex; }

.n2_modal__overlay {
  z-index: 1;
  position: absolute;
  width: 100%;
  height: 100%;
  cursor: pointer; }

.n2_modal__window {
  position: relative;
  z-index: 2;
  display: flex;
  flex-flow: column;
  width: 100%;
  max-height: 100%;
  border-radius: 3px;
  box-shadow: 0 2px 20px 0 rgba(0, 0, 0, 0.2); }

.n2_modal--simple .n2_modal__window {
  border-radius: 3px;
  overflow: hidden; }

.n2_modal--simple .n2_modal__body_outer {
  flex: 1 1 auto;
  position: relative;
  background: #fff;
  border-radius: 3px 3px 0 0;
  overflow: auto; }

.n2_modal--simple .n2_modal__body {
  padding: 20px 40px 10px; }

.n2_modal--simple .n2_modal__close_wrap {
  position: sticky;
  top: 0;
  height: 0;
  display: flex;
  justify-content: flex-end; }

.n2_modal--simple .n2_modal__close {
  margin: 10px;
  width: 36px;
  height: 36px;
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: #F0F4F7;
  border-radius: 100%;
  color: #283F4D;
  font-size: 16px;
  cursor: pointer; }

.n2_modal--simple .n2_modal__buttons {
  display: flex;
  flex: 0 0 auto;
  background-color: #F0F4F7;
  height: 56px;
  border-radius: 0 0 3px 3px;
  border-top: 1px solid #E4E9EC; }
  .n2_modal--simple .n2_modal__buttons[data-buttons="0"] {
    display: none; }
  .n2_modal--simple .n2_modal__buttons[data-buttons="1"] .n2_modal__button {
    width: 100%;
    align-items: center;
    justify-content: center; }
  .n2_modal--simple .n2_modal__buttons[data-buttons="2"] .n2_modal__button {
    width: 50%;
    align-items: center; }
    .n2_modal--simple .n2_modal__buttons[data-buttons="2"] .n2_modal__button:first-child {
      justify-content: flex-end;
      padding-right: 10px; }
    .n2_modal--simple .n2_modal__buttons[data-buttons="2"] .n2_modal__button:last-child {
      justify-content: flex-start;
      padding-left: 10px; }

.n2_modal--simple .n2_modal__button {
  display: flex; }

.n2_modal[data-modal-type="generator-insert-variable"] .n2_generator_variables {
  display: flex;
  flex-wrap: wrap;
  padding: 3px;
  background-color: #F0F4F7;
  border-radius: 3px;
  max-height: 130px;
  overflow-y: auto; }

.n2_modal[data-modal-type="generator-insert-variable"] .n2_generator_variables__variable {
  margin: 3px;
  padding: 0 10px;
  background-color: #94B2C1;
  border-radius: 3px;
  color: #fff;
  font-size: 11px;
  line-height: 30px;
  cursor: pointer; }
  .n2_modal[data-modal-type="generator-insert-variable"] .n2_generator_variables__variable:HOVER {
    background-color: #7F9CAA; }

.n2_modal[data-modal-type="generator-insert-variable"] .n2_generator_variables__variable--selected {
  background-color: #1D81F9;
  color: #fff; }
  .n2_modal[data-modal-type="generator-insert-variable"] .n2_generator_variables__variable--selected:HOVER {
    background-color: #1D81F9; }

.n2_modal[data-modal-type="generator-insert-variable"] .n2_generator_result {
  padding: 0 8px;
  background-color: #F0F4F7;
  border-radius: 3px;
  height: 80px;
  overflow-y: scroll;
  font-size: 12px;
  line-height: 30px;
  color: #325C77; }

.n2_modal--lightbox .n2_modal__window {
  height: 100%; }

.n2_modal--lightbox .n2_modal__top_bar {
  position: relative;
  border-radius: 3px 3px 0 0;
  background-color: #0C1924; }

.n2_modal--lightbox .n2_modal__top_bar_title {
  position: absolute;
  width: 100%;
  z-index: 1;
  line-height: 60px;
  color: #fff;
  font-size: 22px;
  text-align: center;
  text-transform: capitalize; }

.n2_modal--lightbox .n2_modal__top_bar_buttons {
  position: relative;
  z-index: 2;
  display: flex;
  justify-content: flex-end;
  padding: 12px 10px; }
  .n2_modal--lightbox .n2_modal__top_bar_buttons > * {
    margin: 0 10px; }

.n2_modal--lightbox .n2_modal__body {
  flex: 1 1 auto;
  overflow: auto;
  background: #F0F4F7;
  border-radius: 0 0 3px 3px; }

.n2_modal--lightbox[data-modal-type="icons"] .n2_modal__body {
  display: flex;
  overflow: hidden; }

.n2_modal--lightbox[data-modal-type="icons"] .n2_modal__sidebar {
  position: relative;
  flex: 0 0 340px;
  width: 340px;
  background-color: #3a4956; }

.n2_modal--lightbox[data-modal-type="icons"] .n2_modal__sidebar_inner {
  height: 100%;
  overflow: auto; }

.n2_modal--lightbox[data-modal-type="icons"] .n2_modal__content {
  position: relative;
  flex: 1 1 auto;
  background-color: #f0f4f7; }

.n2_modal--lightbox[data-modal-type="icons"] .n2_modal__content_inner {
  height: 100%;
  overflow: auto; }

.n2_modal_icons__search_area {
  padding: 10px 20px;
  background-color: #3a4956;
  border-bottom: 1px solid #1e2830; }
  .n2_modal_icons__search_area .n2_field__label {
    display: none; }
  .n2_modal_icons__search_area .n2_field_text {
    display: flex; }
    .n2_modal_icons__search_area .n2_field_text input {
      width: 100%; }

.n2_modal_icons__list_item {
  background-color: #2C3A45;
  padding: 0 10px;
  border-bottom: 1px solid #1e2830;
  color: #94B2C1;
  font-size: 12px;
  line-height: 44px;
  cursor: pointer; }

.n2_modal_icons__list_item--active {
  background-color: #1D81F9;
  color: #FFFFFF; }

.n2_modal_icons__icon {
  display: inline-block;
  margin: 5px;
  width: 32px;
  height: 32px;
  cursor: pointer;
  font-size: 24px;
  line-height: 32px;
  text-align: center;
  color: #000; }

.n2_modal_filesystem__content {
  display: flex;
  flex-wrap: wrap;
  padding: 10px; }
  .n2_modal_filesystem__content[data-mode="single"] .n2_modal_filesystem_box--file, .n2_modal_filesystem__content[data-mode="multiple"] .n2_modal_filesystem_box--file {
    cursor: pointer; }

.n2_modal_filesystem__current_path {
  width: 100%;
  margin: 0 10px;
  font-size: 14px;
  line-height: 30px;
  color: #325c77; }

.n2_modal_filesystem_box {
  position: relative;
  display: flex;
  flex-flow: column;
  justify-content: flex-end;
  margin: 10px;
  width: 160px;
  height: 140px;
  border-radius: 3px; }
  .n2_modal_filesystem_box .n2-button {
    display: none; }

.n2_modal_filesystem_box--active {
  box-shadow: 0 0 0 3px #1D81F9; }

.n2_modal_filesystem_box__image {
  height: 100px;
  background-repeat: no-repeat;
  background-size: cover; }

.n2_modal_filesystem_box__icon {
  height: 100px;
  display: flex;
  align-items: center;
  justify-content: center;
  color: #94B2C1; }

.n2_modal_filesystem_box__label {
  padding: 0 15px;
  background-color: #FFFFFF;
  color: #325C77;
  font-size: 12px;
  line-height: 40px;
  text-align: center;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis; }

.n2_modal_filesystem_box--upload {
  border: 2px dashed #BDCFD9; }
  .n2_modal_filesystem_box--upload .n2_modal_filesystem_box__icon {
    height: 84px; }
  .n2_modal_filesystem_box--upload .n2_modal_filesystem_box__label {
    line-height: 20px;
    white-space: normal;
    overflow: visible;
    text-overflow: initial; }

.n2_modal_filesystem_box--directory-up {
  cursor: pointer; }

.n2_modal_filesystem_box--directory {
  cursor: pointer; }

.n2_modal_select_slider {
  position: relative;
  display: flex;
  flex-wrap: wrap;
  margin: 0 auto;
  padding: 24px; }

.n2_modal_select_slider__box {
  position: relative;
  flex: 0 0 auto;
  width: 270px;
  height: 180px;
  border-radius: 3px;
  margin: 16px;
  background: #fff;
  cursor: pointer; }

.n2_modal[data-modal-type="select-slider"] .n2_modal__window {
  max-width: 980px;
  max-height: 744px; }

.n2_modal--iframe .n2_modal__window {
  height: 100%; }

.n2_modal--iframe iframe {
  width: 100%;
  height: 100%;
  border: 0; }

.n2_modal__hotkey {
  display: flex;
  flex-wrap: wrap; }

.n2_modal__hotkey_column {
  flex: 0 0 50%;
  padding: 10px;
  box-sizing: border-box; }

.n2_modal__hotkey_group {
  padding: 10px; }

.n2_modal__hotkey_row {
  display: flex;
  justify-content: space-between;
  margin: 5px 0; }

.n2_modal__hotkey_text {
  font-size: 12px;
  line-height: 28px;
  color: #325C77; }

.n2_modal__hotkey_key {
  font-size: 11px;
  font-weight: bold;
  line-height: 30px;
  text-transform: uppercase;
  color: #FFFFFF;
  background: #94B2C1;
  border-radius: 3px;
  padding: 0 10px;
  min-width: 11px;
  text-align: center;
  margin-left: 5px; }

.n2_modal__hotkey_key:last-child {
  background: #1D81F9; }

.n2_modal__hotkey_keys {
  display: flex; }

.n2_modal__hotkey_title {
  text-transform: uppercase;
  font-size: 14px;
  line-height: 26px;
  color: #325C77;
  font-weight: bold; }

.n2_modal__icon {
  margin: 0 auto 10px;
  flex: 0 0 auto;
  width: 99px;
  height: 99px;
  border-radius: 100%;
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: 48px; }

.n2_modal__icon--green {
  background: #e5f8e7;
  color: #04C018; }

.n2_modal__icon--purple {
  background: #EFEBF8;
  color: #5F39C2; }

.n2_modal__icon--red {
  background: #F9EBE9;
  color: #BE331F; }

.n2_modal__icon--blue {
  background: #E8F2FE;
  color: #1D81F9; }

.n2_modal__heading {
  line-height: 28px;
  font-size: 18px;
  color: #283F4D;
  font-weight: bold;
  text-transform: capitalize;
  text-align: center; }

.n2_modal__subheading {
  font-size: 18px;
  line-height: 30px;
  color: #283F4D; }

.n2_modal__paragraph {
  color: #325C77;
  font-size: 14px;
  line-height: 26px;
  text-align: center;
  margin-bottom: 20px; }

input.n2_modal__input {
  box-sizing: initial;
  width: 100%;
  max-width: 240px;
  border: 2px solid #94B2C1;
  border-radius: 3px;
  height: 32px;
  line-height: 32px;
  font-size: 14px;
  color: #325C77;
  text-align: center;
  margin-bottom: 22px; }
  input.n2_modal__input:FOCUS {
    box-shadow: none;
    border-color: #1375e9; }

.n2_modal__form_row {
  margin: 0 -10px; }
  .n2_modal__form_row .n2_field {
    display: inline-flex;
    flex-flow: column;
    vertical-align: top;
    margin-bottom: 15px;
    padding: 5px 10px; }
    .n2_modal__form_row .n2_field .n2_field__label {
      display: flex;
      align-items: center; }
      .n2_modal__form_row .n2_field .n2_field__label label {
        line-height: 20px;
        color: #325C77;
        font-size: 12px;
        text-transform: capitalize; }
      .n2_modal__form_row .n2_field .n2_field__label .ssi_16--info {
        margin: 0 5px;
        font-size: 16px;
        color: #94B2C1; }
  .n2_modal__form_row .n2_field.n2_field--label-none > .n2_field__element {
    display: flex;
    flex-wrap: wrap; }
  .n2_modal__form_row .n2_field.n2_field--label-placeholder {
    padding-top: 25px; }
  .n2_modal__form_row .n2_field__grouping > .n2_field__element,
  .n2_modal__form_row .n2_field_mixed > .n2_field__element {
    margin: -5px -10px; }

.n2_modal__form_row--fullwidth {
  display: flex; }
  .n2_modal__form_row--fullwidth .n2_field {
    display: flex;
    width: 100%; }
    .n2_modal__form_row--fullwidth .n2_field .n2_field__element {
      display: flex; }
      .n2_modal__form_row--fullwidth .n2_field .n2_field__element > * {
        flex: 1 1 auto; }
    .n2_modal__form_row--fullwidth .n2_field .n2_field_text {
      display: flex; }
      .n2_modal__form_row--fullwidth .n2_field .n2_field_text input {
        width: 100%; }
    .n2_modal__form_row--fullwidth .n2_field .n2_field_textarea textarea {
      width: 100%; }
    .n2_modal__form_row--fullwidth .n2_field .n2_field_select select {
      box-sizing: border-box;
      width: 100%;
      height: 30px;
      line-height: 30px; }
      .n2_modal__form_row--fullwidth .n2_field .n2_field_select select[multiple] {
        height: auto; }

.n2_modal__container_hidden {
  display: none; }

.n2_modal__container_hidden--visible {
  display: block; }

.n2_modal__form_row--large .n2_field .n2_field__label label {
  font-size: 18px;
  line-height: 50px;
  color: #283F4D; }

.n2_form_element--hidden {
  display: none !important; }

.n2_field__label label {
  display: block;
  margin: 0;
  white-space: nowrap; }

.n2_button {
  display: inline-flex;
  align-items: center;
  border-radius: 3px;
  padding: 0 18px;
  font-size: 12px;
  line-height: 32px;
  font-weight: bold;
  text-transform: uppercase;
  white-space: nowrap; }
  .n2_button .n2_button__label {
    max-width: 150px;
    text-overflow: ellipsis;
    overflow: hidden; }
  .n2_button, .n2_button:HOVER, .n2_button:FOCUS {
    color: #FFFFFF; }
  .n2_button .ssi_16,
  .n2_button .ssi_24,
  .n2_button .ssi_32 {
    margin-left: 5px;
    margin-right: -5px; }
    html[dir="rtl"] .n2_button .ssi_16, html[dir="rtl"]
    .n2_button .ssi_24, html[dir="rtl"]
    .n2_button .ssi_32 {
      margin-left: -5px;
      margin-right: 5px; }

.n2_button--inactive {
  opacity: 0.5; }

.n2_button--big {
  padding: 0 30px;
  font-size: 12px;
  line-height: 36px; }

.n2_button--small {
  padding: 0 10px;
  font-size: 11px;
  line-height: 30px; }
  .n2_button--small .ssi_16,
  .n2_button--small .ssi_24,
  .n2_button--small .ssi_32 {
    margin-right: 0; }

.n2_button--blue {
  background-color: #1D81F9; }
  .n2_button--blue:HOVER {
    background-color: #338EF9; }

.n2_button--green {
  background-color: #04C018; }
  .n2_button--green:HOVER {
    background-color: #07CA1C; }

.n2_button--red {
  background-color: #C43E2A; }
  .n2_button--red:HOVER {
    background-color: #D23923; }

.n2_button--grey {
  background-color: #94B2C1; }
  .n2_button--grey:HOVER {
    background-color: #7F9CAA; }

.n2_button--grey-dark {
  background-color: #6b7986; }
  .n2_button--grey-dark:HOVER {
    background-color: #8694A2; }

.n2_button--purple {
  background-color: #5F39C2; }

.n2_button--inactive {
  opacity: 0.5; }

.n2_button_plain {
  display: inline-flex;
  align-items: center;
  padding: 0 5px;
  font-size: 16px;
  line-height: 32px;
  text-transform: capitalize; }
  .n2_button_plain, .n2_button_plain:HOVER, .n2_button_plain:FOCUS {
    color: #325C77; }
  .n2_button_plain .ssi_16,
  .n2_button_plain .ssi_24,
  .n2_button_plain .ssi_32 {
    margin: 0 5px; }

.n2_button_plain--small {
  font-size: 14px;
  line-height: 30px; }

.n2_button_plain--color-blue:HOVER {
  color: #005BC6; }

.n2_button_plain--color-blue, .n2_button_plain--color-blue:FOCUS {
  color: #1375E9; }

.n2_button_plain_icon {
  display: inline-flex;
  width: 30px;
  height: 30px;
  align-items: center;
  justify-content: center;
  border-radius: 3px;
  font-size: 16px; }
  .n2_button_plain_icon, .n2_button_plain_icon:HOVER, .n2_button_plain_icon:FOCUS {
    color: #325C77; }

.n2_button_plain_icon--active {
  background: #1d81f9; }
  .n2_button_plain_icon--active, .n2_button_plain_icon--active:HOVER, .n2_button_plain_icon--active:FOCUS {
    color: #fff; }

.n2_button_plain_icon--big {
  font-size: 32px;
  width: 36px;
  height: 36px; }

.n2_button_icon {
  display: inline-flex;
  width: 30px;
  height: 30px;
  align-items: center;
  justify-content: center;
  border-radius: 3px;
  font-size: 16px; }
  .n2_button_icon, .n2_button_icon:HOVER, .n2_button_icon:FOCUS {
    color: #FFFFFF; }

.n2_button_icon--small {
  width: 24px;
  height: 24px; }

.n2_button_icon--blue {
  background-color: #1D81F9; }
  .n2_button_icon--blue:HOVER {
    background-color: #338EF9; }

.n2_button_icon--green {
  background-color: #04C018; }
  .n2_button_icon--green:HOVER {
    background-color: #07CA1C; }

.n2_button_icon--red {
  background-color: #C43E2A; }
  .n2_button_icon--red:HOVER {
    background-color: #D23923; }

.n2_button_icon--grey {
  background-color: #94B2C1; }
  .n2_button_icon--grey:HOVER {
    background-color: #7F9CAA; }

.n2_button_icon--grey-dark {
  background-color: #6b7986; }
  .n2_button_icon--grey-dark:HOVER {
    background-color: #8694A2; }

.n2_popover {
  position: relative; }

.n2_popover_content {
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  line-height: 1.3;
  font-size: 16px;
  -webkit-font-smoothing: antialiased;
  display: none;
  z-index: 200000;
  position: fixed;
  left: 0;
  top: 0; }
  .n2_popover_content a {
    transition: none 0s;
    text-decoration: none;
    box-shadow: none; }

.n2_popover_content--visible {
  display: flex;
  flex-flow: column; }

.n2_popover_content_exit {
  cursor: pointer;
  order: 1; }

.n2_popover_content_inner {
  order: 2;
  border-radius: 3px;
  background-color: #FFFFFF;
  box-shadow: 0 1px 5px 1px rgba(55, 77, 88, 0.2); }

.n2_floating_menu {
  display: inline-block; }

.n2_floating_menu__button {
  vertical-align: top; }
  .n2_floating_menu__button.n2_button {
    padding: 0 20px 0 16px; }

.n2_floating_menu__items {
  display: flex;
  flex-flow: column;
  padding: 8px 0; }

.n2_floating_menu__item {
  display: inline-flex;
  align-items: center;
  white-space: nowrap;
  font-size: 12px;
  line-height: 28px;
  padding: 0 10px;
  text-transform: capitalize; }
  .n2_floating_menu__item .ssi_16 {
    color: #94b2c1;
    padding: 0 5px; }
  .n2_floating_menu__item, .n2_floating_menu__item:FOCUS {
    color: #325C77; }
  .n2_floating_menu__item:HOVER {
    background-color: #1D81F9;
    color: #fff; }
    .n2_floating_menu__item:HOVER .ssi_16 {
      color: #fff; }
  .n2_floating_menu__item[data-state] {
    display: none; }

.n2_floating_menu__item--has-state[data-state] {
  display: block; }

.n2_floating_menu__item--active, .n2_floating_menu__item--active:FOCUS,
.n2_floating_menu__item--active .ssi_16 {
  color: #1375E9; }

.n2_floating_menu__item--active:HOVER {
  color: #fff; }

.n2_floating_menu__item--red, .n2_floating_menu__item--red:FOCUS,
.n2_floating_menu__item--red .ssi_16 {
  color: #C43E2A; }

.n2_floating_menu__item--red:HOVER {
  color: #fff; }
  .n2_floating_menu__item--red:HOVER .ssi_16 {
    color: #fff; }

.n2_floating_menu__item_label {
  padding: 0 5px; }

.n2_floating_menu__item_separator {
  margin: 8px 0;
  border-top: 2px solid rgba(55, 77, 88, 0.2); }

.n2_form__tab[data-tab] {
  display: none; }

.n2_form__tab--active[data-tab] {
  display: block; }

.n2_header__menu_item.n2_form__tab_button--active, .n2_header__menu_item.n2_form__tab_button--active:ACTIVE, .n2_header__menu_item.n2_form__tab_button--active:VISITED, .n2_header__menu_item.n2_form__tab_button--active:FOCUS, .n2_header__menu_item.n2_form__tab_button--active:LINK {
  box-shadow: inset 0 -3px 0 0 #1375E9 !important;
  color: #1375E9; }

.n2_form__table {
  margin: 20px;
  background-color: #FFFFFF;
  border-radius: 3px; }

.n2_form__table_label {
  display: flex;
  padding: 15px 20px; }

.n2_form__table_label_title {
  line-height: 42px;
  font-size: 22px;
  color: #283F4D;
  text-transform: capitalize; }

.n2_form__table_label_fields {
  flex: 1 1 auto;
  display: flex;
  align-items: center;
  padding: 0 5px; }

.n2_form__table_label_fields--end {
  justify-content: flex-end; }

.n2_form__table_label_field {
  margin: 0 5px; }
  .n2_form__table_label_field .n2_field_image_list .n2_field_image_list__preview {
    height: 38px; }
  .n2_form__table_label_field .n2_field_image_list .n2_field_image_list__arrow {
    line-height: 38px; }
  .n2_form__table_label_field .n2_field_image_list .n2_field_image_list__popover {
    top: 42px; }
  .n2_form__table_label_field .n2_field_onoff__labels {
    display: none; }

.n2_form__table_preview {
  border-top: 1px solid #e4e9ec;
  padding: 20px; }

.n2_form__table_row_group_label {
  color: #283F4D;
  border-top: 1px solid #e4e9ec;
  padding: 20px;
  font-size: 18px;
  text-transform: capitalize; }

.n2_form__table_row {
  display: flex;
  flex-wrap: wrap;
  padding: 10px;
  border-top: 1px solid #E4E9EC; }
  .n2_form__table_row .n2_field {
    display: inline-flex;
    flex-flow: column;
    vertical-align: top;
    padding: 5px 10px; }
    .n2_form__table_row .n2_field.n2_field--raw {
      padding: 0 10px; }
    .n2_form__table_row .n2_field .n2_field__label {
      display: flex;
      align-items: center; }
      .n2_form__table_row .n2_field .n2_field__label label {
        line-height: 20px;
        color: #325C77;
        font-size: 12px;
        text-transform: capitalize; }
      .n2_form__table_row .n2_field .n2_field__label .ssi_16--info {
        margin: 0 5px 2px;
        font-size: 16px;
        color: #94B2C1; }
  .n2_form__table_row .n2_field.n2_field--label-none > .n2_field__element {
    display: flex;
    flex-wrap: wrap; }
  .n2_form__table_row .n2_field.n2_field--label-placeholder {
    padding-top: 25px; }
  .n2_form__table_row .n2_field__grouping > .n2_field__element,
  .n2_form__table_row .n2_field_mixed > .n2_field__element {
    margin: -5px -10px; }

.n2_form__table_row--hidden {
  display: none; }

.n2_form__table_row_plain {
  border-top: 1px solid #E4E9EC; }

.n2_fields_layer_window__title {
  display: flex;
  padding: 7px 10px;
  background-color: #1C2933;
  border-bottom: 1px solid #131c23; }

.n2_fields_layer_window__label {
  flex: 1 1 auto;
  color: #94B2C1;
  font-size: 12px;
  line-height: 30px;
  font-weight: bold;
  text-transform: uppercase;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_fields_layer_window__title_fields {
  display: flex; }
  .n2_form--dark .n2_fields_layer_window__title_fields .n2_field_select select {
    background-color: #2c3a45;
    border-color: #2c3a45; }
    .n2_form--dark .n2_fields_layer_window__title_fields .n2_field_select select:FOCUS {
      border: 2px solid #1D81F9; }
  .n2_form--dark .n2_fields_layer_window__title_fields .n2_field_icon_tab {
    background-color: #2c3a45; }

.n2_fields_layer_window__fields {
  display: flex;
  flex-wrap: wrap;
  padding: 5px 0; }
  .n2_fields_layer_window__fields .n2_field {
    display: inline-flex;
    flex-flow: column;
    vertical-align: top;
    padding: 5px 10px; }
    .n2_fields_layer_window__fields .n2_field .n2_field__label {
      display: flex;
      align-items: center;
      max-width: 180px; }
      .n2_fields_layer_window__fields .n2_field .n2_field__label label {
        line-height: 20px;
        font-size: 12px;
        color: #325C77;
        text-transform: capitalize;
        text-overflow: ellipsis;
        overflow: hidden;
        white-space: nowrap; }
        .n2_form--dark .n2_fields_layer_window__fields .n2_field .n2_field__label label {
          color: #BDCFD9; }
      .n2_fields_layer_window__fields .n2_field .n2_field__label .ssi_16--info {
        margin: 0 5px;
        font-size: 16px;
        color: #94B2C1; }
        .n2_form--dark .n2_fields_layer_window__fields .n2_field .n2_field__label .ssi_16--info {
          color: #BDCFD9; }
      .n2_fields_layer_window__fields .n2_field .n2_field__label .ssi_16--minidesktopportrait {
        color: #bdcfd9; }
  .n2_fields_layer_window__fields .n2_field.n2_field--label-none > .n2_field__element {
    display: flex;
    flex-wrap: wrap; }
  .n2_fields_layer_window__fields .n2_field.n2_field--label-placeholder {
    padding-top: 25px; }
  .n2_fields_layer_window__fields .n2_field__grouping > .n2_field__element,
  .n2_fields_layer_window__fields .n2_field_mixed > .n2_field__element {
    margin: -5px -10px; }

.n2_layer_window_notice {
  line-height: 20px;
  font-size: 12px;
  color: #bdcfd9;
  padding: 10px; }

body[data-device='desktopPortrait'] .n2_layer_window_notice__device_icon {
  display: none; }

.n2_form__visual_set {
  display: flex;
  background-color: #1C2933;
  padding: 12px 20px; }

.n2_form__visual_set_label {
  flex: 1 1 auto;
  line-height: 30px;
  font-size: 12px;
  color: #94B2C1;
  text-transform: uppercase; }

.n2_field_text {
  position: relative;
  display: inline-flex;
  vertical-align: top;
  border-radius: 3px;
  background-color: #FFFFFF;
  border: 2px solid #94B2C1; }
  .n2_form--dark .n2_field_text {
    background-color: #2C3A45;
    border: 2px solid #1C2933; }
  .n2_field_text.n2_field_text--focus {
    border-color: #1D81F9; }
  .n2_field_text input {
    background: initial;
    padding: 0;
    margin: 0 6px;
    height: 26px;
    line-height: 1;
    font-size: 12px;
    color: #325C77; }
    .n2_field_text input::placeholder {
      color: #325C77;
      opacity: 1; }
    .n2_form--dark .n2_field_text input {
      color: #BDCFD9; }
      .n2_form--dark .n2_field_text input::placeholder {
        color: #BDCFD9;
        opacity: 1; }
    .n2_field_text input, .n2_field_text input:FOCUS {
      border: 0;
      box-shadow: none;
      outline: 0; }
    .n2_field_text input::-ms-clear {
      display: none; }
  .n2_field_text .n2_field_number__slider {
    display: none;
    position: absolute;
    top: 26px;
    margin: 0 -2px;
    width: 100%;
    min-width: 70px;
    z-index: 2;
    padding-top: 7px; }
  .n2_field_text:HOVER .n2_field_number__slider, .n2_field_text.n2_field_text--focus .n2_field_number__slider {
    display: block; }
  .n2_field_text .n2_field_number__slider_inner {
    overflow: hidden;
    height: 30px;
    border-radius: 3px;
    background-color: #ffffff;
    box-shadow: 0 1px 5px 1px rgba(55, 77, 88, 0.2); }
  .n2_field_text .nui-slider {
    position: relative;
    background-color: #94B2C1;
    height: 6px;
    margin: 12px 10px;
    border-radius: 10px; }
  .n2_field_text .nui-slider .nui-slider-handle {
    position: absolute;
    top: 0;
    z-index: 2;
    width: 10px;
    height: 10px;
    background-color: #FFFFFF;
    border: 2px solid #94B2C1;
    margin: -4px -7px 0;
    border-radius: 50px;
    cursor: ew-resize;
    -ms-touch-action: none;
    touch-action: none; }

.n2_field_text__pre_label {
  padding: 0 6px;
  line-height: 26px;
  background-color: #94b2c1;
  font-size: 11px;
  color: #fff;
  text-align: center;
  text-transform: uppercase; }
  .n2_form--dark .n2_field_text__pre_label {
    background-color: #1C2933;
    color: #94B2C1; }
  .n2_field_text--focus .n2_field_text__pre_label {
    background-color: #1D81F9; }
    .n2_form--dark .n2_field_text--focus .n2_field_text__pre_label {
      color: #FFFFFF; }

.n2_field_text__clear {
  display: flex;
  line-height: 26px;
  width: 26px;
  justify-content: center;
  align-items: center; }
  .n2_field_text__clear, .n2_field_text__clear:HOVER, .n2_field_text__clear:FOCUS {
    color: #94B2C1; }
  .n2_field_text--empty .n2_field_text__clear {
    visibility: hidden; }

.n2_field_text__choose {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  margin: -2px -2px -2px 0;
  background-color: #04C018;
  width: 30px;
  line-height: 30px;
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px; }
  .n2_field_text__choose:HOVER {
    background-color: #07CA1C; }
  .n2_field_text__choose, .n2_field_text__choose:HOVER, .n2_field_text__choose:FOCUS {
    color: #FFFFFF; }
  .n2_field_text--empty .n2_field_text__choose {
    background-color: #94B2C1; }
    .n2_form--dark .n2_field_text--empty .n2_field_text__choose {
      background-color: #1C2933; }
      .n2_form--dark .n2_field_text--empty .n2_field_text__choose, .n2_form--dark .n2_field_text--empty .n2_field_text__choose:HOVER, .n2_form--dark .n2_field_text--empty .n2_field_text__choose:FOCUS {
        color: #94B2C1; }
  html[dir="rtl"] .n2_field_text__choose {
    border-radius: 3px 0 0 3px;
    margin: -2px 0 -2px -2px; }

.n2_field_text__choose_text {
  margin: -2px -2px -2px 0;
  padding: 0 10px;
  background-color: #04C018;
  font-size: 11px;
  line-height: 30px;
  text-transform: uppercase;
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px; }
  .n2_field_text__choose_text, .n2_field_text__choose_text:HOVER, .n2_field_text__choose_text:FOCUS {
    color: #FFFFFF; }

.n2_field_text__post .n2_field_unit__current_unit {
  padding: 0 6px;
  border-radius: 0;
  line-height: 26px; }

.n2_field_text__post .n2_field_unit__units {
  top: 26px;
  right: -2px; }

.n2_field_text_image__preview {
  width: 26px;
  height: 26px;
  background-color: #fff;
  background-size: cover;
  background-position: 50% 50%;
  border-right: 2px solid #94B2C1; }
  html[dir="rtl"] .n2_field_text_image__preview {
    border-right: 0;
    border-left: 2px solid #94B2C1; }
  .n2_form--dark .n2_field_text_image__preview {
    border-right-color: #1C2933;
    background-color: #2C3A45; }
    html[dir="rtl"] .n2_form--dark .n2_field_text_image__preview {
      border-left-color: #1C2933; }
  .n2_field_text--focus .n2_field_text_image__preview {
    border-right-color: #1D81F9; }

.n2_field_text_image__size_label {
  display: none;
  position: absolute;
  right: 28px;
  top: -20px;
  color: #325c77;
  line-height: 16px;
  font-size: 11px;
  background-color: #fff;
  border: 2px solid #94b2c1;
  border-bottom: 0;
  padding: 0 5px;
  border-radius: 2px 2px 0 0; }
  .n2_form--dark .n2_field_text_image__size_label {
    color: #bdcfd9;
    background-color: #2c3a45;
    border-color: #1c2933; }
  html[dir="rtl"] .n2_field_text_image__size_label {
    left: 28px;
    right: unset; }

.n2_field_text_image__size_label--visible {
  display: block; }

.n2_field_text_image__button {
  margin-left: 10px; }
  html[dir="rtl"] .n2_field_text_image__button {
    margin-left: 0;
    margin-right: 10px; }

.n2_field_number input {
  text-align: center; }

.n2_field_text__unit,
.n2_field_number__unit {
  padding: 0 6px;
  background-color: #94B2C1;
  font-size: 11px;
  color: #FFFFFF;
  line-height: 26px;
  text-transform: uppercase; }
  .n2_form--dark .n2_field_text__unit, .n2_form--dark
  .n2_field_number__unit {
    background-color: #1C2933;
    color: #94B2C1; }
  .n2_field_text--focus .n2_field_text__unit, .n2_field_text--focus
  .n2_field_number__unit {
    background-color: #1D81F9; }
    .n2_form--dark .n2_field_text--focus .n2_field_text__unit, .n2_form--dark .n2_field_text--focus
    .n2_field_number__unit {
      color: #FFFFFF; }

.n2_field_upload {
  cursor: pointer; }
  .n2_field_upload .n2_field_chooser__label {
    width: 150px;
    white-space: nowrap;
    text-overflow: ellipsis;
    overflow: hidden; }
  .n2_field_upload input[type="file"] {
    position: absolute;
    top: 0;
    left: 0;
    width: 100%;
    height: 0;
    opacity: 0;
    font-size: 0;
    padding: 15px 0; }
    .n2_field_upload input[type="file"]::-webkit-file-upload-button {
      cursor: pointer; }

.n2_field_table__content {
  display: grid;
  grid-gap: 2px;
  width: 100%; }

.n2_field_table__cell {
  padding: 5px 10px;
  background-color: #F0F4F7;
  font-size: 12px;
  line-height: 22px;
  color: #325C77; }

.n2_field_tab {
  display: inline-flex;
  background-color: #94B2C1;
  border-radius: 2px;
  overflow: hidden; }

.n2_field_tab__option--selected {
  background-color: #1D81F9; }

.n2_field_tab__option {
  padding: 0 15px;
  line-height: 30px;
  font-size: 12px;
  color: #fff;
  cursor: pointer;
  white-space: nowrap; }

.n2_modal_tab__tabs {
  text-align: center;
  background-color: #f0f4f7;
  margin: 0 -40px 16px -40px; }

.n2_modal_tab__tabs_button {
  display: inline-block;
  font-size: 16px;
  color: #325C77;
  font-family: inherit;
  font-weight: 500;
  padding: 20px 0 17px 0;
  margin: 0 20px;
  cursor: pointer;
  border-bottom: 3px solid transparent; }

.n2_modal_tab__tabs_button--active {
  border-bottom: 3px solid #1375e9;
  color: #1375e9;
  box-sizing: border-box; }

.n2_modal_tab__tabs_content {
  display: none; }

.n2_modal_tab__tabs_content--active {
  display: block; }

.n2_field_textarea {
  position: relative;
  display: inline-block;
  vertical-align: top;
  border-radius: 3px;
  background-color: #FFFFFF;
  border: 2px solid #94B2C1; }
  .n2_form--dark .n2_field_textarea {
    background-color: #2C3A45;
    border: 2px solid #1C2933; }
  .n2_field_textarea.n2_field_text--focus {
    border-color: #1D81F9; }
  .n2_field_textarea textarea {
    padding: 0 6px;
    margin: 0;
    background: initial;
    box-sizing: border-box;
    min-height: 44px;
    vertical-align: top;
    line-height: 20px;
    font-size: 12px;
    color: #325C77;
    resize: both; }
    .n2_form--dark .n2_field_textarea textarea {
      color: #BDCFD9; }
    .n2_field_textarea textarea, .n2_field_textarea textarea:FOCUS {
      border: 0;
      outline: 0;
      box-shadow: none; }

.n2_field_textarea--inline textarea {
  min-height: 26px; }

#n2-ss-layer-window textarea {
  resize: vertical; }

.n2_field_textarea_rich {
  position: relative;
  border-radius: 3px;
  background-color: #FFFFFF;
  border: 2px solid #94B2C1; }
  .n2_form--dark .n2_field_textarea_rich {
    background-color: #2C3A45;
    border: 2px solid #1C2933; }
  .n2_field_textarea_rich.n2_field_text--focus {
    border-color: #1D81F9; }
  .n2_field_textarea_rich textarea {
    display: block;
    padding: 0 6px;
    margin: 0;
    box-sizing: border-box;
    min-height: 44px;
    vertical-align: top;
    line-height: 20px;
    font-size: 12px;
    color: #325C77;
    resize: vertical; }
    .n2_form--dark .n2_field_textarea_rich textarea {
      background-color: #2c3a45;
      color: #bdcfd9; }
    .n2_field_textarea_rich textarea, .n2_field_textarea_rich textarea:FOCUS {
      border: 0;
      outline: 0;
      box-shadow: none; }

.n2_field_textarea_rich__buttons {
  display: flex; }
  .n2_form--dark .n2_field_textarea_rich__buttons {
    background-color: #2c3a45;
    border-bottom: 2px solid #1c2933; }

.n2_field_textarea_rich__button {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 30px;
  height: 30px;
  font-size: 16px;
  color: #94b2c1;
  border-right: 2px solid #1c2933;
  cursor: pointer; }

.n2_field_select select {
  margin: 0;
  padding: 0 6px;
  border-radius: 3px;
  max-width: 280px;
  width: auto;
  /* Joomla */
  line-height: 26px;
  height: 26px;
  box-sizing: content-box;
  font-size: 12px;
  color: #325C77;
  background-color: #FFFFFF;
  border: 2px solid #94B2C1; }
  .n2_field_select select[multiple] {
    padding: 0;
    height: auto; }
    .n2_field_select select[multiple] option {
      padding: 6px 6px;
      font-size: 12px;
      color: #325c77; }
  .n2_form--dark .n2_field_select select {
    background-color: #2C3A45;
    border: 2px solid #1C2933;
    color: #BDCFD9; }
  .n2_field_select select, .n2_field_select select:FOCUS {
    box-shadow: none;
    outline: 0; }
  .n2_field_select select:FOCUS {
    border: 2px solid #1D81F9; }

.n2_field_onoff {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  padding: 3px 0;
  display: flex;
  cursor: pointer; }

.n2_field_onoff__slider {
  flex: 0 0 auto;
  border-radius: 12px;
  background-color: #94B2C1;
  padding: 3px;
  width: 38px; }
  .n2_field_onoff--on .n2_field_onoff__slider {
    background-color: #04C018; }

.n2_field_onoff__slider_bullet {
  width: 18px;
  height: 18px;
  border-radius: 20px;
  background-color: #FFFFFF;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1);
  transition: transform 0.25s; }
  .n2_field_onoff--on .n2_field_onoff__slider_bullet {
    transform: translateX(20px); }
    html[dir="rtl"] .n2_field_onoff--on .n2_field_onoff__slider_bullet {
      transform: translateX(-20px); }

.n2_field_onoff__labels {
  margin: 0 3px;
  position: relative;
  overflow: hidden;
  height: 24px; }

.n2_field_onoff__label {
  font-size: 12px;
  line-height: 24px;
  font-weight: bold;
  text-transform: uppercase;
  max-width: 100px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_field_onoff__label_off {
  color: #94B2C1; }
  .n2_field_onoff--on .n2_field_onoff__label_off {
    margin-top: -24px; }

.n2_field_onoff__label_on {
  color: #40BB22; }

.n2_field_unit {
  position: relative;
  display: inline-block;
  vertical-align: top; }

.n2_field_unit__current_unit {
  line-height: 30px;
  padding: 0 6px;
  border-radius: 3px;
  font-size: 11px;
  text-transform: uppercase;
  background-color: #94b2c1;
  color: #fff; }
  .n2_form--dark .n2_field_unit__current_unit {
    background-color: #1C2933;
    color: #94B2C1; }

.n2_field_unit__units {
  display: none;
  z-index: 2;
  position: absolute;
  top: 30px;
  right: 0;
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  background: #fff;
  box-shadow: 0 1px 5px 1px rgba(55, 77, 88, 0.2); }
  .n2_field_unit:HOVER .n2_field_unit__units {
    display: block; }

.n2_field_unit__unit {
  padding: 0 5px;
  line-height: 24px;
  cursor: pointer;
  color: #325C77;
  font-size: 11px;
  text-transform: uppercase; }
  .n2_field_unit__unit:HOVER {
    background: #1D81F9;
    color: #FFF; }

.n2_field_margin_padding {
  display: inline-flex;
  vertical-align: top; }
  .n2_field_margin_padding .n2_field_text {
    position: relative;
    border-radius: 0;
    margin-left: -2px; }
    .n2_field_margin_padding .n2_field_text.n2_field_text--focus {
      z-index: 2; }
  .n2_field_margin_padding .n2_field_unit {
    margin-left: -2px; }
  .n2_field_margin_padding .n2_field_unit__current_unit {
    border-top-left-radius: 0;
    border-bottom-left-radius: 0; }
    html[dir="rtl"] .n2_field_margin_padding .n2_field_unit__current_unit {
      border-radius: 3px 0 0 3px; }

.n2_field_margin_padding__pre_label {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 30px;
  height: 30px;
  background-color: #94b2c1;
  font-size: 16px;
  color: #fff;
  text-align: center;
  border-top-left-radius: 3px;
  border-bottom-left-radius: 3px;
  cursor: pointer; }
  .n2_form--dark .n2_field_margin_padding__pre_label {
    background-color: #1C2933;
    color: #94B2C1; }
  html[dir="rtl"] .n2_field_margin_padding__pre_label {
    border-radius: 0 3px 3px 0; }

.n2_field_margin_padding--linked-values .n2_field_margin_padding__pre_label .ssi_16::before {
  content: "\E64D"; }

.n2_field_margin_padding--linked-values .n2_field_text + .n2_field_text {
  display: none; }

.n2_field_radio {
  display: inline-flex;
  vertical-align: top;
  margin: 0 -5px; }
  .n2_field_radio .n2_field_radio__option {
    display: flex;
    align-items: center;
    cursor: pointer;
    margin: 0 5px; }
  .n2_field_radio .n2_field_radio__option_marker {
    display: flex;
    justify-content: center;
    align-items: center;
    width: 14px;
    height: 14px;
    line-height: 14px;
    background-color: #fff;
    border: 2px solid #94B2C1;
    border-radius: 10px; }
    .n2_field_radio .n2_field_radio__option_marker .ssi_16 {
      display: none;
      color: #fff; }
  .n2_field_radio .n2_field_radio__option--selected .n2_field_radio__option_marker {
    background-color: #04C018;
    border-color: #04C018; }
    .n2_field_radio .n2_field_radio__option--selected .n2_field_radio__option_marker .ssi_16 {
      display: block; }
  .n2_field_radio .n2_field_radio__option_label {
    margin: 0 5px;
    font-size: 12px;
    line-height: 30px;
    color: #325C77; }

.n2_field_radio_icon {
  display: inline-flex;
  vertical-align: top;
  overflow: hidden;
  border-radius: 3px; }
  .n2_field_radio_icon .n2_field_radio__option {
    display: flex;
    align-items: center;
    justify-content: center;
    width: 30px;
    height: 30px;
    background-color: #94B2C1;
    color: #fff;
    font-size: 16px;
    cursor: pointer; }
    .n2_form--dark .n2_field_radio_icon .n2_field_radio__option {
      background-color: #1C2933;
      color: #94B2C1; }
  .n2_field_radio_icon .n2_field_radio__option--selected {
    background-color: #1D81F9; }
    .n2_form--dark .n2_field_radio_icon .n2_field_radio__option--selected {
      background-color: #1D81F9;
      color: #fff; }

.n2_field_color .n2-field-color-preview {
  border-right: 2px solid #94b2c1; }
  html[dir="rtl"] .n2_field_color .n2-field-color-preview {
    border-right: 0;
    border-left: 2px solid #94b2c1; }
  .n2_form--dark .n2_field_color .n2-field-color-preview {
    border-right-color: #1C2933; }
    html[dir="rtl"] .n2_form--dark .n2_field_color .n2-field-color-preview {
      border-left-color: #1C2933; }

.n2_field_color.n2_field_text--focus .n2-field-color-preview {
  border-right-color: #1d81f9; }
  html[dir="rtl"] .n2_field_color.n2_field_text--focus .n2-field-color-preview {
    border-left-color: #1d81f9; }

.n2_field_color .n2-field-color-preview-inner {
  width: 26px;
  height: 26px;
  cursor: pointer; }

.n2_field_color input {
  text-transform: uppercase;
  width: 50px;
  text-align: center; }

.n2_field_color--alpha input {
  width: 65px; }

.n2_field_image_list {
  position: relative;
  display: inline-flex;
  vertical-align: top;
  align-items: center;
  border-radius: 3px;
  border: 2px solid #94B2C1;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }
  .n2_field_image_list > .n2_field_image_list__fields {
    display: none; }

.n2_field_image_list--focus {
  border-color: #1D81F9;
  z-index: 99; }

.n2_field_image_list__preview {
  display: inline-flex;
  background-color: #fff;
  height: 26px;
  cursor: pointer; }
  .n2_field_image_list__preview img {
    height: 100%;
    width: auto; }

.n2_field_image_list__preview_label {
  padding: 0 6px;
  background: #fff;
  line-height: 26px;
  font-size: 12px;
  color: #325C77; }

.n2_field_image_list__arrow {
  width: 18px;
  line-height: 26px;
  font-size: 12px;
  color: #325c77;
  text-align: center;
  cursor: pointer; }

.n2_field_image_list__popover {
  display: none;
  position: absolute;
  top: 30px;
  padding: 10px;
  border-radius: 3px;
  background-color: #FFFFFF;
  box-shadow: 0 1px 5px 1px rgba(55, 77, 88, 0.2); }
  .n2_field_image_list--focus .n2_field_image_list__popover {
    display: block; }

.n2_field_image_list__popover_items {
  max-width: 50vw;
  display: inline-flex;
  flex-wrap: wrap; }

.n2_field_image_list__popover_item {
  margin: 10px;
  background-color: #fff;
  cursor: pointer; }

.n2_field_image_list__popover_item_image {
  border: 2px solid #94B2C1;
  border-radius: 3px;
  padding: 3px; }
  .n2_field_image_list__popover_item_image img {
    display: block;
    width: 100%; }
  .n2_field_image_list__popover_item--selected .n2_field_image_list__popover_item_image {
    border-color: #1D81F9; }

.n2_field_image_list__popover_item_disabled {
  display: inline-flex;
  align-items: center;
  min-height: 100%;
  border: 2px dashed #94b2c1;
  border-radius: 3px;
  padding: 0 10px;
  box-sizing: border-box;
  color: #325c77;
  font-size: 14px;
  line-height: 30px;
  text-transform: capitalize; }
  .n2_field_image_list__popover_item--selected .n2_field_image_list__popover_item_disabled {
    border-color: #1D81F9; }

.n2_field_image_list__popover_item_label {
  color: #325c77;
  background: #fff;
  font-size: 12px;
  text-align: center;
  line-height: 30px; }
  .n2_field_image_list__popover_item--selected .n2_field_image_list__popover_item_label {
    color: #1D81F9; }

.n2_field_checkbox_onoff {
  display: inline-flex;
  vertical-align: top;
  width: 30px;
  height: 30px;
  align-items: center;
  justify-content: center;
  background-color: #94B2C1;
  border-radius: 3px;
  font-size: 16px;
  color: #fff;
  cursor: pointer; }

.n2_field_checkbox_onoff--active {
  background-color: #1D81F9; }

.n2_field_group_checkbox_onoff {
  border-radius: 3px;
  overflow: hidden;
  margin: 5px 10px; }
  .n2_field_group_checkbox_onoff .n2_field {
    padding: 0; }
  .n2_field_group_checkbox_onoff .n2_field_checkbox_onoff {
    border-radius: 0; }

.n2_field_widget_position {
  position: relative;
  display: inline-flex;
  vertical-align: top;
  background-color: #fff;
  border: 2px solid #94b2c1;
  border-radius: 3px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.n2_field_widget_position--focus {
  border-color: #1D81F9;
  z-index: 99; }

.n2_field_widget_position__label {
  display: inline-block;
  vertical-align: top;
  padding: 0 6px;
  line-height: 26px;
  font-size: 12px;
  color: #325c77;
  cursor: pointer; }

.n2_field_widget_position__arrow {
  width: 18px;
  line-height: 26px;
  font-size: 12px;
  color: #325c77;
  text-align: center;
  cursor: pointer; }

.n2_field_widget_position__popover {
  display: none;
  position: absolute;
  top: 30px;
  padding: 10px;
  border-radius: 3px;
  background-color: #FFFFFF;
  box-shadow: 0 1px 5px 1px rgba(55, 77, 88, 0.2); }
  .n2_field_widget_position--focus .n2_field_widget_position__popover {
    display: flex; }
  .n2_field_widget_position__popover .n2_field__element {
    flex-wrap: nowrap !important; }

.n2_field_control_type_picker {
  display: flex;
  flex-wrap: wrap;
  margin: -10px -5px; }

.n2_field_control_type_picker__item {
  margin: 10px;
  position: relative;
  display: inline-block;
  border: none;
  border-radius: 1px;
  height: auto;
  cursor: pointer; }
  .n2_field_control_type_picker__item img {
    display: block; }
  .n2_field_control_type_picker__item:hover {
    box-shadow: 0 2px 10px 0 rgba(0, 0, 0, 0.1); }
  .n2_field_control_type_picker__item.n2_field_control_type_picker__item--selected {
    box-shadow: 0 0 0 3px #1375E9; }

.n2_field_control_type_picker__selected_marker {
  display: none;
  position: absolute;
  top: 10px;
  right: 10px;
  background-color: #1375E9;
  border-radius: 10px;
  width: 16px;
  height: 16px; }
  .n2_field_control_type_picker__item--selected .n2_field_control_type_picker__selected_marker {
    display: block; }
  .n2_field_control_type_picker__selected_marker .ssi_16 {
    color: #FFFFFF; }

.n2_field_message {
  border-radius: 3px;
  padding: 5px 10px;
  font-size: 12px;
  line-height: 20px; }

.n2_field_message--notice {
  background-color: #F0F4F7;
  color: #325C77; }
  .n2_field_message--notice a:HOVER {
    color: #005BC6; }
  .n2_field_message--notice a, .n2_field_message--notice a:FOCUS {
    color: #1375E9; }

.n2_field_message--warning {
  background-color: #F5E293;
  color: #325C77; }
  .n2_field_message--warning a:HOVER {
    color: #005BC6; }
  .n2_field_message--warning a, .n2_field_message--warning a:FOCUS {
    color: #1375E9; }
  .n2_ss_layer_window .n2_field_message--warning {
    width: 298px; }

.n2_field_autocomplete {
  position: relative; }

.n2_field_decoration {
  display: inline-flex;
  vertical-align: top;
  margin: 0 -3px; }

.n2_field_decoration__option {
  margin: 0 3px;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 30px;
  height: 30px;
  background-color: #94B2C1;
  border-radius: 3px;
  color: #fff;
  font-size: 16px;
  cursor: pointer; }
  .n2_form--dark .n2_field_decoration__option {
    background-color: #1C2933;
    color: #94B2C1; }

.n2_field_decoration__option--selected {
  background-color: #1D81F9; }
  .n2_form--dark .n2_field_decoration__option--selected {
    background-color: #1D81F9;
    color: #fff; }

.n2_field_icon__preview {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 30px;
  height: 30px; }
  .n2_field_icon__preview .n2i {
    color: #fff;
    font-size: 24px !important;
    vertical-align: top; }

.n2_field_icon_tab {
  background-color: #1C2933;
  border-radius: 2px;
  overflow: hidden;
  white-space: nowrap; }

.n2_field_icon_tab__option {
  display: inline-flex;
  padding: 7px;
  color: #fff;
  cursor: pointer; }
  .n2_field_icon_tab__option i {
    color: #94b2c1; }

.n2_field_icon_tab__option--selected {
  background-color: #1D81F9; }
  .n2_field_icon_tab__option--selected i {
    color: #ffffff; }

.n2_field_mixed_font_size__container > .n2_field_text {
  border-top-right-radius: 0;
  border-bottom-right-radius: 0; }
  html[dir="rtl"] .n2_field_mixed_font_size__container > .n2_field_text {
    border-radius: 0 3px 3px 0; }

.n2_field_mixed_font_size__container > .n2_field_unit > .n2_field_unit__current_unit {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0; }
  html[dir="rtl"] .n2_field_mixed_font_size__container > .n2_field_unit > .n2_field_unit__current_unit {
    border-radius: 3px 0 0 3px; }

.n2_field_mixed_box_shadow__container > .n2_field_text {
  margin-left: -2px;
  border-radius: 0; }
  html[dir="rtl"] .n2_field_mixed_box_shadow__container > .n2_field_text {
    margin-left: 0;
    margin-right: -2px; }
  .n2_field_mixed_box_shadow__container > .n2_field_text:first-child {
    margin-left: 0;
    border-top-left-radius: 3px;
    border-bottom-left-radius: 3px; }
    html[dir="rtl"] .n2_field_mixed_box_shadow__container > .n2_field_text:first-child {
      margin-right: 0;
      border-radius: 0 3px 3px 0; }
  .n2_field_mixed_box_shadow__container > .n2_field_text:last-of-type {
    border-top-right-radius: 3px;
    border-bottom-right-radius: 3px; }
    html[dir="rtl"] .n2_field_mixed_box_shadow__container > .n2_field_text:last-of-type {
      border-radius: 3px 0 0 3px; }

.n2_field_mixed_box_shadow__container > .n2_field_text--focus {
  z-index: 2; }

.n2_field_mixed_text_shadow__container > .n2_field_text {
  margin-left: -2px; }
  .n2_field_mixed_text_shadow__container > .n2_field_text:first-child {
    margin-left: 0;
    border-radius: 3px 0 0 3px; }
    html[dir="rtl"] .n2_field_mixed_text_shadow__container > .n2_field_text:first-child {
      margin-left: -2px;
      border-radius: 0 3px 3px 0; }
  .n2_field_mixed_text_shadow__container > .n2_field_text:last-child {
    border-radius: 0 3px 3px 0; }
    html[dir="rtl"] .n2_field_mixed_text_shadow__container > .n2_field_text:last-child {
      border-radius: 3px 0 0 3px; }

.n2_field_mixed_text_shadow__container > .n2_field_text--focus {
  z-index: 2; }

.n2_field_mixed_border__container {
  display: inline-flex;
  vertical-align: top;
  margin: 0 -5px; }
  .n2_field_mixed_border__container > * {
    margin: 0 5px; }

.n2_form__table_row .n2_field.n2_field_mixed_generator_order {
  padding: 0; }

.n2_field_button {
  display: inline-block;
  text-align: center;
  padding: 0 10px;
  background-color: #94b2c1;
  font-size: 11px;
  line-height: 30px;
  text-transform: uppercase;
  border-radius: 3px;
  max-width: 150px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }
  .n2_field_button:HOVER {
    background-color: #7F9CAA; }
  .n2_field_button, .n2_field_button:HOVER, .n2_field_button:FOCUS {
    color: #FFFFFF; }
  .n2_form--dark .n2_field_button {
    background-color: #6B7986; }
    .n2_form--dark .n2_field_button:HOVER {
      background-color: #8694A2; }
    .n2_form--dark .n2_field_button, .n2_form--dark .n2_field_button:HOVER, .n2_form--dark .n2_field_button:FOCUS {
      color: #FFFFFF; }

.n2_field_button--icon {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  padding: 0;
  width: 30px;
  height: 30px;
  font-size: 16px; }

.n2_field_button--blue {
  background-color: #1D81F9; }
  .n2_field_button--blue:HOVER {
    background-color: #338EF9; }

.n2_field_widget_area {
  width: 80px;
  height: 80px;
  position: relative;
  margin: 0 10px; }

.n2_field_widget_area__inner {
  position: absolute;
  top: 14px;
  left: 14px;
  width: 46px;
  height: 46px;
  border: 3px solid #94b2c1;
  border-radius: 3px; }

.n2_field_widget_area__area {
  position: absolute;
  background-color: #94b2c1;
  border-radius: 2px;
  cursor: pointer;
  width: 10px;
  height: 10px;
  left: 0;
  top: 0; }
  .n2_field_widget_area__area[data-area="1"] {
    left: 35px; }
  .n2_field_widget_area__area[data-area="2"] {
    left: 21px;
    top: 21px; }
  .n2_field_widget_area__area[data-area="3"] {
    left: 35px;
    top: 21px; }
  .n2_field_widget_area__area[data-area="4"] {
    left: 49px;
    top: 21px; }
  .n2_field_widget_area__area[data-area="5"] {
    top: 35px; }
  .n2_field_widget_area__area[data-area="6"] {
    left: 21px;
    top: 35px; }
  .n2_field_widget_area__area[data-area="7"] {
    left: 49px;
    top: 35px; }
  .n2_field_widget_area__area[data-area="8"] {
    left: 70px;
    top: 35px; }
  .n2_field_widget_area__area[data-area="9"] {
    left: 21px;
    top: 49px; }
  .n2_field_widget_area__area[data-area="10"] {
    left: 35px;
    top: 49px; }
  .n2_field_widget_area__area[data-area="11"] {
    left: 49px;
    top: 49px; }
  .n2_field_widget_area__area[data-area="12"] {
    left: 35px;
    top: 70px; }

.n2_field_widget_area__area--selected {
  background-color: #1d81f9;
  cursor: default; }

.n2_field_columns {
  display: grid;
  grid-gap: 10px;
  grid-template-columns: 280px 30px;
  width: 310px; }

.n2_field_columns__content {
  position: relative;
  display: flex;
  overflow: hidden; }

.n2_field_columns__column {
  flex: 0 0 auto;
  overflow: hidden;
  background-color: #04C018;
  border-radius: 2px;
  font-size: 12px;
  line-height: 30px;
  text-align: center;
  color: #FFFFFF;
  cursor: ew-resize; }

.n2_field_columns__handle {
  display: inline-flex;
  justify-content: center;
  align-items: center;
  width: 16px;
  height: 30px;
  cursor: ew-resize;
  color: #BDCFD9; }

.n2_field_columns__content.n2-sortable-currently-sorted .n2_field_columns__column {
  margin-right: 16px; }
  .n2_field_columns__content.n2-sortable-currently-sorted .n2_field_columns__column:last-child {
    margin-right: 0; }

.n2_field_columns__content.n2-sortable-currently-sorted .n2_field_columns__handle {
  display: none; }

.n2_field_columns__add {
  flex: 0 0 auto;
  display: inline-flex;
  justify-content: center;
  align-items: center;
  width: 30px;
  height: 30px;
  background-color: #04C018;
  border-radius: 2px;
  color: #fff;
  cursor: pointer; }
  .n2_field_columns__add:HOVER {
    background-color: #07CA1C; }

.n2_field_select_list {
  height: 120px;
  background-color: #FFFFFF;
  border: 2px solid #94B2C1;
  border-radius: 3px;
  overflow-y: scroll; }

.n2_field_select_list__option {
  display: flex;
  cursor: pointer;
  line-height: 30px;
  font-size: 12px;
  color: #325C77; }

.n2_field_select_list__option:nth-child(even) {
  background-color: #F0F4F7; }

.n2_field_select_list__option.n2_field_select_list__option--selected {
  background-color: #1D81F9;
  color: #fff; }

.n2_field_select_list__option_primary {
  flex: 1 1 auto;
  padding: 0 8px; }

.n2_field_select_list__option_secondary {
  padding: 0 8px; }

.n2_field_chooser {
  position: relative;
  display: inline-flex;
  vertical-align: top;
  border-radius: 3px;
  background-color: #F0F4F7;
  height: 30px; }
  .n2_form--dark .n2_field_chooser {
    background-color: #2c3a45; }

.n2_field_chooser__label {
  min-width: 100px;
  padding: 0 8px;
  font-size: 12px;
  line-height: 30px;
  color: #325C77;
  cursor: pointer;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }
  .n2_form--dark .n2_field_chooser__label {
    color: #bdcfd9; }

.n2_field_chooser__clear {
  display: flex;
  line-height: 30px;
  width: 30px;
  justify-content: center;
  align-items: center; }
  .n2_field_chooser__clear, .n2_field_chooser__clear:HOVER, .n2_field_chooser__clear:FOCUS {
    color: #94B2C1; }
  .n2_field_chooser--empty .n2_field_chooser__clear {
    visibility: hidden; }

.n2_field_chooser__choose {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  background-color: #04C018;
  width: 30px;
  line-height: 30px;
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px; }
  .n2_field_chooser__choose:HOVER {
    background-color: #07CA1C; }
  .n2_field_chooser__choose, .n2_field_chooser__choose:HOVER, .n2_field_chooser__choose:FOCUS {
    color: #FFFFFF; }
  .n2_field_chooser--empty .n2_field_chooser__choose {
    background-color: #94B2C1; }
    .n2_form--dark .n2_field_chooser--empty .n2_field_chooser__choose {
      background-color: #1C2933; }
      .n2_form--dark .n2_field_chooser--empty .n2_field_chooser__choose, .n2_form--dark .n2_field_chooser--empty .n2_field_chooser__choose:HOVER, .n2_form--dark .n2_field_chooser--empty .n2_field_chooser__choose:FOCUS {
        color: #94B2C1; }
  html[dir="rtl"] .n2_field_chooser__choose {
    border-radius: 3px 0 0 3px; }

.n2_field_select_icon {
  display: flex;
  flex-wrap: wrap;
  margin: -10px -20px; }

.n2_field_select_icon__option {
  position: relative;
  display: flex;
  flex-flow: column;
  margin: 20px;
  width: 130px;
  padding: 15px 10px;
  cursor: pointer;
  border-radius: 3px; }
  .n2_field_select_icon__option:HOVER {
    box-shadow: 0 2px 10px 0 rgba(0, 0, 0, 0.1); }

.n2_field_select_icon__option--selected {
  box-shadow: 0 2px 10px 0 rgba(0, 0, 0, 0.1); }

.n2_field_select_icon__option_icon {
  display: flex;
  align-items: center;
  justify-content: center;
  color: #94B2C1; }
  .n2_field_select_icon__option--selected .n2_field_select_icon__option_icon {
    color: #1375E9; }

.n2_field_select_icon__option_label {
  font-size: 14px;
  line-height: 30px;
  color: #325C77;
  text-align: center;
  font-weight: bold; }
  .n2_field_select_icon__option--selected .n2_field_select_icon__option_label {
    color: #1375E9; }

.n2_field_select_icon__selected_marker {
  display: none;
  position: absolute;
  top: 10px;
  right: 10px;
  background-color: #1375E9;
  border-radius: 10px;
  width: 16px;
  height: 16px;
  color: #fff; }
  .n2_field_select_icon__option--selected .n2_field_select_icon__selected_marker {
    display: block; }

.n2_field_font {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  background-color: #04c018;
  min-width: 30px;
  line-height: 30px;
  border-radius: 3px;
  padding: 0 10px;
  font-size: 11px;
  text-transform: uppercase;
  cursor: pointer; }
  .n2_field_font:HOVER {
    background-color: #07CA1C; }
  .n2_field_font, .n2_field_font:HOVER, .n2_field_font:FOCUS {
    color: #FFFFFF; }

.n2_field_style {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  background-color: #04c018;
  min-width: 30px;
  line-height: 30px;
  border-radius: 3px;
  padding: 0 10px;
  font-size: 11px;
  text-transform: uppercase;
  cursor: pointer; }
  .n2_field_style:HOVER {
    background-color: #07CA1C; }
  .n2_field_style, .n2_field_style:HOVER, .n2_field_style:FOCUS {
    color: #FFFFFF; }

.n2_field_subform_icon {
  margin: -8px;
  display: flex;
  flex-wrap: wrap; }

.n2_field_subform_icon__option {
  margin: 8px;
  display: flex;
  flex-flow: column;
  align-items: center;
  min-width: 120px;
  border: 3px solid #fff;
  border-radius: 3px;
  cursor: pointer; }

.n2_field_subform_icon__option_icon {
  display: flex;
  align-items: center;
  justify-content: center;
  color: #94B2C1; }

.n2_field_subform_icon__option_label {
  margin-top: -13px;
  line-height: 28px;
  font-size: 12px;
  color: #325C77;
  font-weight: bold;
  padding: 0 10px; }

.n2_field_subform_icon__option--selected {
  border-color: #1375E9; }
  .n2_field_subform_icon__option--selected .n2_field_subform_icon__option_icon,
  .n2_field_subform_icon__option--selected .n2_field_subform_icon__option_label {
    color: #1375E9; }

.n2_field_autoplaypicker {
  position: relative;
  display: inline-flex;
  vertical-align: top;
  background-color: #fff;
  border: 2px solid #94b2c1;
  border-radius: 3px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.n2_field_autoplaypicker--focus {
  border-color: #1D81F9;
  z-index: 99; }

.n2_field_autoplaypicker__label {
  display: inline-block;
  vertical-align: top;
  padding: 0 6px;
  width: 230px;
  line-height: 26px;
  font-size: 12px;
  color: #325c77;
  cursor: pointer; }

.n2_field_autoplaypicker__arrow {
  width: 18px;
  line-height: 26px;
  font-size: 12px;
  color: #325c77;
  text-align: center;
  cursor: pointer; }

.n2_field_autoplaypicker__popover {
  display: none;
  position: absolute;
  top: 30px;
  padding: 10px;
  border-radius: 3px;
  background-color: #FFFFFF;
  box-shadow: 0 1px 5px 1px rgba(55, 77, 88, 0.2); }
  .n2_field_autoplaypicker--focus .n2_field_autoplaypicker__popover {
    display: flex; }
  .n2_field_autoplaypicker__popover .n2_field__element {
    flex-wrap: nowrap !important; }

.n2_field_layer_window_focus {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  position: relative;
  cursor: pointer;
  background: #1c2933;
  border: 2px solid #1c2933;
  border-radius: 3px; }

.n2_field_layer_window_focus__image {
  display: block;
  width: 100%;
  height: auto;
  border-radius: 2px; }

.n2_field_layer_window_focus__dot {
  position: absolute;
  left: 50%;
  top: 50%;
  width: 12px;
  height: 12px;
  margin-top: -8px;
  margin-left: -8px;
  border: 2px solid #fff;
  border-radius: 16px;
  background: #04c018; }

.n2_field_breakpoint {
  display: flex;
  flex-wrap: wrap; }

.n2_field_breakpoint__breakpoint_container {
  position: relative;
  margin: 25px 10px 5px;
  height: 30px;
  display: flex;
  align-items: center;
  background-color: #94B2C1;
  border-radius: 3px; }
  .n2_field_breakpoint__breakpoint_container[data-orientation="portrait"] [data-orientation="landscape"] {
    display: none !important; }
  .n2_field_breakpoint__breakpoint_container[data-orientation="landscape"] [data-orientation="portrait"] {
    display: none !important; }

.n2_field_breakpoint__device {
  position: relative;
  flex: 0 0 auto;
  width: 130px;
  text-align: center;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.n2_field_breakpoint__device_enable {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 100%;
  height: 30px;
  color: #fff; }

.n2_field_breakpoint__device_disable {
  position: absolute;
  right: 5px;
  top: 0;
  color: #fff;
  height: 30px;
  display: none;
  align-items: center;
  opacity: 0.5;
  cursor: pointer; }
  .n2_field_breakpoint__device_disable:HOVER {
    opacity: 1; }
  .n2_field_breakpoint__device--enabled .n2_field_breakpoint__device_disable {
    display: flex; }

.n2_field_breakpoint__breakpoint {
  position: relative;
  flex: 0 0 auto;
  height: 30px; }

.n2_field_breakpoint__breakpoint_divider {
  margin: 5px 0;
  width: 0;
  height: 20px;
  box-shadow: 0 0 0 1px #fff; }

.n2_field_breakpoint__breakpoint_label_container {
  display: flex;
  align-items: center;
  justify-content: center;
  position: absolute;
  margin-left: -32px;
  top: -26px;
  width: 50px; }
  html[dir="rtl"] .n2_field_breakpoint__breakpoint_label_container {
    margin-left: 0;
    margin-right: -32px; }
  .n2_field_breakpoint__breakpoint_start .n2_field_breakpoint__breakpoint_label_container {
    margin-left: 0;
    justify-content: flex-start; }
    html[dir="rtl"] .n2_field_breakpoint__breakpoint_start .n2_field_breakpoint__breakpoint_label_container {
      margin-right: 0; }
  .n2_field_breakpoint__breakpoint_end .n2_field_breakpoint__breakpoint_label_container {
    margin-left: -50px;
    justify-content: flex-end; }
    html[dir="rtl"] .n2_field_breakpoint__breakpoint_end .n2_field_breakpoint__breakpoint_label_container {
      margin-left: 0;
      margin-right: -50px; }

.n2_field_breakpoint__breakpoint_label_rename {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 12px;
  cursor: pointer;
  color: #94B2C1;
  opacity: 0.7; }
  .n2_field_breakpoint__breakpoint_label_rename:HOVER {
    opacity: 1; }
  .n2_field_breakpoint__breakpoint_label_container--disable-edit .n2_field_breakpoint__breakpoint_label_rename {
    visibility: hidden;
    pointer-events: none; }

.n2_field_breakpoint__breakpoint_label {
  color: #325C77;
  font-size: 12px;
  line-height: 26px; }
  .n2_field_breakpoint__breakpoint_start .n2_field_breakpoint__breakpoint_label,
  .n2_field_breakpoint__breakpoint_end .n2_field_breakpoint__breakpoint_label {
    cursor: default; }
  .n2_field_breakpoint__breakpoint .n2_field_breakpoint__breakpoint_label {
    cursor: default; }
    .n2_field_breakpoint__breakpoint .n2_field_breakpoint__breakpoint_label[contenteditable=true] {
      cursor: text;
      outline: 0; }

.n2_field_breakpoint--with-enables .n2_field_breakpoint__device .n2_field_breakpoint__device_enable {
  cursor: pointer;
  opacity: 0.5; }

.n2_field_breakpoint--with-enables .n2_field_breakpoint__device--enabled .n2_field_breakpoint__device_enable {
  opacity: 1; }

.n2_field_breakpoint--with-enables .n2_field_breakpoint__device[data-id="desktopportrait"] .n2_field_breakpoint__device_enable,
.n2_field_breakpoint--with-enables .n2_field_breakpoint__device[data-id="tabletportrait"] .n2_field_breakpoint__device_enable,
.n2_field_breakpoint--with-enables .n2_field_breakpoint__device[data-id="mobileportrait"] .n2_field_breakpoint__device_enable {
  cursor: default;
  opacity: 1; }

.n2_field_breakpoint--with-enables .n2_field_breakpoint__breakpoint {
  display: none; }

.n2_field_breakpoint--with-enables .n2_field_breakpoint__breakpoint--enabled,
.n2_field_breakpoint--with-enables .n2_field_breakpoint__breakpoint[data-id="desktopportrait"],
.n2_field_breakpoint--with-enables .n2_field_breakpoint__breakpoint[data-id="tabletportrait"],
.n2_field_breakpoint--with-enables .n2_field_breakpoint__breakpoint[data-id="mobileportrait"] {
  display: block; }

body[data-desktoplandscape="0"] .n2-slider-settings-require--desktoplandscape,
body[data-tabletlandscape="0"] .n2-slider-settings-require--tabletlandscape,
body[data-mobilelandscape="0"] .n2-slider-settings-require--mobilelandscape {
  display: none !important; }

.n2_autocomplete_options {
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  line-height: 1.3;
  font-size: 16px;
  -webkit-font-smoothing: antialiased;
  position: absolute;
  top: 0;
  z-index: 100003;
  overflow: auto;
  max-height: 300px;
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  background: #fff;
  box-shadow: 0 1px 5px 1px rgba(55, 77, 88, 0.2); }
  .n2_autocomplete_options a {
    transition: none 0s;
    text-decoration: none;
    box-shadow: none; }

.n2_autocomplete_option {
  padding: 0 5px;
  line-height: 24px;
  cursor: pointer;
  color: #325C77;
  font-size: 11px; }
  .n2_autocomplete_option:HOVER {
    background: #1D81F9;
    color: #FFF; }

.n2_tooltip {
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  line-height: 1.3;
  font-size: 16px;
  -webkit-font-smoothing: antialiased;
  visibility: visible;
  z-index: 100000;
  position: fixed;
  left: -10000px;
  top: -10000px;
  margin-top: -9000000px;
  opacity: 0;
  border-radius: 3px;
  font-size: 12px;
  line-height: 16px;
  font-weight: bold;
  padding: 4px 6px;
  color: #94B2C1;
  background: #0c1924;
  white-space: nowrap; }
  .n2_tooltip a {
    transition: none 0s;
    text-decoration: none;
    box-shadow: none; }

.n2_tooltip--active {
  opacity: 1;
  margin: 10px; }
  .n2_tooltip--active.n2_tooltip_position {
    margin: 0; }

.n2_body--tooltip-position-active .n2_tooltip:not(.n2_tooltip_position) {
  display: none; }

.n2_form_tip {
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  line-height: 1.3;
  font-size: 16px;
  -webkit-font-smoothing: antialiased;
  z-index: 100000;
  position: fixed;
  display: none;
  max-width: 360px;
  padding: 5px 0; }
  .n2_form_tip a {
    transition: none 0s;
    text-decoration: none;
    box-shadow: none; }

.n2_form_tip--visible {
  display: block; }

.n2_form_tip__overlay {
  position: absolute;
  width: 20px;
  height: 20px; }
  .n2_form_tip[data-position-horizontal="left"] .n2_form_tip__overlay {
    left: 0; }
  .n2_form_tip[data-position-horizontal="right"] .n2_form_tip__overlay {
    right: 0; }
  .n2_form_tip[data-position-vertical="bottom"] .n2_form_tip__overlay {
    top: 100%; }
  .n2_form_tip[data-position-vertical="top"] .n2_form_tip__overlay {
    bottom: 100%; }

.n2_form_tip__content {
  background-color: rgba(12, 25, 36, 0.95);
  border-radius: 5px;
  padding: 20px; }

.n2_form_tip__label {
  color: #FFFFFF;
  font-size: 14px;
  line-height: 20px;
  text-transform: capitalize;
  margin-bottom: 10px; }

.n2_form_tip__description {
  color: #94B2C1;
  font-size: 14px;
  line-height: 20px; }
  .n2_form_tip__description a,
  .n2_form_tip__description a:HOVER,
  .n2_form_tip__description a:FOCUS {
    color: #1D81F9; }

.n2_form_tip__link {
  margin-top: 10px;
  display: inline-block;
  line-height: 30px;
  background-color: #1D81F9;
  border-radius: 3px;
  padding: 0 10px;
  font-size: 11px;
  text-transform: capitalize;
  text-decoration: none; }
  .n2_form_tip__link, .n2_form_tip__link:HOVER, .n2_form_tip__link:FOCUS {
    color: #FFFFFF; }

.n2_dashboard_info {
  position: relative; }
  .n2_dashboard_info .n2_button_plain_icon {
    position: relative; }

.n2_dashboard_info--visible .n2_button_plain_icon, .n2_dashboard_info--visible .n2_button_plain_icon:HOVER, .n2_dashboard_info--visible .n2_button_plain_icon:FOCUS {
  color: #fff; }

.n2_dashboard_info__marker {
  display: none;
  position: absolute;
  top: 7px;
  right: 8px;
  width: 8px;
  height: 8px;
  background-color: #F69300;
  border-radius: 100%;
  border: 2px solid #FFFFFF; }
  html[data-ss3-activated="0"] .n2_dashboard_info__marker {
    display: block; }

.n2_dashboard_info__content {
  display: none;
  position: absolute;
  right: 0;
  top: 45px;
  padding: 24px;
  border-radius: 3px;
  background-color: #fff;
  box-shadow: 0 1px 5px 1px rgba(55, 77, 88, 0.2);
  white-space: nowrap; }
  .n2_dashboard_info--visible .n2_dashboard_info__content {
    display: grid;
    grid-template-columns: 24px 1fr auto;
    grid-gap: 15px; }
  html[dir="rtl"] .n2_dashboard_info__content {
    left: 0;
    right: auto; }

.n2_dashboard_info__row_icon .ssi_24 {
  display: block;
  font-size: 24px;
  line-height: 30px; }

.n2_dashboard_info__row_content {
  color: #325C77;
  line-height: 30px;
  font-size: 14px; }

.n2_dashboard_info__row_action {
  text-align: right; }
  .n2_dashboard_info__row_action a, .n2_dashboard_info__row_action a:HOVER, .n2_dashboard_info__row_action a:FOCUS {
    line-height: 30px;
    font-size: 14px; }
  .n2_dashboard_info__row_action a, .n2_dashboard_info__row_action a:FOCUS {
    color: #1375E9; }
  .n2_dashboard_info__row_action a:HOVER {
    color: #005BC6; }
  html[dir="rtl"] .n2_dashboard_info__row_action {
    text-align: left; }

html[data-ss3-activated="0"] .n2_dashboard_info__row_icon_activated,
html[data-ss3-activated="0"] .n2_dashboard_info__row_content_activated,
html[data-ss3-activated="0"] .n2_dashboard_info__row_action_activated {
  display: none; }

html[data-ss3-activated="1"] .n2_dashboard_info__row_icon_activate,
html[data-ss3-activated="1"] .n2_dashboard_info__row_content_activate,
html[data-ss3-activated="1"] .n2_dashboard_info__row_action_activate,
html[data-ss3-activated="1"] #n2-ss-activate-license-banner {
  display: none; }

.n2_dashboard_info__row_icon_version .ssi_24 {
  color: #94B2C1; }

.n2_dashboard_info__row_icon_check_update .ssi_24 {
  color: #1D81F9; }

.n2_dashboard_info__row_icon_activate .ssi_24 {
  color: #C43E2A; }

.n2_dashboard_info__row_icon_activated .ssi_24 {
  color: #04C018; }

.n2_dashboard_manager {
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  padding: 0 40px; }

.n2_dashboard_manager__content {
  position: relative;
  display: flex;
  flex-wrap: wrap;
  margin: 0 -16px; }
  .n2_dashboard_manager__content > * {
    margin: 16px;
    flex: 0 0 auto; }

.n2_dashboard_manager_upgrade_pro {
  position: relative;
  display: flex;
  flex-flow: column;
  align-items: center;
  width: 572px;
  min-height: 392px;
  background-color: #FFFFFF;
  border-radius: 5px;
  box-shadow: 0 10px 8px -10px rgba(0, 0, 0, 0.1); }
  .n2_dashboard_manager_upgrade_pro:HOVER {
    box-shadow: 0 10px 8px -10px rgba(0, 0, 0, 0.2); }

.n2_dashboard_manager_upgrade_pro__logo {
  margin-top: 44px;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100px;
  height: 100px;
  background-color: rgba(29, 129, 249, 0.1);
  border-radius: 50px;
  color: #1D81F9; }

.n2_dashboard_manager_upgrade_pro__heading {
  margin-top: 9px;
  font-size: 18px;
  line-height: 30px;
  color: #283F4D;
  font-weight: bold; }

.n2_dashboard_manager_upgrade_pro__details {
  margin-top: 8px;
  display: grid;
  grid-template-columns: 1fr 1fr;
  grid-gap: 14px;
  width: 100%;
  padding: 0 30px 14px;
  box-sizing: border-box; }

.n2_dashboard_manager_upgrade_pro__details_option {
  display: flex;
  align-items: center; }
  .n2_dashboard_manager_upgrade_pro__details_option, .n2_dashboard_manager_upgrade_pro__details_option:HOVER, .n2_dashboard_manager_upgrade_pro__details_option:FOCUS {
    color: #1375E9; }

.n2_dashboard_manager_upgrade_pro__details_option_label {
  margin: 0 10px;
  font-size: 14px;
  line-height: 16px;
  text-transform: capitalize;
  padding: 5px 0; }

.n2_dashboard_manager_upgrade_pro__button {
  margin-top: 4px;
  margin-bottom: 20px;
  padding: 0 20px;
  min-width: 260px;
  background-color: #1D81F9;
  border-radius: 3px;
  text-align: center;
  font-size: 12px;
  line-height: 36px;
  text-transform: uppercase;
  font-weight: bold; }
  .n2_dashboard_manager_upgrade_pro__button, .n2_dashboard_manager_upgrade_pro__button:HOVER, .n2_dashboard_manager_upgrade_pro__button:FOCUS {
    color: #FFFFFF; }
  .n2_dashboard_manager_upgrade_pro__button:HOVER {
    background-color: #338ef9; }

.n2_dashboard_manager_upgrade_pro__close {
  display: flex;
  position: absolute;
  top: 10px;
  right: 10px;
  width: 36px;
  height: 36px;
  justify-content: center;
  align-items: center;
  background-color: #F0F4F7;
  border-radius: 50px;
  color: #325C77;
  cursor: pointer;
  opacity: 0;
  transition: opacity 0.3s 0.5s; }
  .n2_dashboard_manager_upgrade_pro:HOVER .n2_dashboard_manager_upgrade_pro__close {
    opacity: 1; }

.n2_dashboard_manager_review {
  position: relative;
  display: flex;
  flex-flow: column;
  align-items: center;
  width: 572px;
  height: 392px;
  background-color: #FFFFFF;
  border-radius: 5px;
  box-shadow: 0 10px 8px -10px rgba(0, 0, 0, 0.1); }
  .n2_dashboard_manager_review:HOVER {
    box-shadow: 0 10px 8px -10px rgba(0, 0, 0, 0.2); }

.n2_dashboard_manager_review__logo {
  display: flex;
  align-items: center;
  justify-content: center;
  margin-top: 44px;
  width: 100px;
  height: 100px;
  background-color: rgba(246, 183, 0, 0.1);
  border-radius: 50px;
  overflow: hidden;
  color: #F6B700; }
  .n2_dashboard_manager_review__logo > * {
    display: none; }

.n2_dashboard_manager_review[data-star="0"] .ssi_48--review0,
.n2_dashboard_manager_review[data-star="1"] .ssi_48--review1,
.n2_dashboard_manager_review[data-star="2"] .ssi_48--review2,
.n2_dashboard_manager_review[data-star="3"] .ssi_48--review3,
.n2_dashboard_manager_review[data-star="4"] .ssi_48--review4,
.n2_dashboard_manager_review[data-star="5"] .ssi_48--review5 {
  display: block; }

.n2_dashboard_manager_review__heading {
  margin-top: 9px;
  font-size: 18px;
  line-height: 30px;
  color: #283F4D;
  font-weight: bold; }

.n2_dashboard_manager_review__paragraph {
  width: 380px;
  height: 78px;
  color: #325C77;
  font-size: 14px;
  line-height: 26px;
  text-align: center; }

.n2_dashboard_manager_review__star_selector {
  margin-top: 25px;
  display: flex; }

.n2_dashboard_manager_review__star {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 34px;
  height: 34px;
  color: #94B2C1;
  cursor: pointer; }

.n2_dashboard_manager_review[data-star="1"] .n2_dashboard_manager_review__star[data-star="1"],
.n2_dashboard_manager_review[data-star="2"] .n2_dashboard_manager_review__star[data-star="1"],
.n2_dashboard_manager_review[data-star="2"] .n2_dashboard_manager_review__star[data-star="2"],
.n2_dashboard_manager_review[data-star="3"] .n2_dashboard_manager_review__star[data-star="1"],
.n2_dashboard_manager_review[data-star="3"] .n2_dashboard_manager_review__star[data-star="2"],
.n2_dashboard_manager_review[data-star="3"] .n2_dashboard_manager_review__star[data-star="3"],
.n2_dashboard_manager_review[data-star="4"] .n2_dashboard_manager_review__star[data-star="1"],
.n2_dashboard_manager_review[data-star="4"] .n2_dashboard_manager_review__star[data-star="2"],
.n2_dashboard_manager_review[data-star="4"] .n2_dashboard_manager_review__star[data-star="3"],
.n2_dashboard_manager_review[data-star="4"] .n2_dashboard_manager_review__star[data-star="4"],
.n2_dashboard_manager_review[data-star="5"] .n2_dashboard_manager_review__star[data-star="1"],
.n2_dashboard_manager_review[data-star="5"] .n2_dashboard_manager_review__star[data-star="2"],
.n2_dashboard_manager_review[data-star="5"] .n2_dashboard_manager_review__star[data-star="3"],
.n2_dashboard_manager_review[data-star="5"] .n2_dashboard_manager_review__star[data-star="4"],
.n2_dashboard_manager_review[data-star="5"] .n2_dashboard_manager_review__star[data-star="5"] {
  color: #F6B700; }

.n2_dashboard_manager_review__label {
  display: none;
  margin-top: 4px;
  font-size: 16px;
  line-height: 28px;
  color: #283F4D;
  text-align: center;
  font-weight: bold; }

.n2_dashboard_manager_review[data-star="0"] .n2_dashboard_manager_review__label[data-star="0"],
.n2_dashboard_manager_review[data-star="1"] .n2_dashboard_manager_review__label[data-star="1"],
.n2_dashboard_manager_review[data-star="2"] .n2_dashboard_manager_review__label[data-star="2"],
.n2_dashboard_manager_review[data-star="3"] .n2_dashboard_manager_review__label[data-star="3"],
.n2_dashboard_manager_review[data-star="4"] .n2_dashboard_manager_review__label[data-star="4"],
.n2_dashboard_manager_review[data-star="5"] .n2_dashboard_manager_review__label[data-star="5"] {
  display: block; }

.n2_dashboard_manager_review__close {
  display: flex;
  position: absolute;
  top: 10px;
  right: 10px;
  width: 36px;
  height: 36px;
  justify-content: center;
  align-items: center;
  background-color: #F0F4F7;
  border-radius: 50px;
  color: #325C77;
  cursor: pointer;
  opacity: 0;
  transition: opacity 0.3s 0.5s; }
  html[dir="rtl"] .n2_dashboard_manager_review__close {
    right: auto;
    left: 10px; }
  .n2_dashboard_manager_review:HOVER .n2_dashboard_manager_review__close {
    opacity: 1; }

.n2_dashboard_manager_newsletter {
  position: relative;
  display: flex;
  flex-flow: column;
  align-items: center;
  width: 572px;
  height: 392px;
  background-color: #FFFFFF;
  border-radius: 5px;
  box-shadow: 0 10px 8px -10px rgba(0, 0, 0, 0.1); }
  .n2_dashboard_manager_newsletter:HOVER {
    box-shadow: 0 10px 8px -10px rgba(0, 0, 0, 0.2); }

.n2_dashboard_manager_newsletter__logo {
  margin-top: 44px;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100px;
  height: 100px;
  background-color: rgba(95, 57, 194, 0.1);
  border-radius: 50px;
  color: #5F39C2; }

.n2_dashboard_manager_newsletter__heading {
  margin-top: 9px;
  font-size: 18px;
  line-height: 30px;
  color: #283F4D;
  font-weight: bold; }

.n2_dashboard_newsletter__paragraph {
  width: 380px;
  height: 78px;
  color: #325C77;
  font-size: 14px;
  line-height: 26px;
  text-align: center; }

.n2_dashboard_newsletter__form {
  margin-top: 10px;
  display: block; }

.n2_dashboard_newsletter__form input[type=email] {
  width: 300px;
  background-color: #FFFFFF;
  border: 2px solid #94B2C1;
  border-radius: 3px;
  color: #325C77;
  font-size: 14px;
  line-height: 36px;
  text-align: center;
  box-shadow: none; }
  .n2_dashboard_newsletter__form input[type=email]:FOCUS {
    border-color: #5F39C2; }

.n2_dashboard_manager_newsletter__button {
  margin-top: 10px;
  padding: 0 20px;
  min-width: 260px;
  background-color: #5F39C2;
  border-radius: 3px;
  text-align: center;
  font-size: 12px;
  line-height: 36px;
  text-transform: uppercase;
  font-weight: bold;
  cursor: pointer; }
  .n2_dashboard_manager_newsletter__button, .n2_dashboard_manager_newsletter__button:HOVER, .n2_dashboard_manager_newsletter__button:FOCUS {
    color: #FFFFFF; }
  .n2_dashboard_manager_newsletter__button:HOVER {
    background-color: #683fd4; }

.n2_dashboard_manager_newsletter__close {
  display: flex;
  position: absolute;
  top: 10px;
  right: 10px;
  width: 36px;
  height: 36px;
  justify-content: center;
  align-items: center;
  background-color: #F0F4F7;
  border-radius: 50px;
  color: #325C77;
  cursor: pointer;
  opacity: 0;
  transition: opacity 0.3s 0.5s; }
  html[dir="rtl"] .n2_dashboard_manager_newsletter__close {
    right: auto;
    left: 10px; }
  .n2_dashboard_manager_newsletter:HOVER .n2_dashboard_manager_newsletter__close {
    opacity: 1; }

.n2_device_changer {
  display: inline-flex;
  align-items: center;
  position: relative;
  direction: ltr; }

.n2_device_changer__button {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 24px;
  height: 24px;
  font-size: 24px;
  color: #94b2c1; }

.n2_device_changer__button--marked:after {
  position: absolute;
  top: -3px;
  right: -3px;
  display: block;
  content: '';
  width: 8px;
  height: 8px;
  border-radius: 20px;
  border: 2px solid #FFFFFF;
  background-color: #F69300; }

.n2_device_tester {
  display: none;
  position: absolute;
  top: 100%;
  left: 12px;
  transform: translateX(-50%);
  padding: 10px 10px 0;
  width: 260px;
  background-color: #0C1924; }
  .n2_device_changer--active .n2_device_tester {
    display: block; }

.n2_device_tester_devices {
  display: flex;
  justify-content: space-around; }

.n2_device_tester_devices__device {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  padding: 6px 10px;
  width: 24px;
  height: 24px;
  color: #94B2C1;
  font-size: 24px;
  cursor: pointer; }

.n2_device_tester_devices__device--active {
  color: #1D81F9; }

.n2_device_tester_zoom {
  display: flex;
  align-items: center;
  padding: 10px 0;
  background-color: #0C1924;
  border-radius: 0 0 3px 3px;
  text-align: center; }

.n2_device_tester_zoom__min_label,
.n2_device_tester_zoom__max_label {
  width: 30px;
  padding: 0 10px;
  color: #94B2C1;
  font-size: 10px; }

.n2_device_tester_zoom__min_label {
  text-align: right; }

.n2_device_tester_zoom__max_label {
  text-align: left; }

.n2_device_tester_zoom__inner {
  position: relative;
  margin: 0 0;
  width: 160px;
  height: 34px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.n2_device_tester_zoom__trail {
  position: absolute;
  left: 0;
  top: 50%;
  margin: -3px 0px;
  width: 160px;
  background-color: #3A4956;
  height: 6px;
  border-radius: 3px; }

.n2_device_tester_zoom__editor_size {
  position: absolute;
  left: 0;
  top: 9px;
  margin-left: -2px;
  width: 2px;
  height: 16px;
  background-color: #3A4956; }

.n2_device_tester_zoom__handle {
  position: absolute;
  top: 9px;
  display: block;
  width: 16px;
  height: 16px;
  margin-left: -8px;
  background-color: #fff;
  border-radius: 16px;
  z-index: 2;
  cursor: ew-resize; }

.n2_device_tester_zoom__handle_label {
  position: absolute;
  left: -22px;
  top: -18px;
  width: 60px;
  color: #94B2C1;
  font-size: 10px;
  line-height: 16px;
  text-align: center; }

.n2_slider_manager {
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  padding: 0 40px; }
  .n2_slider_manager__search {
    position: relative; }
    .n2_slider_manager__search_label {
      display: none; }
      .n2_slider_manager__search_label_item {
        font-size: 14px;
        line-height: 28px;
        color: #325c77; }
      .n2_slider_manager__search_label_keyword {
        font-weight: bold; }
    .n2_slider_manager__search_form input {
      position: relative;
      padding-left: 26px;
      border-radius: 3px;
      border: 2px solid #94B2C1;
      width: 200px;
      font-size: 14px;
      line-height: 28px;
      color: #325C77; }
      html[dir="rtl"] .n2_slider_manager__search_form input {
        padding-left: 0;
        padding-right: 26px; }
      .n2_slider_manager__search_form input::placeholder {
        color: #325C77; }
      .n2_slider_manager__search_form input:focus {
        outline: none;
        border: 2px solid #94B2C1;
        box-shadow: none; }
    .n2_slider_manager__search_icon {
      position: absolute;
      top: 0;
      left: 0;
      padding-left: 10px;
      bottom: -2px;
      align-items: center;
      justify-content: center;
      color: #94b2c1;
      z-index: 2; }
      html[dir="rtl"] .n2_slider_manager__search_icon {
        padding-left: 0;
        padding-right: 10px;
        left: unset;
        right: 0; }
      .n2_slider_manager__search_icon--magnifier {
        display: flex; }
      .n2_slider_manager__search_icon--abort {
        display: none;
        cursor: pointer; }
        .n2_slider_manager__search_icon--abort i {
          font-size: 14px !important; }
        .n2_slider_manager__search_icon--abort:hover {
          color: #325c77; }
  .n2_slider_manager--search .n2_slider_manager__new_slider {
    display: none; }
  .n2_slider_manager--search .n2_slider_manager__paginator {
    display: none; }
  .n2_slider_manager--search .n2_button_disabled {
    opacity: .5;
    pointer-events: none; }
  .n2_slider_manager--search .n2_slider_manager__search_label {
    display: block; }
  .n2_slider_manager--search .n2_slider_manager__search_icon--magnifier {
    display: none; }
  .n2_slider_manager--search .n2_slider_manager__search_icon--abort {
    display: flex; }
  .n2_slider_manager--noresult .n2_slider_manager__search_label {
    display: none; }
  .n2_slider_manager--noresult .n2_slider_manager__content .n2_slider_manager__content--empty {
    display: flex; }

.n2_slider_manager__action_bar {
  display: flex;
  padding: 16px 0 0;
  height: 30px; }
  .n2_slider_manager__action_bar_left {
    flex: 1 1 auto;
    display: flex;
    justify-content: flex-start;
    align-items: center;
    margin: 0 -5px; }
    .n2_slider_manager__action_bar_left .n2_slider_icon--blue {
      color: #94B2C1; }
  .n2_slider_manager__action_bar_right {
    flex: 1 1 auto;
    display: flex;
    justify-content: flex-end; }

.n2_slider_manager__content {
  position: relative;
  display: flex;
  flex-wrap: wrap;
  margin: 0 -16px; }
  .n2_slider_manager__content .n2_slider_manager__content--empty {
    padding-top: 80px;
    margin: auto;
    width: 500px;
    flex-flow: column;
    align-items: center;
    justify-content: center;
    height: 216px;
    display: none; }
    .n2_slider_manager__content .n2_slider_manager__content--empty__logo {
      display: flex;
      align-items: center;
      justify-content: center;
      margin-top: 44px;
      width: 100px;
      height: 100px;
      border-radius: 50px;
      overflow: hidden;
      color: #89A9B9; }
    .n2_slider_manager__content .n2_slider_manager__content--empty__heading {
      margin-top: 10px;
      font-size: 18px;
      line-height: 30px;
      color: #283F4D;
      font-weight: bold; }
    .n2_slider_manager__content .n2_slider_manager__content--empty__paragraph {
      width: 360px;
      height: 78px;
      color: #325C77;
      font-size: 14px;
      line-height: 26px;
      text-align: center; }

.n2_slider_manager__box {
  position: relative;
  flex: 0 0 auto;
  width: 270px;
  height: 180px;
  border-radius: 3px;
  margin: 16px;
  background: #fff; }

.n2_slider_manager__sortable_placeholder {
  height: 200px;
  margin: 5px 0;
  width: 0;
  box-shadow: 0 0 0 2px #1d81f9; }

.n2_slider_manager__new_slider {
  background-color: #04C018;
  color: #fff;
  display: flex;
  flex-flow: column;
  justify-content: center;
  align-items: center;
  cursor: pointer; }
  .n2_slider_manager__new_slider:HOVER {
    background-color: #07CA1C; }

.n2_slider_manager__new_slider_icon {
  margin: 5px 0 25px; }

.n2_slider_manager__new_slider_label {
  font-size: 16px;
  line-height: 16px;
  text-transform: uppercase;
  font-weight: bold;
  max-width: 200px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_slider_box {
  position: relative;
  display: flex;
  flex-flow: column;
  border-radius: 3px;
  box-shadow: 0 10px 8px -10px rgba(0, 0, 0, 0.1);
  overflow: hidden;
  transition: transform 0.2s, box-shadow 0.5s; }
  .n2_slider_box:HOVER, .n2_slider_box.n2_slider_box--context-menu {
    box-shadow: 0 10px 8px -10px rgba(0, 0, 0, 0.2); }

.n2_slider_box.n2_slider_box--selected {
  box-shadow: 0 0 0 5px #1d81f9;
  transition: box-shadow 0s; }

.n2_slider_box.n2-ui-sortable-helper {
  opacity: 0.8; }

.n2_slider_box__content {
  position: relative;
  height: 100%;
  background-size: cover;
  background-position: 50% 0;
  background-repeat: no-repeat; }
  .n2_slider_box__content .n2_slider_box__icon {
    background: #1375e9;
    height: 100%;
    width: 100%;
    position: absolute;
    top: 0;
    left: 0;
    display: flex;
    align-items: center;
    justify-content: center;
    flex-flow: column; }
    .n2_slider_box__content .n2_slider_box__icon.n2_slider_box__icon_grey {
      background: #6B7986; }
    .n2_slider_box__content .n2_slider_box__icon .n2_slider_box__icon_container {
      color: white; }
    .n2_slider_box__content .n2_slider_box__icon .n2_slider_box__icon_text {
      color: white;
      text-transform: uppercase;
      font-weight: bold;
      margin-top: 12px; }

.n2_slider_box--group .n2_slider_box__icon {
  background: #94B2C1; }

.n2_slider_box--slider {
  background-size: cover;
  background-position: 50% 0;
  background-repeat: no-repeat; }

.n2_slider_box__footer {
  flex: 0 0 auto;
  padding: 15px 10px;
  background-color: #fff;
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  display: flex;
  align-items: center; }

.n2_slider_box__footer_title {
  display: block;
  padding: 0 5px;
  box-sizing: border-box;
  width: 100%;
  min-height: 20px;
  max-height: 60px;
  overflow: hidden;
  word-wrap: break-word;
  cursor: text;
  font-size: 14px;
  line-height: 20px;
  font-weight: bold;
  color: #325c77; }

.n2_slider_box__footer_icon {
  color: #94B2C1;
  height: 16px;
  margin: 0 5px; }

.n2_slider_box__footer_children_count {
  flex: 0 0 auto;
  margin-left: auto;
  height: 24px;
  width: 24px;
  border-radius: 12px;
  background-color: #94b2c1;
  font-size: 12px;
  line-height: 24px;
  color: #FFFFFF;
  font-weight: bold;
  text-align: center; }

.n2_slider_box__slider_overlay {
  display: none;
  z-index: 10;
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(32, 41, 52, 0.9);
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
  justify-content: center;
  align-items: center; }
  .n2_slider_box:HOVER .n2_slider_box__slider_overlay,
  .n2_slider_box--context-menu .n2_slider_box__slider_overlay {
    display: flex; }

.n2_slider_box__slider_overlay_link {
  z-index: 1;
  position: absolute;
  display: block;
  width: 100%;
  height: 100%; }

.n2_slider_box__slider_overlay .n2_button {
  display: inline-block;
  position: relative;
  z-index: 2;
  max-width: 120px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_slider_box__slider_select_tick {
  z-index: 2;
  position: absolute;
  left: 8px;
  top: 8px;
  box-sizing: border-box;
  width: 20px;
  height: 20px;
  border-radius: 3px;
  border: 2px solid #6B7986;
  cursor: pointer;
  font-size: 16px;
  line-height: 16px;
  color: #fff; }
  .n2_slider_box__slider_select_tick .ssi_16 {
    display: none; }

.n2_slider_box__slider_identifiers {
  z-index: 9;
  position: absolute;
  left: 2px;
  bottom: 2px;
  display: flex; }

.n2_slider_box__slider_identifier {
  margin: 3px;
  padding: 0 5px;
  background-color: #6B7986;
  border-radius: 3px;
  font-size: 12px;
  line-height: 2em;
  color: #FFFFFF;
  text-transform: uppercase; }

.n2_slider_box__slider_actions {
  display: none;
  position: absolute;
  right: 8px;
  top: 8px;
  z-index: 12; }
  .n2_slider_box:HOVER .n2_slider_box__slider_actions,
  .n2_slider_box--context-menu .n2_slider_box__slider_actions {
    display: block; }

.n2_slide_box__screen_reader {
  border: 0;
  clip-path: inset(50%);
  height: 1px;
  margin: -1px;
  overflow: hidden;
  padding: 0;
  position: absolute;
  width: 1px;
  word-wrap: normal !important; }

.n2_slider_manager__action_bar_bulk_actions {
  display: none; }
  .n2_body--bulk-select .n2_slider_manager__action_bar_bulk_actions, .n2_slider_manager__action_bar_bulk_actions.n2_slider_manager__action_bar_bulk_actions--popover-visible {
    display: block; }

.n2_body--bulk-select .n2_header__actions {
  visibility: hidden; }

.n2_body--bulk-select .n2_slider_box {
  opacity: 0.5; }
  .n2_body--bulk-select .n2_slider_box.n2_slider_box--bulk-selected {
    opacity: 1; }
    .n2_body--bulk-select .n2_slider_box.n2_slider_box--bulk-selected .n2_slider_box__slider_select_tick {
      background-color: #1D81F9;
      border-color: #1D81F9; }
      .n2_body--bulk-select .n2_slider_box.n2_slider_box--bulk-selected .n2_slider_box__slider_select_tick .ssi_16 {
        display: block; }

.n2_body--bulk-select .n2_slider_box__slider_overlay {
  display: flex; }

.n2_body--bulk-select .n2_slider_box__slider_overlay_link,
.n2_body--bulk-select .n2_slider_box__slider_overlay_edit_button,
.n2_body--bulk-select .n2_slider_box__slider_actions {
  display: none !important; }

.n2_slider_manager__paginator {
  align-items: center;
  opacity: 1;
  display: grid;
  grid-template-columns: 1fr 1fr 1fr; }
  .n2_slider_manager__paginator .n2_slider_manager__paginator_label_item {
    font-size: 14px;
    color: #325C77; }
    .n2_slider_manager__paginator .n2_slider_manager__paginator_label_item--active {
      display: block; }
    .n2_slider_manager__paginator .n2_slider_manager__paginator_label_item--empty {
      display: none; }
  .n2_slider_manager__paginator .n2_slider_manager__paginator_label--nosliders .n2_slider_manager__paginator_label_item--active {
    display: none; }
  .n2_slider_manager__paginator .n2_slider_manager__paginator_label--nosliders .n2_slider_manager__paginator_label_item--empty {
    display: block; }
  .n2_slider_manager__paginator .n2_slider_manager__paginator_buttons {
    display: flex;
    justify-content: center; }
  .n2_slider_manager__paginator .n2_slider_manager__paginator_item {
    color: #325c77;
    font-weight: 700;
    display: inline-flex;
    align-items: center;
    font-size: 14px;
    line-height: 28px;
    justify-content: center;
    margin: 0 5px; }
    .n2_slider_manager__paginator .n2_slider_manager__paginator_item--active {
      color: #1375E9; }
    .n2_slider_manager__paginator .n2_slider_manager__paginator_item_arrow {
      margin: 0; }
      .n2_slider_manager__paginator .n2_slider_manager__paginator_item_arrow i {
        font-size: 10px !important; }
      .n2_slider_manager__paginator .n2_slider_manager__paginator_item_arrow--prev {
        transform: rotate(180deg); }
        html[dir="rtl"] .n2_slider_manager__paginator .n2_slider_manager__paginator_item_arrow--prev {
          transform: none; }
      html[dir="rtl"] .n2_slider_manager__paginator .n2_slider_manager__paginator_item_arrow--next {
        transform: rotate(180deg); }
      .n2_slider_manager__paginator .n2_slider_manager__paginator_item_arrow--disabled {
        visibility: hidden; }
  .n2_slider_manager__paginator .n2_slider_manager__paginator_limiter {
    text-align: right; }
    html[dir="rtl"] .n2_slider_manager__paginator .n2_slider_manager__paginator_limiter {
      text-align: left; }

.n2_new_project {
  min-height: 100%;
  display: flex;
  flex-flow: column;
  justify-content: center; }

.n2_new_project__heading {
  margin-top: 30px;
  color: #283F4D;
  font-size: 32px;
  line-height: 40px;
  text-align: center; }

.n2_new_project__sub_heading {
  color: #325C77;
  font-size: 14px;
  line-height: 30px;
  text-align: center; }

.n2_new_project__boxes {
  display: flex;
  justify-content: space-between;
  margin: 40px -30px; }

.n2_new_project__box {
  flex: 1 1 50%;
  margin: 0 30px;
  padding: 30px 40px;
  background-color: #FFFFFF;
  border-radius: 10px;
  text-align: center;
  cursor: pointer; }
  .n2_new_project__box:HOVER {
    box-shadow: 0 2px 10px 0 rgba(0, 0, 0, 0.1); }

.n2_new_project__box_heading {
  color: #283F4D;
  font-size: 22px;
  line-height: 40px; }

.n2_new_project__box_sub_heading {
  color: #325C77;
  font-size: 14px;
  line-height: 24px; }

.n2_new_project__import {
  display: block;
  margin: 0 auto 20px;
  font-size: 14px;
  line-height: 30px;
  text-transform: capitalize; }
  .n2_new_project__import:HOVER {
    color: #005BC6; }
  .n2_new_project__import, .n2_new_project__import:FOCUS {
    color: #1375E9; }

.n2_create_new_project {
  display: flex;
  flex-flow: column;
  max-width: 840px;
  margin: 0 auto;
  box-sizing: border-box;
  min-height: 100%;
  padding: 30px 20px; }

.n2_create_new_project__heading {
  color: #283F4D;
  font-size: 32px;
  line-height: 40px;
  text-align: center; }

.n2_ss_slider_publish {
  display: flex; }

.n2_ss_slider_publish__option {
  padding: 40px 20px;
  flex: 1;
  display: flex;
  flex-flow: column;
  align-items: center; }
  .n2_ss_slider_publish__option img {
    margin-top: 15px;
    max-width: 100%; }
  .n2_ss_slider_publish__option .n2_button {
    margin-top: 15px; }

.n2_ss_slider_publish__option + .n2_ss_slider_publish__option {
  border-left: 1px solid #E4E9EC; }
  html[dir="rtl"] .n2_ss_slider_publish__option + .n2_ss_slider_publish__option {
    border-left: 0;
    border-right: 1px solid #E4E9EC; }

.n2_ss_slider_publish__option_label {
  line-height: 28px;
  font-size: 18px;
  color: #283F4D; }

.n2_ss_slider_publish__option_description {
  text-align: center;
  line-height: 28px;
  font-size: 14px;
  color: #325C77; }

.n2_ss_slider_publish__option_code {
  margin-top: 15px;
  padding: 15px 20px;
  background-color: #F5E293;
  border-radius: 2px;
  line-height: 20px;
  font-size: 13px;
  color: #325C77; }

.n2_ss_slider_publish__related_modules {
  display: flex;
  flex-wrap: wrap;
  margin-top: 10px; }
  .n2_ss_slider_publish__related_modules .n2_button {
    margin: 3px; }

.n2_slider_trash {
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  position: relative;
  display: flex;
  flex-wrap: wrap;
  margin-left: 5px; }
  html[dir="rtl"] .n2_slider_trash {
    margin-left: 0px;
    margin-right: 5px; }

.n2_slider_manager__dummy_slider {
  display: none;
  background: #f0f4f7;
  border: 2px dashed #94B2C1;
  flex-flow: column;
  justify-content: center;
  align-items: center;
  box-sizing: border-box; }
  .n2_slider_trash--empty .n2_slider_manager__dummy_slider {
    display: flex; }

.n2_slider_manager__dummy_slider_icon {
  margin: 16px 0;
  color: #94B2C1; }

.n2_slider_manager__dummy_slider_label {
  font-size: 14px;
  line-height: 22px;
  color: #325C77;
  font-weight: bold; }

.n2_slide_manager {
  position: relative;
  z-index: 1100;
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  margin: 0 -1px; }
  .n2_slide_manager[data-breadcrumbopener="1"] {
    display: none; }
    .n2_admin_editor_overlay--show-slides .n2_slide_manager[data-breadcrumbopener="1"] {
      display: flex;
      flex-flow: column; }

.n2_slide_manager__inner {
  background-color: #2C3A45; }

.n2_slide_manager__exit {
  flex: 1 1 auto;
  background: rgba(28, 41, 51, 0.5);
  cursor: pointer; }

.n2_slide_manager__action_bar {
  position: relative;
  z-index: 3;
  padding: 5px 35px;
  height: 30px;
  margin-bottom: -40px; }

.n2_slide_manager__content {
  position: relative;
  display: flex;
  flex-wrap: wrap;
  padding: 30px 30px; }

.n2_slide_manager__box {
  position: relative;
  box-sizing: border-box;
  flex: 0 0 auto;
  width: 200px;
  height: 135px;
  border-radius: 3px;
  margin: 10px;
  background: #0c1924; }

.n2_slide_manager__sortable_placeholder {
  height: 135px;
  margin: 5px 0;
  width: 0;
  box-shadow: 0 0 0 2px #1d81f9; }

.n2_slide_manager__action_bar .n2_button_plain, .n2_slide_manager__action_bar .n2_button_plain:HOVER, .n2_slide_manager__action_bar .n2_button_plain:FOCUS {
  color: #bdcfd9; }

.n2_slide_manager__action_bar_bulk_actions {
  display: none; }
  .n2_slide_manager--bulk-select .n2_slide_manager__action_bar_bulk_actions,
  .n2_slide_manager__action_bar_bulk_actions .n2_slide_manager__action_bar_bulk_actions--popover-visible {
    display: block; }

.n2_slide_manager--bulk-select .n2_slide_box {
  opacity: 0.5; }
  .n2_slide_manager--bulk-select .n2_slide_box.n2_slide_box--bulk-selected {
    opacity: 1; }
    .n2_slide_manager--bulk-select .n2_slide_box.n2_slide_box--bulk-selected .n2_slide_box__slide_select_tick {
      background-color: #1D81F9;
      border-color: #1D81F9; }
      .n2_slide_manager--bulk-select .n2_slide_box.n2_slide_box--bulk-selected .n2_slide_box__slide_select_tick .ssi_16 {
        display: block; }

.n2_slide_manager--bulk-select .n2_slide_box__slide_overlay {
  display: flex; }

.n2_slide_manager--bulk-select .n2_slide_box__slide_overlay_link,
.n2_slide_manager--bulk-select .n2_slide_box__slide_overlay_edit_button,
.n2_slide_manager--bulk-select .n2_slide_box__slide_actions {
  display: none !important; }

.n2_slide_manager__add_slide {
  background-color: #04C018;
  padding: 16px 0;
  display: flex;
  flex-flow: column;
  justify-content: center;
  align-items: center;
  color: #fff;
  cursor: pointer; }
  .n2_slide_manager__add_slide:HOVER {
    background-color: #07CA1C; }

.n2_slide_manager__add_slide_icon {
  font-size: 48px;
  margin: 16px 0; }

.n2_slide_manager__add_slide_label {
  font-size: 14px;
  line-height: 22px;
  font-weight: bold;
  text-transform: uppercase;
  max-width: 160px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_slide_manager__add_slide_label--close {
  display: none; }

.n2_slide_manager--add-slide .n2_slide_manager__add_slide {
  background-color: #6B7986; }
  .n2_slide_manager--add-slide .n2_slide_manager__add_slide:HOVER {
    background-color: #8694A2; }

.n2_slide_manager--add-slide .n2_slide_manager__add_slide_icon {
  transform: rotateZ(45deg); }

.n2_slide_manager--add-slide .n2_slide_manager__add_slide_label--add-slide {
  display: none; }

.n2_slide_manager--add-slide .n2_slide_manager__add_slide_label--close {
  display: block; }

.n2_slide_manager__add_slide_actions {
  overflow: hidden;
  height: 0;
  transition: height 0.4s; }
  .n2_slide_manager--add-slide .n2_slide_manager__add_slide_actions {
    height: 150px; }

.n2_slide_manager__add_slide_actions_inner {
  display: flex;
  padding: 10px 30px; }

.n2_slide_manager__add_slide_action {
  display: flex;
  flex-flow: column;
  align-items: center;
  justify-content: center;
  margin: 10px;
  width: 140px;
  height: 110px;
  box-sizing: border-box;
  padding: 14px 0;
  border-radius: 3px; }
  .n2_slide_manager__add_slide_action, .n2_slide_manager__add_slide_action:HOVER, .n2_slide_manager__add_slide_action:FOCUS {
    color: #BDCFD9; }
  .n2_slide_manager__add_slide_action:not(:first-child):HOVER {
    color: #fff; }

.n2_slide_manager__add_slide_action--image {
  background-color: #04C018; }
  .n2_slide_manager__add_slide_action--image:HOVER {
    background-color: #07CA1C; }
  .n2_slide_manager__add_slide_action--image, .n2_slide_manager__add_slide_action--image:HOVER, .n2_slide_manager__add_slide_action--image:FOCUS {
    color: #fff; }

.n2_slide_manager__add_slide_action_icon {
  padding: 4px 0;
  font-size: 48px;
  display: flex; }

.n2_slide_manager__add_slide_action_label {
  font-size: 14px;
  line-height: 26px;
  font-weight: bold;
  text-transform: capitalize;
  max-width: 120px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_slide_manager__dummy_slide {
  display: none;
  background-color: #2C3A45;
  border: 2px dashed #BDCFD9;
  padding: 16px 0;
  flex-flow: column;
  justify-content: center;
  align-items: center;
  color: #BDCFD9;
  cursor: pointer; }
  html[data-slides="0"] .n2_slide_manager__dummy_slide {
    display: flex; }

.n2_slide_manager__dummy_slide_icon {
  margin: 16px 0; }

.n2_slide_manager__dummy_slide_label {
  font-size: 14px;
  line-height: 22px; }

.n2_slide_box {
  position: relative;
  opacity: 0.5;
  display: flex;
  flex-flow: column;
  transition: opacity 0.6s; }
  .n2_slide_box.n2_slide_box--published {
    opacity: 1; }

.n2_slide_box--currently-edited {
  box-shadow: 0 0 0 3px #1d81f9; }

.n2_slide_box--just-added {
  opacity: 0; }

.n2_slide_box__content {
  position: relative;
  height: 100%;
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
  background-size: cover;
  background-position: 50% 0;
  background-repeat: no-repeat; }

.n2_slide_box__footer {
  flex: 0 0 auto;
  padding: 9px 10px;
  background-color: #0C1924;
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px;
  display: flex;
  align-items: center; }

.n2_slide_box__footer_title {
  display: block;
  padding: 0 5px;
  box-sizing: border-box;
  width: 100%;
  min-height: 20px;
  max-height: 60px;
  overflow: hidden;
  word-wrap: break-word;
  cursor: text;
  font-size: 14px;
  line-height: 20px;
  font-weight: bold;
  color: #BDCFD9; }

.n2_slide_box__footer_status {
  margin-left: auto;
  display: flex;
  align-items: center; }
  .n2_slide_box__footer_status > * {
    display: flex;
    padding: 3px; }

.n2_slide_box__footer_status_first_slide {
  display: none;
  color: #e19f21; }
  .n2_slide_box--first-slide .n2_slide_box__footer_status_first_slide {
    display: flex; }

.n2_slide_box__footer_status_published {
  display: none; }
  .n2_slide_box--published .n2_slide_box__footer_status_published {
    display: flex; }
  .n2_slide_box__footer_status_published, .n2_slide_box__footer_status_published:HOVER, .n2_slide_box__footer_status_published:FOCUS {
    color: #04c018; }

.n2_slide_box--published .n2_slide_box__footer_status_unpublished {
  display: none; }

.n2_slide_box__footer_status_unpublished, .n2_slide_box__footer_status_unpublished:HOVER, .n2_slide_box__footer_status_unpublished:FOCUS {
  color: #bdcfd9; }

.n2_slide_box__footer_status_hidden {
  display: none; }
  .n2_slide_box__footer_status_hidden:not([data-n2tip=""]) {
    display: flex; }
  .n2_slide_box__footer_status_hidden, .n2_slide_box__footer_status_hidden:HOVER, .n2_slide_box__footer_status_hidden:FOCUS {
    color: #bdcfd9; }

.n2_slide_box__slide_overlay {
  display: none;
  z-index: 2;
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  background-color: rgba(32, 41, 52, 0.9);
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
  justify-content: center;
  align-items: center; }
  .n2_slide_box:HOVER .n2_slide_box__slide_overlay,
  .n2_slide_box--context-menu .n2_slide_box__slide_overlay {
    display: flex; }

.n2_slide_box__slide_overlay_link {
  z-index: 1;
  position: absolute;
  display: block;
  width: 100%;
  height: 100%; }

.n2_slide_box__slide_overlay_edit_button {
  position: relative;
  z-index: 2;
  padding: 0 10px;
  line-height: 28px;
  border-radius: 2px;
  background-color: #04C018;
  font-size: 11px;
  text-transform: uppercase;
  max-width: 100px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }
  .n2_slide_box__slide_overlay_edit_button:HOVER {
    background-color: #07CA1C; }
  .n2_slide_box__slide_overlay_edit_button, .n2_slide_box__slide_overlay_edit_button:HOVER, .n2_slide_box__slide_overlay_edit_button:FOCUS {
    color: #FFFFFF; }

.n2_slide_box--currently-edited .n2_slide_box__slide_overlay_link,
.n2_slide_box--currently-edited .n2_slide_box__slide_overlay_edit_button {
  display: none; }

.n2_slide_box__slide_select_tick {
  z-index: 2;
  position: absolute;
  left: 8px;
  top: 8px;
  box-sizing: border-box;
  width: 20px;
  height: 20px;
  border-radius: 3px;
  border: 2px solid #6B7986;
  cursor: pointer;
  font-size: 16px;
  line-height: 16px;
  color: #fff; }
  .n2_slide_box__slide_select_tick .ssi_16 {
    display: none; }
  html[dir="rtl"] .n2_slide_box__slide_select_tick {
    right: 8px;
    left: auto; }

.n2_slide_box__slide_actions {
  display: none;
  position: absolute;
  right: 8px;
  top: 8px;
  z-index: 12; }
  .n2_slide_box:HOVER .n2_slide_box__slide_actions,
  .n2_slide_box--context-menu .n2_slide_box__slide_actions {
    display: block; }
  html[dir="rtl"] .n2_slide_box__slide_actions {
    left: 8px;
    right: auto; }

.n2_slide_box__details {
  z-index: 1;
  position: absolute;
  left: 5px;
  bottom: 5px;
  display: flex;
  flex-flow: column; }
  .n2_slide_box__details > * {
    margin: 5px;
    padding: 0 3px;
    background-color: #6b7986;
    border-radius: 3px;
    font-size: 11px;
    line-height: 2em;
    color: #fff; }

.n2_slide_box__details_static_slide {
  text-transform: uppercase; }

.n2_slide_manager__block_notice {
  background-color: #0c1924;
  display: flex;
  align-items: center;
  justify-content: center;
  text-align: center;
  flex-flow: column; }

html[data-slides="0"] .n2_slide_manager__block_notice,
html[data-slides="1"] .n2_slide_manager__block_notice {
  display: none; }

.n2_slide_manager__block_notice_description {
  margin-bottom: 10px; }

.n2_slide_manager__block_notice_button {
  background: #1375e9;
  line-height: 30px;
  border-radius: 3px;
  padding: 0 10px;
  font-size: 11px;
  text-transform: uppercase;
  font-weight: bold;
  cursor: pointer; }
  .n2_slide_manager__block_notice_button:HOVER {
    background-color: #005BC6; }
  .n2_slide_manager__block_notice_button, .n2_slide_manager__block_notice_button:HOVER, .n2_slide_manager__block_notice_button:FOCUS {
    color: white; }

.n2_slide_manager__autoplay_notice {
  background-color: #0c1924;
  align-items: center;
  justify-content: center;
  text-align: center;
  flex-flow: column;
  display: none; }

html[data-published-regular-slides="1"] .n2_slide_manager__autoplay_notice {
  display: flex; }

.n2_slide_manager__autoplay_notice_description {
  margin-bottom: 10px; }

.n2_slide_manager__autoplay_notice_button {
  background: #1375e9;
  line-height: 30px;
  border-radius: 3px;
  padding: 0 10px;
  font-size: 11px;
  text-transform: uppercase;
  font-weight: bold;
  cursor: pointer; }
  .n2_slide_manager__autoplay_notice_button:HOVER {
    background-color: #005BC6; }
  .n2_slide_manager__autoplay_notice_button, .n2_slide_manager__autoplay_notice_button:HOVER, .n2_slide_manager__autoplay_notice_button:FOCUS {
    color: white; }

.n2_nav_bar__breadcrumb_button_slides {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  cursor: pointer; }
  .n2_nav_bar__breadcrumb_button_slides .ssi_16 {
    display: inline-block;
    vertical-align: middle; }
  .n2_admin_editor_overlay--show-slides .n2_nav_bar__breadcrumb_button_slides span .ssi_16 {
    transform: rotateZ(180deg); }
  .n2_breadcrumbs__breadcrumb--active .n2_nav_bar__breadcrumb_button_slides, .n2_breadcrumbs__breadcrumb--active .n2_nav_bar__breadcrumb_button_slides:HOVER, .n2_breadcrumbs__breadcrumb--active .n2_nav_bar__breadcrumb_button_slides:FOCUS {
    color: #94b2c1; }
    .n2_admin_editor_overlay--show-slides .n2_breadcrumbs__breadcrumb--active .n2_nav_bar__breadcrumb_button_slides, .n2_admin_editor_overlay--show-slides .n2_breadcrumbs__breadcrumb--active .n2_nav_bar__breadcrumb_button_slides:HOVER, .n2_admin_editor_overlay--show-slides .n2_breadcrumbs__breadcrumb--active .n2_nav_bar__breadcrumb_button_slides:FOCUS {
      color: #fff; }

.n2_ss_history_action {
  opacity: 0.5; }

.n2_ss_history_action--allowed {
  opacity: 1; }

#n2-admin[data-slide-background-type="image"] .n2_form__table_row[data-field="table-row-background-video"] {
  display: none; }

#n2-admin[data-slide-background-type="color"] .n2_form__table_row[data-field="table-row-background-video"],
#n2-admin[data-slide-background-type="color"] .n2_form__table_row[data-field="table-row-background-image"],
#n2-admin[data-slide-background-type="color"] .n2_field[data-field="slidebackgroundColorOverlay"] {
  display: none; }

.n2_admin_editor_overlay__middle {
  flex: 1 1 auto;
  display: flex; }
  [dir="rtl"] .n2_admin_editor_overlay__middle {
    flex-flow: row-reverse; }

.n2_admin_editor_overlay__middle_center {
  position: relative;
  flex: 1 1 auto;
  overflow: hidden; }

.n2_add_layer {
  visibility: visible;
  flex: 0 0 auto;
  position: relative;
  display: flex;
  width: 50px;
  z-index: 10; }

.n2_add_layer__bar {
  position: relative;
  width: 100%;
  height: 100%;
  background-color: #0C1924;
  overflow: hidden; }
  .n2_add_layer__bar .n2_button_plain_icon, .n2_add_layer__bar .n2_button_plain_icon:HOVER, .n2_add_layer__bar .n2_button_plain_icon:FOCUS {
    color: #94B2C1; }
  .n2_add_layer__bar .n2_button_plain_icon--active {
    background: #1d81f9; }
    .n2_add_layer__bar .n2_button_plain_icon--active, .n2_add_layer__bar .n2_button_plain_icon--active:HOVER, .n2_add_layer__bar .n2_button_plain_icon--active:FOCUS {
      color: #fff; }
  .n2_add_layer__bar .n2_timeline_control_play_pause--playing {
    background: #1d81f9; }
    .n2_add_layer__bar .n2_timeline_control_play_pause--playing, .n2_add_layer__bar .n2_timeline_control_play_pause--playing:HOVER, .n2_add_layer__bar .n2_timeline_control_play_pause--playing:FOCUS {
      color: #fff; }
    .n2_add_layer__bar .n2_timeline_control_play_pause--playing .ssi_24::before {
      content: "\E16D"; }

.n2_add_layer__bar_top,
.n2_add_layer__bar_bottom {
  background-color: #0C1924;
  position: absolute;
  left: 0;
  display: flex;
  flex-flow: column;
  align-items: center;
  padding: 0 10px; }

.n2_add_layer__bar_top {
  top: 0; }
  .n2_add_layer__bar_top > * {
    margin-bottom: 14px; }

.n2_add_layer__bar_bottom {
  bottom: 0; }
  .n2_add_layer__bar_bottom > * {
    margin-bottom: 14px; }

.n2_add_layer__bar_button {
  flex: 0 0 auto;
  border-radius: 2px; }

.n2_add_layer__more {
  display: none;
  flex-flow: column;
  position: absolute;
  left: 0;
  top: 0;
  width: 330px;
  height: 100%;
  background-color: #2C3A45; }
  .n2_admin_editor_overlay--show-add-more .n2_add_layer__more {
    display: flex; }

.n2_add_layer__more_tab_buttons {
  flex: 0 0 auto;
  display: flex;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.n2_add_layer__more_tab_button {
  flex: 1 1 0;
  display: flex;
  align-items: center;
  flex-flow: column;
  padding: 14px 0 6px;
  text-align: center;
  cursor: pointer;
  background-color: #0C1924;
  color: #94B2C1; }

.n2_add_layer__more_tab_button--active {
  background-color: #1D81F9;
  color: #FFFFFF; }

.n2_add_layer__more_tab_button_icon {
  display: flex;
  align-items: center;
  justify-content: center; }

.n2_add_layer__more_tab_button_label {
  font-size: 11px;
  line-height: 26px;
  text-transform: uppercase;
  font-weight: bold;
  max-width: 145px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_add_layer__more_tab {
  display: none;
  flex-flow: column;
  flex: 1 1 auto;
  overflow: hidden; }

.n2_add_layer__more_tab--active {
  display: flex; }

.n2_add_layer__more_layers {
  flex: 1 1 auto;
  overflow-y: auto; }

.n2_add_layer_group {
  margin-bottom: 10px; }

.n2_add_layer_group__label {
  padding: 8px 20px;
  background-color: #1c2933;
  border-bottom: 1px solid #131c23;
  color: #94b2c1;
  font-size: 12px;
  line-height: 28px;
  font-weight: bold;
  text-transform: uppercase;
  margin-bottom: 10px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_add_layer_group__content {
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  grid-gap: 10px;
  padding: 0 10px; }

.n2_add_layer_box {
  padding: 6px 8px;
  background-color: #6B7986;
  border-radius: 2px;
  text-align: center;
  cursor: pointer;
  /* When item dragged from outside */ }
  .n2_add_layer_box.n2-ss-layer--drag {
    pointer-events: none;
    width: 90px;
    opacity: 0.8;
    z-index: 9999;
    margin: 0; }

.n2_add_layer_box__icon {
  display: flex;
  align-items: center;
  justify-content: center;
  margin-top: 4px;
  color: #fff; }

.n2_add_layer_box__label_wrap {
  display: flex;
  flex-flow: column;
  justify-content: center;
  min-height: 32px; }

.n2_add_layer_box__label {
  font-size: 12px;
  line-height: 14px;
  color: #fff;
  font-weight: bold;
  text-transform: capitalize; }

.n2_add_layer__more_position {
  flex: 0 0 auto;
  display: flex;
  align-items: center;
  height: 50px;
  background-color: #0C1924;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.n2_add_layer_position__label {
  flex: 1 1 50%;
  padding: 0 5px;
  color: #94B2C1;
  font-size: 12px;
  line-height: 24px;
  font-weight: bold;
  text-transform: uppercase;
  cursor: pointer;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_add_layer_position__default_label {
  text-align: right; }
  .n2_add_layer_position[data-position="default"] .n2_add_layer_position__default_label {
    color: #fff;
    cursor: initial; }
  html[dir="rtl"] .n2_add_layer_position__default_label {
    text-align: left; }

.n2_add_layer_position__absolute_label {
  text-align: left; }
  .n2_add_layer_position[data-position="absolute"] .n2_add_layer_position__absolute_label {
    color: #fff;
    cursor: initial; }
  html[dir="rtl"] .n2_add_layer_position__absolute_label {
    text-align: right; }

.n2_add_layer_position__switch {
  padding: 3px;
  width: 44px;
  height: 24px;
  box-sizing: border-box;
  background-color: #1D81F9;
  border-radius: 12px;
  cursor: pointer;
  transition: background-color 0.3s; }
  .n2_add_layer_position[data-position="absolute"] .n2_add_layer_position__switch {
    background-color: #5F39C2; }

.n2_add_layer_position__switch_dot {
  width: 18px;
  height: 18px;
  background-color: #FFFFFF;
  border-radius: 18px;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1);
  transition: transform 0.3s; }
  .n2_add_layer_position[data-position="absolute"] .n2_add_layer_position__switch_dot {
    transform: translateX(20px); }
    html[dir="rtl"] .n2_add_layer_position[data-position="absolute"] .n2_add_layer_position__switch_dot {
      transform: translateX(-20px); }

.n2_add_layer_library__title,
.n2_add_layer_library_tag__title {
  display: flex;
  padding: 7px 10px;
  background-color: #1c2933;
  border-bottom: 1px solid #131c23; }

.n2_add_layer_library__title_label,
.n2_add_layer_library_tag__title_label {
  padding: 0 10px;
  flex: 1 1 auto;
  color: #94b2c1;
  font-size: 12px;
  line-height: 30px;
  font-weight: bold;
  text-transform: uppercase; }

.n2_add_layer_library__theme {
  display: none;
  position: relative;
  overflow-y: scroll;
  height: 100%;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.n2_add_layer_library__theme--active {
  display: block; }

.n2_add_layer_library_tag__title {
  cursor: pointer; }

.n2_add_layer_library_tag__title_opener {
  display: flex;
  align-items: center;
  justify-content: center;
  width: 30px;
  color: #94B2C1; }
  .n2_add_layer_library_tag--active .n2_add_layer_library_tag__title_opener {
    transform: rotateZ(180deg); }

.n2_add_layer_library_tag__sections {
  flex-flow: column;
  align-items: center;
  padding: 10px 0; }
  .n2_add_layer_library_tag .n2_add_layer_library_tag__sections {
    display: none; }
  .n2_add_layer_library_tag--active .n2_add_layer_library_tag__sections {
    display: flex; }

.n2_add_layer_library_tag__section {
  position: relative;
  margin: 10px 0;
  width: 270px;
  border-radius: 3px;
  overflow: hidden; }
  .n2_add_layer_library_tag__section img {
    display: block;
    width: 100%; }

.n2_add_layer_library_tag__section--available {
  cursor: pointer; }

.n2_add_layer_library_tag__section_pro {
  z-index: 10;
  position: absolute;
  top: 5px;
  right: 5px;
  padding: 0 5px;
  background-color: #6b7986;
  border-radius: 3px;
  font-size: 12px;
  line-height: 2em;
  color: #fff; }

.n2_add_layer_library_tag__section_overlay {
  display: none;
  z-index: 9;
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  padding: 0 40px;
  box-sizing: border-box;
  background: rgba(12, 25, 36, 0.9);
  align-items: center;
  color: #94B2C1;
  font-size: 14px;
  line-height: 22px;
  text-align: center; }
  .n2_add_layer_library_tag__section_overlay a, .n2_add_layer_library_tag__section_overlay a:HOVER, .n2_add_layer_library_tag__section_overlay a:FOCUS {
    color: #1D81F9; }
  .n2_add_layer_library_tag__section:HOVER .n2_add_layer_library_tag__section_overlay {
    display: flex; }

.n2_ss_layer_window {
  visibility: visible;
  z-index: 5;
  position: absolute !important;
  left: 100px;
  top: 100px;
  display: none;
  flex-flow: column;
  width: 355px; }
  .n2_body--layer-window-visible .n2_ss_layer_window {
    display: flex; }
  .n2_body--show-add-more .n2_ss_layer_window,
  .n2_body--drag-layer .n2_ss_layer_window,
  .n2_body--resize-absolute .n2_ss_layer_window,
  .n2_body--resize-editor .n2_ss_layer_window {
    display: none; }

.n2_ss_layer_window__resize {
  flex: 0 0 auto;
  position: static !important;
  height: 7px;
  width: 100%;
  cursor: ns-resize;
  background-color: #0C1924;
  border-bottom-left-radius: 3px;
  border-bottom-right-radius: 3px; }

.n2_ss_layer_window__crop {
  flex: 1 1 auto;
  display: flex;
  flex-flow: column;
  position: relative;
  width: 100%;
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
  box-shadow: 0 1px 10px 0 rgba(0, 0, 0, 0.3);
  overflow: hidden;
  background-color: #0C1924;
  z-index: 2; }

.n2_ss_layer_window__title {
  flex: 0 0 auto;
  display: flex;
  position: relative;
  line-height: 36px;
  height: 36px;
  overflow: hidden;
  background-color: #0C1924;
  font-size: 14px;
  color: #94B2C1;
  cursor: move;
  border-top-left-radius: 5px;
  border-top-right-radius: 5px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.n2_ss_layer_window__title_nav a {
  display: block;
  width: 36px;
  height: 36px;
  text-align: center; }

.n2_ss_layer_window__title_nav_button {
  margin: 6px;
  display: inline-flex;
  width: 24px;
  height: 24px;
  align-items: center;
  justify-content: center;
  border-radius: 2px;
  cursor: pointer;
  color: #94B2C1; }

.n2_admin_editor_overlay--attached-layer-list .n2_ss_layer_window__title_nav_button_layer_list {
  background-color: #1d81f9;
  color: #fff; }

.n2_ss_layer_window__title_inner {
  flex: 1 1 auto;
  padding: 0 20px;
  text-align: center;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  font-weight: bold; }

.n2_ss_layer_window__tab_buttons {
  flex: 0 0 auto;
  display: flex;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }
  .n2_ss_layer_window__tab_buttons[data-visible-tabs="1"] {
    display: none; }
  .n2_admin_editor_overlay--attached-layer-list .n2_ss_layer_window__tab_buttons {
    display: none; }

.n2_ss_layer_window__tab_button {
  display: none;
  flex: 1 1 0;
  width: 33%;
  flex-flow: column;
  align-items: center;
  padding: 11px 0 2px;
  cursor: pointer;
  background-color: #0C1924;
  color: #94B2C1; }

.n2_ss_layer_window__tab_button_icon {
  display: flex;
  align-items: center;
  justify-content: center; }

.n2_ss_layer_window__tab_button_label {
  font-size: 11px;
  line-height: 23px;
  text-transform: uppercase;
  font-weight: bold;
  max-width: 100px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_ss_layer_window__tab_button--allowed {
  display: flex; }
  .n2_ss_layer_window__tab_button--allowed.n2_ss_layer_window__tab_button--active {
    background-color: #1D81F9;
    color: #FFFFFF; }

.n2_ss_layer_window__tab_container {
  position: relative;
  flex: 1 1 auto;
  overflow-x: hidden;
  overflow-y: scroll;
  background-color: #3A4956; }
  .n2_admin_editor_overlay--attached-layer-list .n2_ss_layer_window__tab_container {
    display: none; }

.n2_ss_layer_window__tab {
  display: none;
  color: #fff; }
  .n2_ss_layer_window__tab[data-tab="item"] > * {
    display: none; }

.n2_ss_layer_window__tab--allowed.n2_ss_layer_window__tab--active {
  display: block; }

.n2_ss_layer_window__tab_panel {
  display: none; }

.n2_ss_layer_window__tab_panel--active {
  display: block; }

.n2_ss_layer_window [data-generator-related="1"] {
  display: none; }
  .n2_ss_body--dynamic-slide .n2_ss_layer_window [data-generator-related="1"] {
    display: block; }

body[data-device="desktopPortrait"] .n2_field[data-field="layer-clear-device-specific-changes"],
body[data-device="desktopPortrait"] .n2_field[data-field="layer-slide-clear-device-specific-changes"] {
  display: none; }

.n2_admin_editor_overlay--attached-layer-list .n2_layer_navigation_list_title {
  display: none; }

.n2_admin_editor_overlay--attached-layer-list .n2_layer_navigation {
  flex: 1 1 auto;
  width: 100% !important;
  height: auto !important;
  max-height: none;
  overflow: auto; }

.n2_admin_editor_overlay--attached-layer-list .n2_layer_navigation_list {
  width: 100%;
  overflow-y: auto !important; }

.n2_admin_editor_overlay--attached-layer-list .n2_layer_navigation_list_layers {
  padding-bottom: 0 !important; }

.n2_admin_editor_overlay--attached-layer-list .n2_layer_navigation_list_layer__title {
  border-right: 0; }

.n2_admin_editor_overlay--attached-layer-list .n2_timeline {
  width: 0;
  overflow: hidden; }

.n2_fields_layer_window__title_fields .n2_form__table_label_field:last-child {
  margin-right: 0; }

.n2_fields_layer_window[data-fieldset-type="style-mode"][data-state=""] .n2_form__table_label_field[data-style-mode-feature="reset-to-normal"] {
  display: none; }

.n2_ss_design_layer_window_design {
  display: none; }

.n2_ss_design_layer_window_design--visible {
  display: block; }

.n2_layer_window_design_preset {
  display: flex;
  padding: 7px 10px;
  background-color: #1C2933;
  border-bottom: 1px solid #131c23; }

.n2_layer_window_design_preset__label_container {
  flex: 1 1 auto;
  display: inline-flex;
  align-items: center;
  height: 30px; }
  .n2_layer_window_design_preset__label_container .ssi_16--info {
    margin: 0 5px;
    color: #94B2C1; }

.n2_layer_window_design_preset__label {
  font-size: 12px;
  font-weight: bold;
  text-transform: uppercase;
  color: #94B2C1;
  max-width: 160px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_layer_window_design_preset__fields {
  display: flex; }

.n2_layer_window_design_preset__presets {
  display: none; }

.n2_layer_window_design_preset__button_choose {
  display: inline-flex;
  vertical-align: top;
  width: 30px;
  height: 30px;
  background-color: #04C018;
  border-radius: 2px;
  align-items: center;
  justify-content: center;
  font-size: 16px; }
  .n2_layer_window_design_preset__button_choose:HOVER {
    background-color: #07CA1C; }
  .n2_layer_window_design_preset__button_choose, .n2_layer_window_design_preset__button_choose:HOVER, .n2_layer_window_design_preset__button_choose:FOCUS {
    color: #FFFFFF; }

.n2_layer_window_design_preset__button_back {
  display: none;
  vertical-align: top;
  width: 30px;
  height: 30px;
  background-color: #6B7986;
  border-radius: 2px;
  align-items: center;
  justify-content: center;
  font-size: 16px; }
  .n2_layer_window_design_preset__button_back:HOVER {
    background-color: #8694A2; }
  .n2_layer_window_design_preset__button_back, .n2_layer_window_design_preset__button_back:HOVER, .n2_layer_window_design_preset__button_back:FOCUS {
    color: #FFFFFF; }

.n2_layer_window_design_preset__fields_secondary {
  display: inline-flex;
  vertical-align: top;
  margin: 0 10px; }

.n2_layer_window_design_preset__button_secondary {
  display: inline-flex;
  vertical-align: top;
  width: 30px;
  height: 30px;
  font-size: 16px;
  align-items: center;
  justify-content: center; }
  .n2_layer_window_design_preset__button_secondary, .n2_layer_window_design_preset__button_secondary:HOVER, .n2_layer_window_design_preset__button_secondary:FOCUS {
    color: #94B2C1; }

.n2_ss_layer_window--show-presets .n2_ss_layer_window__tab_panel:not([data-panel="item"]) {
  display: none; }

.n2_ss_layer_window--show-presets .n2_ss_design_layer_window_design .n2_fields_layer_window {
  display: none; }

.n2_ss_layer_window--show-presets .n2_layer_window_design_preset__fields_secondary,
.n2_ss_layer_window--show-presets .n2_layer_window_design_preset__button_choose {
  display: none; }

.n2_ss_layer_window--show-presets .n2_layer_window_design_preset__button_back {
  display: inline-flex; }

.n2_ss_layer_window--show-presets .n2_layer_window_design_preset {
  position: -webkit-sticky;
  position: sticky;
  top: 0; }

.n2_ss_layer_window--show-presets .n2_layer_window_design_preset__presets {
  display: block; }

.n2_fields_layer_window[data-fieldset-type="design"][data-state="0"] .n2_form__table_label_field[data-design-feature="reset-to-normal"] {
  display: none; }

.n2_fields_layer_window[data-fieldset-type="design"][data-elements="0"] {
  display: none; }

.n2_fields_layer_window[data-fieldset-type="design"][data-elements="1"] [data-design-feature="element"] {
  display: none; }

.n2_layer_window_design_preset__preset_list_preset {
  display: flex;
  padding: 5px 10px;
  background-color: #2C3A45;
  border-bottom: 1px solid #131c23;
  cursor: pointer; }
  .n2_layer_window_design_preset__preset_list_preset span {
    font-size: 12px;
    line-height: 30px;
    margin-right: auto;
    color: #BDCFD9; }
    html[dir="rtl"] .n2_layer_window_design_preset__preset_list_preset span {
      margin-right: 0;
      margin-left: auto; }

.n2_layer_window_design_preset__preset_list_preset_buttons {
  display: inline-flex; }

.n2_layer_window_design_preset__preset_list_preset_button {
  display: inline-flex;
  vertical-align: top;
  width: 30px;
  height: 30px;
  font-size: 16px;
  align-items: center;
  justify-content: center;
  cursor: pointer;
  color: #94B2C1; }

.n2_container_animation__buttons {
  display: flex;
  align-items: center;
  padding: 8px 10px;
  background-color: #0C1924; }

.n2_container_animation__button {
  flex: 1 1 0;
  padding: 6px 5px;
  color: #94B2C1;
  font-size: 12px;
  line-height: 16px;
  border-radius: 14px;
  text-align: center;
  text-transform: uppercase;
  cursor: pointer;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_container_animation__button--active {
  background-color: #1d81f9;
  color: #fff; }

.n2_container_animation__tab {
  display: none; }

.n2_container_animation__tab--active {
  display: block; }

.n2_layer_window_animations_presets__buttons {
  display: grid;
  grid-template-columns: repeat(4, 1fr);
  grid-gap: 10px;
  padding: 10px;
  background-color: #3A4956; }

.n2_layer_window_animations_presets__button {
  padding: 10px 8px 5px;
  border-radius: 3px;
  background-color: #6B7986;
  color: #FFFFFF;
  text-align: center;
  cursor: pointer; }
  .n2_layer_window_animations_presets__button .ssi_24 {
    margin-bottom: 5px;
    display: block; }

.n2_layer_window_animations_presets__button--active {
  background-color: #1D81F9; }

.n2_layer_window_animations_presets__button_label {
  font-size: 12px;
  line-height: 20px;
  max-width: 56px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_layer_window_animations_presets__presets {
  display: none; }

.n2_layer_window_animations_presets__presets--active {
  display: block; }

.n2_layer_window_animations_presets__preset {
  padding: 10px 20px;
  background-color: #2C3A45;
  border-bottom: 1px solid #1e2830;
  color: #94B2C1;
  font-size: 12px;
  line-height: 20px;
  cursor: pointer;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_layer_window_animations_editor .n2_fields_layer_window[data-field="fieldset-layer-window-layer-animation-basic-form-in"],
.n2_layer_window_animations_editor .n2_fields_layer_window[data-field="fieldset-layer-window-layer-animation-basic-form-loop"],
.n2_layer_window_animations_editor .n2_fields_layer_window[data-field="fieldset-layer-window-layer-animation-basic-form-out"] {
  display: none; }

.n2_layer_window_animations_editor--settings .n2_fields_layer_window[data-field="fieldset-layer-window-layer-animation-basic-form-in"],
.n2_layer_window_animations_editor--settings .n2_fields_layer_window[data-field="fieldset-layer-window-layer-animation-basic-form-loop"],
.n2_layer_window_animations_editor--settings .n2_fields_layer_window[data-field="fieldset-layer-window-layer-animation-basic-form-out"] {
  display: block; }

.n2_layer_window_animations_editor__title {
  display: flex;
  padding: 7px 0;
  background-color: #1C2933;
  border-bottom: 1px solid #131c23; }

.n2_layer_window_animations_editor__label {
  flex: 1 1 auto;
  font-size: 12px;
  line-height: 30px;
  color: #94B2C1; }

.n2_layer_window_animations_editor__title_left {
  padding: 0 10px; }

.n2_layer_window_animations_editor__button_play {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 30px;
  height: 30px;
  border-radius: 2px;
  background-color: #6B7986;
  font-size: 16px;
  color: #fff;
  cursor: pointer; }

.n2_layer_window_animations_editor__button_play--active {
  background-color: #1D81F9; }
  .n2_layer_window_animations_editor__button_play--active .ssi_16::before {
    content: "\E607"; }

.n2_layer_window_animations_editor__title_right {
  padding: 0 5px; }

.n2_layer_window_animations_editor__button_settings {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 30px;
  height: 30px;
  border-radius: 2px;
  font-size: 16px;
  color: #94B2C1;
  cursor: pointer; }

.n2_layer_window_animations_editor__button_settings--active {
  background-color: #1D81F9;
  color: #fff; }

.n2_layer_window_animations_editor__button_delete {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 30px;
  height: 30px;
  border-radius: 2px;
  font-size: 16px;
  color: #94B2C1;
  cursor: pointer; }

.n2_layer_window_animations_editor_basic {
  position: relative; }

.n2_layer_window_animations_editor_basic__keyframe.n2-ui-sortable-helper {
  width: 100%;
  opacity: 0.5; }

.n2_layer_window_animations_editor_basic__keyframe--sort .n2_fields_layer_window {
  display: none; }

.n2_layer_window_animations_editor_basic__keyframe_title {
  display: flex;
  padding: 5px 0;
  background-color: #2C3A45;
  border-bottom: 1px solid #1e2830;
  color: #94B2C1;
  font-size: 12px;
  line-height: 30px;
  cursor: pointer; }
  .n2_layer_window_animations_editor_basic__keyframe--active .n2_layer_window_animations_editor_basic__keyframe_title {
    background-color: #1D81F9;
    color: #fff; }
    .n2_layer_window_animations_editor_basic--single-keyframe .n2_layer_window_animations_editor_basic__keyframe--active .n2_layer_window_animations_editor_basic__keyframe_title {
      background-color: #2C3A45;
      color: #94B2C1;
      cursor: initial; }

.n2_layer_window_animations_editor_basic__keyframe_label {
  flex: 1 1 auto;
  padding: 0 20px;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis; }

.n2_layer_window_animations_editor_basic__keyframe_delete {
  margin: 0 5px;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 30px;
  height: 30px;
  border-radius: 2px;
  font-size: 16px;
  color: #94B2C1;
  cursor: pointer; }
  .n2_layer_window_animations_editor_basic__keyframe--active .n2_layer_window_animations_editor_basic__keyframe_delete {
    color: #fff; }
  .n2_layer_window_animations_editor_basic--single-keyframe .n2_layer_window_animations_editor_basic__keyframe_delete {
    display: none; }

.n2_layer_window_animations_editor_basic__add_keyframe {
  display: flex;
  justify-content: center;
  padding: 10px 0; }

.n2_layer_window_animations_editor_basic__button_add_keyframe {
  padding: 0 10px;
  background-color: #6B7986;
  border-radius: 3px;
  font-size: 11px;
  line-height: 30px;
  text-transform: uppercase;
  color: #FFFFFF;
  cursor: pointer; }
  .n2_layer_window_animations_editor_basic__button_add_keyframe:HOVER {
    background-color: #8694A2; }

[data-devicespecific] {
  position: relative; }

#n2-ss-devicespecific-settings {
  position: absolute;
  bottom: 40px;
  left: 0;
  margin: 0 10px;
  white-space: nowrap;
  z-index: 2;
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  grid-gap: 0;
  border-radius: 3px;
  overflow: hidden;
  background: #a1aeb5; }
  html[dir="rtl"] #n2-ss-devicespecific-settings {
    left: auto;
    right: 0; }

#n2-ss-devicespecific-settings * {
  cursor: pointer;
  background: #a1aeb5;
  display: inline-block;
  width: 20px;
  height: 20px;
  padding: 5px;
  line-height: 20px;
  text-align: center;
  font-size: 16px;
  color: #fff; }

body[data-device="desktopPortrait"] #n2-ss-devicespecific-settings .ssi_16--desktopportrait,
body[data-device="desktopLandscape"] #n2-ss-devicespecific-settings .ssi_16--desktoplandscape,
body[data-device="tabletPortrait"] #n2-ss-devicespecific-settings .ssi_16--tabletportrait,
body[data-device="tabletLandscape"] #n2-ss-devicespecific-settings .ssi_16--tabletportraitlarge,
body[data-device="mobilePortrait"] #n2-ss-devicespecific-settings .ssi_16--mobileportrait,
body[data-device="mobileLandscape"] #n2-ss-devicespecific-settings .ssi_16--mobileportraitlarge {
  background: #1d81f9; }

[data-placement="absolute"] [data-placement]:not([data-placement="absolute"]):not([data-placement="all"]),
[data-placement="content"] [data-placement]:not([data-placement="content"]):not([data-placement="all"]),
[data-placement="normal"] [data-placement]:not([data-placement="normal"]):not([data-placement="all"]),
[data-placement="default"] [data-placement]:not([data-placement="default"]):not([data-placement="all"]),
[data-placement=""] [data-placement] {
  display: none !important; }

.n2_layer_navigation {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  flex: 0 0 auto;
  visibility: visible;
  display: flex;
  overflow: hidden;
  max-height: 0;
  z-index: 2; }
  .n2_admin_editor_overlay--show-layer-navigation:not(.n2_admin_editor_overlay--show-add-more) .n2_layer_navigation {
    max-height: none;
    overflow: auto; }

.n2_layer_navigation_list {
  position: relative;
  width: 340px;
  flex: 0 0 auto;
  overflow-y: auto;
  overflow-x: hidden;
  background-color: #1c2933; }
  .n2_layer_navigation--has_timeline .n2_layer_navigation_list {
    overflow: hidden; }

.n2_layer_navigation_list_title {
  position: -webkit-sticky;
  position: sticky;
  top: 0;
  z-index: 2;
  display: flex;
  align-items: center;
  background-color: #0C1924;
  height: 48px; }

.n2_layer_navigation_list_title__hide {
  position: relative;
  z-index: 2;
  margin: 10px;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 30px;
  height: 30px;
  background-color: #1D81F9;
  border-radius: 2px;
  cursor: pointer;
  color: #fff;
  font-size: 16px; }

.n2_layer_navigation_list_title__label {
  z-index: 1;
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  text-align: center;
  cursor: ns-resize;
  font-size: 18px;
  line-height: 48px;
  color: #FFFFFF; }

.n2_layer_navigation_list_layers {
  position: relative; }

.n2_layer_navigation_list_layers__sortable_placeholder {
  position: relative;
  height: 0;
  z-index: 1001;
  box-shadow: 0 0 0 2px #1D81F9; }

.n2_layer_navigation_list_layer {
  position: relative; }

.n2_layer_navigation_list_layer__title {
  position: relative;
  display: flex;
  height: 32px;
  background-color: #1C2933;
  border-right: 1px solid #0C1924;
  border-bottom: 1px solid #0C1924;
  color: #94B2C1;
  cursor: pointer; }
  .n2_layer_navigation_list_layer__title[data-rows="2"] {
    height: 64px; }
  .n2_layer_navigation_list_layer__title:HOVER {
    background-color: #0C1924;
    border-bottom: 1px solid #0C1924; }
  .n2_layer_navigation_list_layer--active > .n2_layer_navigation_list_layer__title {
    background-color: #1D81F9;
    border-color: #1D81F9;
    color: #fff; }
  .n2_layer_navigation_list_layer--absolute.n2_layer_navigation_list_layer--active > .n2_layer_navigation_list_layer__title {
    background-color: #5f39c2;
    border-color: #5f39c2;
    color: #fff; }
    .n2_layer_navigation_list_layer--absolute.n2_layer_navigation_list_layer--active > .n2_layer_navigation_list_layer__title .n2_layer_navigation_list_layer__title_label_icon {
      color: #fff; }
  .n2_layer_navigation_list_layer--drop > .n2_layer_navigation_list_layer__title {
    background: #0c1924;
    border-color: #0c1924; }

.n2_layer_navigation_list_layer__title_label {
  flex: 1 1 auto;
  display: flex;
  align-items: center;
  line-height: 32px;
  padding-left: 10px;
  overflow: hidden; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__title_label {
  padding-left: 20px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layers__sortable_placeholder {
  margin-left: 30px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__title_label {
  padding-left: 30px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layers__sortable_placeholder {
  margin-left: 40px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__title_label {
  padding-left: 40px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layers__sortable_placeholder {
  margin-left: 50px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__title_label {
  padding-left: 50px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layers__sortable_placeholder {
  margin-left: 60px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__title_label {
  padding-left: 60px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layers__sortable_placeholder {
  margin-left: 70px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__title_label {
  padding-left: 70px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layers__sortable_placeholder {
  margin-left: 80px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__title_label {
  padding-left: 80px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layers__sortable_placeholder {
  margin-left: 90px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__title_label {
  padding-left: 90px; }

.n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layers__sortable_placeholder {
  margin-left: 100px; }

.n2_layer_navigation_list_layer__title_label_icon {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  margin: 0 3px;
  width: 20px;
  height: 20px;
  font-size: 16px; }
  .n2_layer_navigation_list_layer__title_label_icon[data-action="hide-show"]:HOVER .ssi_16::before {
    content: "\E60F"; }
  .n2_layer_navigation_list_layer__title--hidden > .n2_layer_navigation_list_layer__title_label .n2_layer_navigation_list_layer__title_label_icon .ssi_16::before {
    content: "\E923"; }

.n2_layer_navigation_list_layer__title_label_folder {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 12px;
  height: 12px;
  font-size: 16px;
  cursor: pointer;
  opacity: 0.5; }
  .n2_layer_navigation_list_layer__title_label_folder .ssi_16::before {
    content: "\E19E"; }
  .n2_layer_navigation_list_layer__children .n2_layer_navigation_list_layer__title_label_folder {
    margin-left: -12px; }
  .n2_layer_navigation_list_layer__title_label_folder:HOVER {
    opacity: 1; }
  .n2_layer_navigation_list_layer--closed .n2_layer_navigation_list_layer__title_label_folder .ssi_16::before {
    content: "\E19D"; }

.n2_layer_navigation_list_layer__title_label_text {
  font-size: 12px;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  max-width: 180px;
  text-transform: capitalize;
  font-weight: bold; }
  .n2_layer_navigation_list_layer__title_label_text[contenteditable="true"]:focus {
    text-overflow: initial;
    cursor: initial; }
  .n2_layer_navigation_list_layer__title_label_text::selection {
    background: rgba(255, 255, 255, 0.99);
    color: #1d81f9; }

.n2_layer_navigation_list_layer__title_actions {
  display: flex;
  align-items: center;
  padding: 0 5px; }

.n2_layer_navigation_list_layer__title_action {
  margin: 3px;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 20px;
  height: 20px;
  font-size: 16px;
  cursor: pointer; }

.n2_layer_navigation_list_layer__title_label_rename {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 12px;
  height: 32px;
  opacity: 0.5;
  cursor: pointer; }
  .n2_layer_navigation_list_layer__title_label_rename:HOVER {
    opacity: 1; }

.n2_layer_navigation_list_layer__title--hidden .n2_layer_navigation_list_layer__title_action_hide .ssi_16::before {
  content: "\E923"; }

.n2_ss_layer_window .n2_layer_navigation_list_layer__title_action--add-animation,
.n2_layer_navigation_list_layer__title--has-animations .n2_layer_navigation_list_layer__title_action--add-animation {
  display: none; }

.n2_ss_layer_window .n2_layer_navigation_list_layer__title_action--remove-animation,
.n2_layer_navigation_list_layer__title:not(.n2_layer_navigation_list_layer__title--has-animations) .n2_layer_navigation_list_layer__title_action--remove-animation {
  display: none; }

.n2_layer_navigation_list_layer__title_absolute_marker {
  margin: 2px;
  width: 16px;
  height: 16px;
  background-color: #5F39C2;
  border-radius: 2px;
  text-align: center;
  font-size: 12px;
  line-height: 16px;
  color: #FFFFFF;
  font-weight: bold; }

.n2_layer_navigation_list_layer--sorted {
  position: absolute;
  left: 0;
  width: 100%;
  overflow: hidden;
  opacity: 0.7; }

.n2_timeline {
  position: relative;
  flex: 1 1 auto;
  overflow: scroll;
  background: #1c2933; }

.n2_timeline__inner_pane {
  display: flex;
  flex-flow: column; }

.n2_timeline__inner_pane--calculate-duration {
  width: auto !important; }

.n2_timeline__time_frames {
  position: -webkit-sticky;
  position: sticky;
  top: 0;
  z-index: 100000;
  display: flex;
  height: 48px;
  background-color: #0C1924;
  padding-left: 21px; }
  .n2_timeline__inner_pane--calculate-duration .n2_timeline__time_frames {
    width: 0;
    overflow: hidden; }

.n2_timeline__cti {
  position: absolute;
  left: -10px;
  top: 3px;
  z-index: 100001;
  width: 0;
  height: 1000%;
  border-left: 1px solid RGBA(230, 182, 37, 0.5);
  margin-left: 21px;
  cursor: ew-resize; }

.n2_timeline__cti_dot {
  position: relative;
  left: -6px;
  top: 0;
  width: 11px;
  height: 11px;
  border-radius: 0 50% 50% 50%;
  transform: rotate(-135deg);
  background-color: #E6B625; }

.n2_timeline__time_frames_overlay {
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  z-index: 2;
  display: flex; }
  .n2_timeline__time_frames_overlay svg {
    flex: 1 1 auto;
    margin-left: 19px;
    height: 48px;
    color: #3a454e; }

.n2_timeline__one_second {
  flex: 0 0 auto;
  position: relative;
  width: 195px;
  height: 100%;
  padding-left: 5px;
  font-size: 12px;
  line-height: 48px;
  color: #94B2C1; }

.n2_timeline_layer__animations {
  display: flex;
  height: 32px;
  padding-left: 20px;
  background-color: #1c2933;
  border-bottom: 1px solid rgba(0, 0, 0, 0.2); }
  .n2_timeline_layer__animations[data-rows="2"] {
    height: 64px; }
  .n2_timeline_layer__animations.n2_timeline_layer__animations--repeated.n2_timeline_layer__animations--has-animation {
    padding-left: 0; }

.n2_timeline_layer__animations--active {
  background-color: #0C1924; }

.n2_timeline_animation_repeat {
  position: relative;
  display: none;
  align-items: center;
  justify-content: flex-end;
  line-height: 32px;
  font-size: 12px;
  color: #fff;
  cursor: ew-resize;
  padding: 0 5px; }
  .n2_timeline_animation_repeat:after {
    position: absolute;
    top: 50%;
    margin-top: -5px;
    display: block;
    content: '';
    width: 10px;
    height: 10px;
    border-radius: 10px;
    background-color: rgba(255, 255, 255, 0.3); }

.n2_timeline_animation_repeat--start {
  margin-left: -20px;
  padding: 0 20px; }
  .n2_timeline_animation_repeat--start:after {
    right: 5px; }

.n2_timeline_animation_repeat--end {
  margin-left: -10px; }
  .n2_timeline_animation_repeat--end:after {
    right: -15px; }

.n2_timeline_layer__animations.n2_timeline_layer__animations--repeated.n2_timeline_layer__animations--has-animation .n2_timeline_animation_repeat {
  display: flex;
  flex-shrink: 0; }

.n2_timeline_layer__animations.n2_timeline_layer__animations--repeated.n2_timeline_layer__animations--has-animation .n2_timeline_animation_group,
.n2_timeline_layer__animations.n2_timeline_layer__animations--repeated.n2_timeline_layer__animations--has-animation .n2_timeline_animation_repeat--end {
  background-color: #3A4956; }

.n2_timeline_animation_group__row {
  display: flex; }

.nui_resize_bar__handle {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  z-index: 90;
  position: absolute;
  top: 0;
  width: 18px; }
  .nui_resize_bar__handle:after {
    margin: 4px;
    display: block;
    content: '';
    width: 10px;
    height: 10px;
    border-radius: 10px;
    background-color: RGBA(0, 0, 0, 0.5); }

.nui_resize_bar__handle--e {
  cursor: e-resize;
  right: 0; }

.nui_resize_bar__handle--w {
  cursor: w-resize;
  left: 0; }

.n2_timeline_animation_bar {
  position: relative;
  height: 18px;
  margin: 7px 0;
  border-radius: 10px;
  cursor: ew-resize;
  z-index: 90; }
  .n2_timeline_animation_bar:HOVER {
    z-index: 90; }

.n2_timeline_animation_bar--in {
  background-color: #1D81F9; }

.n2_timeline_animation_bar--loop {
  background-color: #04C018; }

.n2_timeline_animation_bar--out {
  background-color: #6B7986; }

.n2_timeline_animation_bar--extra {
  background-color: #6B7986; }

.n2_timeline_animation_bar__delay {
  position: absolute;
  line-height: 18px;
  text-align: right;
  right: 100%;
  margin-right: 5px;
  font-size: 11px;
  color: #fff; }

.n2_timeline_animation_bar__delay--small {
  display: none; }

.n2_timeline_animation_bar__duration {
  margin: 0 7px;
  line-height: 18px;
  text-align: center;
  cursor: ew-resize;
  overflow: hidden;
  text-overflow: ellipsis;
  white-space: nowrap;
  font-size: 11px;
  color: #FFFFFF;
  text-transform: uppercase; }

.n2_timeline_layer--closed .n2_timeline_layer__children {
  display: none; }

.n2_timeline_overlay_playing {
  display: none;
  position: fixed;
  width: 100%;
  height: 100%;
  left: 0;
  top: 0;
  z-index: 9999;
  cursor: pointer; }

.n2_body--timeline-preview .n2_timeline_overlay_playing {
  display: block; }

.n2_body--timeline-preview .n2_ss_layer_window {
  display: none !important; }

.n2_body--timeline-preview #n2-ss-0 .n2-ss-layer {
  cursor: default; }

.n2_body--timeline-preview #n2-ss-slide-canvas-container #n2-ss-0 .n2-ss-layer .nui_resize_normal__handle {
  display: none !important; }

#n2-ss-0[data-responsive="fullpage"] {
  min-height: 0 !important; }

#n2-ss-0 {
  box-shadow: 0 3px 10px 0 rgba(0, 0, 0, 0.1); }
  #n2-ss-0 .n2-ss-widget {
    pointer-events: none;
    opacity: 0.5 !important; }

#n2-ss-0-align {
  margin: 0 !important; }

body:not(.n2-ss-slider-visible) #n2-ss-0 .n2-ss-layer {
  opacity: 0 !important; }

.n2_slide_editor_slider {
  position: relative;
  z-index: 1;
  /**
  @see https://stackoverflow.com/questions/58100020/force-flex-element-to-adjust-self-width-to-their-childrens-width
   */
  display: inline-flex;
  align-items: flex-start;
  min-width: 100%;
  min-height: calc(100vh - 60px);
  padding-bottom: 100px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.n2_slide_editor_slider__editor {
  position: relative; }

.n2_slide_editor_slider__editor_inner {
  position: relative;
  background: #f0f4f7;
  box-shadow: 0 2px 20px rgba(0, 0, 0, 0.2); }

div#n2-ss-0:HOVER .n2-ss-static-slide:not(.n2-ss-currently-edited-slide) {
  visibility: hidden;
  z-index: -1; }

div div#n2-ss-0 .n2-ss-static-slide div[data-sstype="slide"],
div div#n2-ss-0 .n2-ss-static-slide div[data-sstype="content"],
div div#n2-ss-0 .n2-ss-static-slide div[data-sstype="content"] div.n2-ss-section-main-content {
  visibility: visible; }

.n2_ruler {
  display: none;
  z-index: 1;
  position: absolute;
  left: 0;
  top: 0;
  height: 100%;
  width: 100%;
  direction: ltr;
  overflow: hidden;
  cursor: pointer;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }
  html[dir="rtl"] .n2_ruler {
    left: auto;
    right: 0; }
  .n2_body--ruler .n2_ruler {
    display: block; }

.n2_ruler_mark {
  flex: 0 0 auto;
  position: relative;
  vertical-align: top; }

.n2_ruler_mark__label {
  position: absolute;
  display: block;
  font-size: 9px;
  color: #325c77;
  line-height: 12px; }

.n2_ruler--vertical {
  top: 14px;
  height: calc(100% - 14px); }
  .n2_ruler--vertical .n2_ruler__inner {
    width: 14px;
    visibility: visible;
    position: relative;
    background: #fff;
    border-right: 1px solid #94B2C1; }
  .n2_ruler--vertical .n2_ruler_mark {
    width: 3px;
    height: 9px;
    border-top: 1px solid #94B2C1; }
  .n2_ruler--vertical .n2_ruler_mark--small {
    left: 11px; }
  .n2_ruler--vertical .n2_ruler_mark--large {
    width: 100%; }
  .n2_ruler--vertical .n2_ruler_mark__label {
    left: 0;
    top: 2px;
    writing-mode: vertical-rl;
    -ms-writing-mode: tb-rl;
    /* for IE */
    -webkit-writing-mode: vertical-rl;
    /* for Webkit */
    -webkit-text-orientation: upright;
    text-orientation: upright; }

.n2_ruler--horizontal {
  left: 14px;
  width: calc(100% - 14px); }
  .n2_ruler--horizontal .n2_ruler__inner {
    visibility: visible;
    height: 14px;
    position: relative;
    display: inline-flex;
    vertical-align: top;
    flex-wrap: nowrap;
    direction: ltr;
    background: #fff;
    border-bottom: 1px solid #94B2C1; }
  .n2_ruler--horizontal .n2_ruler_mark {
    width: 9px;
    height: 3px;
    border-left: 1px solid #94B2C1; }
  .n2_ruler--horizontal .n2_ruler_mark--small {
    top: 11px; }
  .n2_ruler--horizontal .n2_ruler_mark--large {
    height: 100%; }
  .n2_ruler--horizontal .n2_ruler_mark__label {
    left: 2px;
    top: 0; }

.n2_ruler__guide {
  visibility: hidden;
  position: absolute;
  left: 0;
  top: 0;
  z-index: 2; }
  .n2_ruler--vertical .n2_ruler__guide {
    width: 100%;
    height: 0; }
  .n2_ruler--horizontal .n2_ruler__guide {
    width: 0;
    height: 100%; }

.n2_ruler__guide--measure {
  z-index: 1; }

.n2_ruler__guide_border {
  visibility: visible;
  pointer-events: none; }
  .n2_ruler--vertical .n2_ruler__guide_border {
    border-bottom: 1px solid #ccaa2b;
    width: 100%; }
  .n2_ruler--horizontal .n2_ruler__guide_border {
    border-right: 1px solid #ccaa2b;
    height: 100%; }
  .n2_ruler__guide--measure .n2_ruler__guide_border {
    border-color: #f00; }

.n2_ruler__guide_handle {
  visibility: visible;
  position: absolute;
  left: 0;
  top: 0;
  background: #e6b625;
  width: 9px;
  height: 9px;
  color: #fff;
  font-size: 9px;
  line-height: 9px;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center; }
  .n2_ruler__guide_handle .ssi_16 {
    font-size: 9px !important; }
  .n2_ruler--vertical .n2_ruler__guide_handle {
    top: -4px; }
  .n2_ruler--horizontal .n2_ruler__guide_handle {
    left: -4px; }

.n2_ruler_corner {
  display: block;
  position: absolute;
  left: 0;
  top: 0;
  width: 14px;
  height: 14px;
  border-right: 1px solid #94B2C1;
  border-bottom: 1px solid #94B2C1;
  visibility: visible;
  background: #ffffff;
  cursor: pointer; }

/**
Mouse over on the closest layer
 */
.n2_layer_contextual_hover_layer::after,
.n2_layer_context_menu_target::after,
.n2_layer_col_highlight::after,
.n2_layer_highlight_row_structure::after {
  display: block !important;
  content: '';
  z-index: 10;
  position: absolute;
  left: 0;
  top: 0;
  box-sizing: border-box !important;
  width: 100%;
  height: 100%;
  border: 2px solid #6B7986;
  pointer-events: none; }

.n2_layer_contextual_hover_layer[data-pm="absolute"]::after,
.n2_layer_context_menu_target[data-pm="absolute"]::after,
.n2_layer_col_highlight[data-pm="absolute"]::after,
.n2_layer_highlight_row_structure[data-pm="absolute"]::after {
  display: block !important;
  content: '';
  z-index: 10;
  position: absolute;
  left: 0;
  top: 0;
  box-sizing: border-box !important;
  width: 100%;
  height: 100%;
  border: 2px solid #5f39c2;
  pointer-events: none; }

/**
Active layer
 */
.n2_layer_contextual_active_layer::after,
.nui_resize_absolute--resizing::after,
.n2_layer_resize_snap_to::after,
.n2_layer_drag__dragging::after,
.n2_layer_drag_snap_to::after,
.n2_layer_parent_highlight::after {
  display: block !important;
  content: '';
  z-index: 10;
  position: absolute;
  left: 0;
  top: 0;
  box-sizing: border-box !important;
  width: 100%;
  height: 100%;
  border: 2px solid #1d81f9;
  pointer-events: none; }

.n2_layer_contextual_active_layer[data-pm="absolute"]::after,
.nui_resize_absolute--resizing[data-pm="absolute"]::after,
.n2_layer_resize_snap_to[data-pm="absolute"]::after,
.n2_layer_drag__dragging[data-pm="absolute"]::after,
.n2_layer_drag_snap_to[data-pm="absolute"]::after,
.n2_layer_parent_highlight[data-pm="absolute"]::after {
  display: block !important;
  content: '';
  z-index: 10;
  position: absolute;
  left: 0;
  top: 0;
  box-sizing: border-box !important;
  width: 100%;
  height: 100%;
  border: 2px solid #5f39c2;
  pointer-events: none; }

.n2_layer_drag__dragging {
  opacity: 0.5; }

/**
 When normal layer dragged, the possible target groups highlighted
 */
.n2_layer_drag_target_groups[data-sstype="content"]::after, .n2_layer_drag_target_groups[data-sstype="col"]::after {
  display: block !important;
  content: '';
  z-index: 10;
  position: absolute;
  left: 0;
  top: 0;
  box-sizing: border-box !important;
  width: 100%;
  height: 100%;
  border: 2px solid #6B7986;
  pointer-events: none; }

/**
Hide the layer until created
 */
.n2_layer--creation-in-progress,
.n2_layer--creation-in-progress * {
  visibility: hidden !important; }

.n2_admin_editor__content--hover .n2-ss-layer-content .n2-ss-layer.n2-active {
  z-index: 10; }

/**
Make overflow visible on active layer
*/
.n2_admin_editor__content--hover .n2-ss-layer.n2-active {
  overflow: visible !important; }

/**
Minimum height for content in the editor
 */
.n2-ss-section-main-content {
  min-height: 20px; }

/**
Minimum height for rows in the editor
 */
.n2-ss-layer-row .n2-ss-layer-content {
  min-height: 20px; }

/**
Make layers temporary hidden
 */
[data-visibility="hidden"],
[data-visibility="hidden"] * {
  visibility: hidden !important;
  transition: none !important; }

.n2_admin_editor__content--hover .n2-ss-layer.n2-active {
  z-index: 9999999 !important; }

.n2_layer_layer_list_hover--force-zindex {
  z-index: 9999999 !important; }

.n2-ss-layer-placeholder {
  display: block;
  position: relative;
  width: 100%;
  height: 0;
  z-index: 11; }
  .n2-ss-layer-placeholder::after {
    display: block !important;
    content: '';
    position: absolute;
    left: 0;
    top: -3px;
    box-sizing: border-box !important;
    width: 100%;
    border: 3px solid #1d81f9; }

.n2_smartguide {
  background: #4affff;
  position: absolute;
  left: 0;
  top: 0;
  z-index: 1000000;
  display: none; }

.n2_smartguide--horizontal {
  width: 100%;
  height: 1px; }

.n2_smartguide--vertical {
  height: 100%;
  width: 1px; }

.n2-ss-currently-edited-slide .n2-ss-layer[data-sstype="col"],
.n2-ss-currently-edited-slide .n2-ss-layer[data-sstype="col"] .n2-ss-layer {
  cursor: pointer; }

/**
Column width handle
 */
.ui-column-width-handle {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  display: none;
  position: absolute;
  top: 25%;
  height: 50%;
  cursor: ew-resize;
  width: 5px;
  background: #1d81f9;
  z-index: 88;
  opacity: 0.5;
  box-sizing: border-box !important;
  border-radius: 5px; }

.ui-column-width-handle--visible {
  display: block; }

.n2-ss-layer:not(.n2-ss-layer--block) > .n2-ss-layer-row > .ui-column-width-handle,
.n2-ss-layer-row[data-row-wrapped="1"] > .ui-column-width-handle {
  display: none !important; }

#n2-ss-0 .n2-ss-layer {
  cursor: not-allowed; }

#n2-ss-0 .n2-ss-currently-edited-slide .n2-ss-layer {
  cursor: pointer; }

/**
While dragging a layer with normal position
*/
div#n2-ss-0 .n2-ss-layer[data-sstype="content"] .n2-ss-layer.nui-draggable-dragging,
div#n2-ss-0 .n2-ss-layer[data-sstype="col"] .n2-ss-layer.nui-draggable-dragging {
  z-index: 100000;
  outline: 0 !important; }

/**
Fade out not edited slides for carousel and showcase type
*/
#n2-ss-0 .n2-ss-slide:not(.n2-ss-currently-edited-slide) {
  opacity: 0.3; }

/**
Resize normal
 */
.nui_resize_normal__handle {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  position: absolute;
  z-index: 90;
  display: none;
  border: 2px solid #1d81f9;
  height: 6px;
  width: 6px;
  background: #fff;
  border-radius: 50px;
  transform-origin: 50% 50%; }
  .nui_resize_normal__handle:HOVER {
    transform: scale(1.5); }
  .nui_resize_normal__handle.nui-enabled {
    display: block; }

.nui_resize_normal__handle--none {
  border-color: #6B7986; }

.nui_resize_normal__handle--e {
  cursor: e-resize;
  right: -4px;
  top: 50%;
  margin-top: -4px; }

.nui_resize_normal__handle--w {
  cursor: w-resize;
  left: -4px;
  top: 50%;
  margin-top: -4px; }

.nui_resize_normal__handle--s {
  cursor: s-resize;
  bottom: -4px;
  left: 50%;
  margin-left: -4px; }

/**
Normal spacing
 */
.nui_spacing__handle {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  position: absolute;
  display: block;
  z-index: 89;
  background: #1d81f9;
  overflow: hidden;
  opacity: 0; }
  .nui_spacing__handle.nui-enabled {
    opacity: 0.5; }

.nui_spacing__handle--zero {
  background: #6B7986; }

.nui_spacing__handle--negative {
  background: #BE331F; }

.nui_spacing__handle:HOVER.nui-enabled,
.nui_spacing__handle--spacing.nui-enabled {
  opacity: 0.8; }

.nui_spacing__handle--n.nui_spacing__handle.nui-enabled {
  min-height: 5px;
  cursor: s-resize; }

.nui_spacing__handle--n.nui_spacing__handle--padding {
  top: 0;
  margin-left: 0;
  left: 25%;
  width: 50%; }

.nui_spacing__handle--n.nui_spacing__handle--margin {
  left: 0;
  bottom: 100%;
  width: 100%; }

.nui_spacing__handle--e.nui_spacing__handle.nui-enabled {
  min-width: 5px;
  cursor: w-resize; }

.nui_spacing__handle--e.nui_spacing__handle--padding {
  top: 25%;
  margin-top: 0;
  right: 0;
  height: 50%; }

.nui_spacing__handle--e.nui_spacing__handle--margin {
  top: 0;
  left: 100%;
  height: 100%; }

.nui_spacing__handle--s.nui_spacing__handle.nui-enabled {
  min-height: 5px;
  cursor: n-resize; }

.nui_spacing__handle--s.nui_spacing__handle--padding {
  bottom: 0;
  margin-left: 0;
  left: 25%;
  width: 50%; }

.nui_spacing__handle--s.nui_spacing__handle--margin {
  bottom: auto;
  top: 100%;
  left: 0;
  width: 100%; }

.nui_spacing__handle--w.nui_spacing__handle.nui-enabled {
  min-width: 5px;
  cursor: e-resize; }

.nui_spacing__handle--w.nui_spacing__handle--padding {
  top: 25%;
  margin-top: 0;
  left: 0;
  height: 50%; }

.nui_spacing__handle--w.nui_spacing__handle--margin {
  left: auto;
  right: 100%;
  top: 0;
  height: 100%; }

.n2-ss-layer.n2_layer_contextual_hover_layer:not(.n2-active) > .nui_spacing__handle--margin,
.n2-ss-layer.n2_layer_contextual_hover_layer:not(.n2-active) > .nui_spacing__handle--padding,
.n2-ss-layer.n2_layer_contextual_hover_layer:not(.n2-active) > div > .nui_spacing__handle--padding {
  display: block;
  min-width: 0;
  min-height: 0;
  /* pointer-events: none;*/
  background: #6B7986;
  opacity: 0.5; }

#n2-ss-0 .n2-ss-layer {
  cursor: not-allowed; }

#n2-ss-0 .n2-ss-currently-edited-slide .n2-ss-layer {
  cursor: pointer; }

/**
While dragging a layer with normal position
*/
div#n2-ss-0 .n2-ss-layer[data-sstype="content"] .n2-ss-layer.nui-draggable-dragging,
div#n2-ss-0 .n2-ss-layer[data-sstype="col"] .n2-ss-layer.nui-draggable-dragging {
  z-index: 100000;
  outline: 0 !important; }

.n2-ss-currently-edited-slide .n2-ss-layer[data-sstype="col"],
.n2-ss-currently-edited-slide .n2-ss-layer[data-sstype="col"] .n2-ss-layer {
  cursor: pointer; }

/**
Column width handle
 */
.ui-column-width-handle {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  display: none;
  position: absolute;
  top: 25%;
  height: 50%;
  cursor: ew-resize;
  width: 5px;
  background: #1d81f9;
  z-index: 88;
  opacity: 0.5;
  box-sizing: border-box !important;
  border-radius: 5px; }

.ui-column-width-handle--visible {
  display: block; }

.n2-ss-layer:not(.n2-ss-layer--block) > .n2-ss-layer-row > .ui-column-width-handle,
.n2-ss-layer-row[data-row-wrapped="1"] > .ui-column-width-handle {
  display: none !important; }

.n2-ss-layer-cc,
.nui_resize_absolute__handle {
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  position: absolute;
  z-index: 90;
  display: none;
  border: 2px solid #5f39c2;
  height: 6px;
  width: 6px;
  background: #fff;
  border-radius: 50px;
  transform-origin: 50% 50%; }
  .n2-ss-layer-cc:HOVER,
  .nui_resize_absolute__handle:HOVER {
    transform: scale(1.5); }
  .n2-ss-layer-cc.nui-enabled,
  .nui_resize_absolute__handle.nui-enabled {
    display: block; }

.n2-ss-layer-cc {
  opacity: 0;
  left: 50%;
  top: 50%;
  margin-top: -5px;
  margin-left: -5px; }
  .n2-ss-layer-cc:HOVER {
    opacity: 1; }

.n2-ss-layer[data-align="left"][data-valign="top"] .nui_resize_absolute__handle--nw,
.n2-ss-layer[data-align="left"][data-valign="middle"] .nui_resize_absolute__handle--w,
.n2-ss-layer[data-align="left"][data-valign="bottom"] .nui_resize_absolute__handle--sw,
.n2-ss-layer[data-align="center"][data-valign="top"] .nui_resize_absolute__handle--n,
.n2-ss-layer[data-align="center"][data-valign="middle"] .n2-ss-layer-cc,
.n2-ss-layer[data-align="center"][data-valign="bottom"] .nui_resize_absolute__handle--s,
.n2-ss-layer[data-align="right"][data-valign="top"] .nui_resize_absolute__handle--ne,
.n2-ss-layer[data-align="right"][data-valign="middle"] .nui_resize_absolute__handle--e,
.n2-ss-layer[data-align="right"][data-valign="bottom"] .nui_resize_absolute__handle--se {
  background: #5f39c2;
  opacity: 1;
  border: 2px solid #fff; }

.nui_resize_absolute__handle--e {
  cursor: e-resize;
  right: -4px;
  top: 50%;
  margin-top: -5px; }

.nui_resize_absolute__handle--w {
  cursor: w-resize;
  left: -4px;
  top: 50%;
  margin-top: -5px; }

.nui_resize_absolute__handle--n {
  cursor: n-resize;
  left: 50%;
  top: -4px;
  margin-left: -5px; }

.nui_resize_absolute__handle--ne {
  cursor: ne-resize;
  right: -4px;
  top: -4px; }

.nui_resize_absolute__handle--nw {
  cursor: nw-resize;
  left: -4px;
  top: -4px; }

.nui_resize_absolute__handle--s {
  cursor: s-resize;
  bottom: -4px;
  left: 50%;
  margin-left: -5px; }

.nui_resize_absolute__handle--se {
  cursor: se-resize;
  right: -4px;
  bottom: -4px; }

.nui_resize_absolute__handle--sw {
  cursor: sw-resize;
  left: -4px;
  bottom: -4px; }

/**
Item overlay
 */
.n2-ss-item-overlay {
  display: none;
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%; }

.n2-ss-item-html .n2-ss-item-overlay,
.n2-ss-item-iframe .n2-ss-item-overlay {
  display: block; }

/**
Item specific things
 */
.n2-ss-item {
  position: relative;
  float: left;
  width: 100%; }

.n2-ss-item-video,
.n2-ss-item-youtube,
.n2-ss-item-vimeo,
.n2-ss-item-area,
.n2-ss-item-imagearea {
  height: 100%; }

.n2_ss_absolute_parent_picker {
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 30px;
  height: 30px;
  background: #6b7986;
  border-radius: 3px;
  cursor: pointer;
  line-height: 30px;
  color: #fff; }
  .n2_ss_absolute_parent_picker .ssi_16::before {
    content: "\E64D"; }
  .n2_ss_absolute_parent_picker:HOVER {
    background-color: #8694A2; }

.n2_ss_absolute_parent_picker--active {
  background: #1D81F9; }
  .n2_ss_absolute_parent_picker--active .ssi_16::before {
    content: "\E64B"; }
  .n2_ss_absolute_parent_picker--active:HOVER {
    background-color: #338EF9; }

.n2_ss_absolute_parent_picker__overlay {
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%;
  z-index: 1000000;
  box-shadow: inset 0 0 0 1px rgba(0, 0, 0, 0.8);
  cursor: pointer;
  background: #5f39c2;
  opacity: 0.5; }

.n2_ss_absolute_parent_picker__overlay--tile {
  width: 33%;
  height: 33%; }

.n2_ss_absolute_parent_picker__overlay:HOVER,
.n2_ss_absolute_parent_picker__overlay--selected {
  opacity: 1; }

.n2_ss_absolute_parent_picker__component--focused {
  z-index: 2147483647 !important; }

.n2_field_generator_data_button {
  position: absolute;
  right: -2px;
  top: -26px;
  z-index: 10;
  display: inline-flex;
  align-items: center;
  padding: 0 5px;
  background-color: #1D81F9;
  border-radius: 3px;
  color: #fff;
  cursor: pointer; }
  .n2_field_generator_data_button:HOVER {
    background-color: #338EF9; }

.n2_field_generator_data_button_icon {
  flex: 0 0 auto;
  display: flex;
  align-items: center;
  justify-content: center; }

.n2_field_generator_data_button_label {
  padding: 0 2px;
  font-size: 10px;
  line-height: 22px;
  font-weight: bold;
  text-transform: uppercase; }

.n2_layer_contextual {
  display: none;
  position: absolute;
  z-index: 8;
  height: 28px;
  margin-top: -28px; }

.n2_layer_contextual--hover-section {
  z-index: 7;
  opacity: 0.7; }

.n2_layer_contextual--hover {
  z-index: 9; }
  .n2_layer_contextual--hover.n2_layer_contextual--hover-active {
    visibility: hidden;
    pointer-events: none; }

.n2_layer_contextual--visible {
  display: inline-flex; }

.n2_layer_contextual__inner {
  display: inline-flex;
  background-color: #1d81f9;
  border-top-left-radius: 3px;
  border-top-right-radius: 3px;
  line-height: 30px;
  overflow: hidden; }
  .n2_layer_contextual--invert .n2_layer_contextual__inner {
    border-radius: 0 0 3px 3px; }

.n2_layer_contextual__label {
  padding: 0 6px;
  font-size: 12px;
  line-height: 30px;
  text-transform: uppercase;
  color: #fff;
  cursor: pointer;
  max-width: 100px;
  text-overflow: ellipsis;
  overflow: hidden;
  white-space: nowrap; }

.n2_layer_contextual__button {
  height: 28px;
  padding: 0 6px;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  color: #fff;
  cursor: pointer; }

.n2_layer_contextual__button--active {
  background: #1167CD; }

.n2_layer_contextual[data-color="purple"] .n2_layer_contextual__inner {
  background-color: #5f39c2; }

.n2_layer_contextual[data-color="purple"] .n2_layer_contextual__button--active {
  background-color: #4C2D9B; }

.n2_layer_contextual[data-color="grey"] .n2_layer_contextual__inner {
  background-color: #6B7986; }

.n2_layer_contextual__button--responsive-tools {
  display: none; }

body:not([data-device="desktopPortrait"]) .n2_layer_contextual--has-responsive-tools .n2_layer_contextual__button--responsive-tools {
  display: inline-flex; }

.n2_layer_contextual_responsive_tools {
  display: flex;
  height: 30px; }
  .n2_layer_contextual_responsive_tools .ssi_16 {
    display: block;
    padding: 0 5px;
    color: #94b2c1; }

.n2_layer_contextual_responsive_tools__hide {
  padding: 7px 0;
  cursor: pointer; }
  .n2_layer_contextual_responsive_tools__hide .ssi_16::before {
    content: "\E60F"; }

.n2_layer_contextual_responsive_tools__hide--hidden .ssi_16::before {
  content: "\E923"; }

.n2_layer_contextual_responsive_tools__text_scale {
  display: flex; }
  .n2_layer_contextual_responsive_tools__text_scale input {
    margin: 0;
    padding: 0;
    height: 30px;
    line-height: 30px;
    font-size: 12px;
    color: #325c77;
    text-align: right; }
    .n2_layer_contextual_responsive_tools__text_scale input, .n2_layer_contextual_responsive_tools__text_scale input:FOCUS {
      box-shadow: none;
      outline: 0;
      border: 0; }
    .n2_layer_contextual_responsive_tools__text_scale input::-webkit-inner-spin-button, .n2_layer_contextual_responsive_tools__text_scale input::-webkit-outer-spin-button {
      -webkit-appearance: none;
      margin: 0; }
    .n2_layer_contextual_responsive_tools__text_scale input[type="number"] {
      -moz-appearance: textfield; }
  .n2_layer_contextual_responsive_tools__text_scale .nui-slider {
    position: relative;
    background-color: #94B2C1;
    height: 6px;
    margin: 12px 10px;
    border-radius: 10px; }
  .n2_layer_contextual_responsive_tools__text_scale .nui-slider .nui-slider-handle {
    position: absolute;
    top: 0;
    z-index: 2;
    width: 10px;
    height: 10px;
    background-color: #FFFFFF;
    border: 2px solid #94B2C1;
    margin: -4px -7px 0;
    border-radius: 50px;
    cursor: ew-resize;
    box-sizing: content-box;
    -ms-touch-action: none;
    touch-action: none; }

.n2_layer_contextual_responsive_tools__text_scale_percent {
  line-height: 30px;
  font-size: 12px;
  color: #325c77; }

.n2_context_menu {
  font-family: "Inter-Nextend", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
  line-height: 1.3;
  font-size: 16px;
  -webkit-font-smoothing: antialiased;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
  z-index: 1000000;
  position: fixed;
  left: 0;
  top: 0; }
  .n2_context_menu a {
    transition: none 0s;
    text-decoration: none;
    box-shadow: none; }

.n2_context_menu__inner {
  background-color: #FFFFFF;
  border-radius: 3px;
  box-shadow: 0 1px 5px 1px rgba(55, 77, 88, 0.2);
  overflow: hidden; }

.n2_context_menu__item {
  display: flex;
  align-items: center;
  padding: 0 10px;
  height: 36px;
  cursor: default; }

.n2_context_menu__item--has-action {
  cursor: pointer; }

.n2_context_menu__item--has-action:HOVER,
.n2_context_menu__item--active {
  background-color: #1D81F9; }

.n2_context_menu__item_icon {
  padding: 0 5px;
  color: #94B2C1; }
  .n2_context_menu__item--color-red .n2_context_menu__item_icon {
    color: #C43E2A; }
  .n2_context_menu__item--has-action:HOVER .n2_context_menu__item_icon,
  .n2_context_menu__item--active .n2_context_menu__item_icon {
    color: #fff; }

.n2_context_menu__item_onoff .n2_context_menu__item_icon::before {
  content: "\E19A"; }

.n2_context_menu__item_onoff--on .n2_context_menu__item_icon::before {
  content: "\E199"; }

.n2_context_menu__item_label {
  padding: 0 5px;
  font-size: 12px;
  color: #325C77;
  white-space: nowrap;
  text-transform: capitalize; }
  .n2_context_menu__item--color-red .n2_context_menu__item_label {
    color: #C43E2A; }
  .n2_context_menu__item--has-action:HOVER .n2_context_menu__item_label,
  .n2_context_menu__item--active .n2_context_menu__item_label {
    color: #fff; }

.n2_context_menu__sub_menu {
  display: none;
  z-index: 2;
  position: absolute;
  left: 0;
  top: 0;
  background-color: #FFFFFF;
  border-radius: 3px;
  box-shadow: 0 1px 5px 1px rgba(55, 77, 88, 0.2);
  overflow: hidden; }

.n2_context_menu__sub_menu--active {
  display: block; }

html[data-component="layer"][data-component-sub="image"] .n2_field[data-field="layerfont-size"], html[data-component="layer"][data-component-sub="transition"] .n2_field[data-field="layerfont-size"], html[data-component="layer"][data-component-sub="youtube"] .n2_field[data-field="layerfont-size"], html[data-component="layer"][data-component-sub="vimeo"] .n2_field[data-field="layerfont-size"], html[data-component="layer"][data-component-sub="video"] .n2_field[data-field="layerfont-size"], html[data-component="layer"][data-component-sub="audio"] .n2_field[data-field="layerfont-size"], html[data-component="layer"][data-component-sub="imagearea"] .n2_field[data-field="layerfont-size"], html[data-component="layer"][data-component-sub="area"] .n2_field[data-field="layerfont-size"], html[data-component="layer"][data-component-sub="iframe"] .n2_field[data-field="layerfont-size"] {
  display: none; }

html[data-component="layer"][data-component-sub="animatedHeading"] .n2_field .n2_field_decoration__option[data-value="underline"], html[data-component="layer"][data-component-sub="highlightedHeading"] .n2_field .n2_field_decoration__option[data-value="underline"] {
  display: none; }

.n2_slide_generator_box {
  position: relative;
  width: 270px;
  height: 180px;
  border-radius: 3px;
  overflow: hidden;
  display: flex;
  flex-flow: column;
  justify-content: flex-end;
  background-color: #dce2e5;
  background-position: left top; }

.n2_slide_generator_box__title {
  display: flex;
  align-items: center;
  padding: 10px;
  background-color: #0C1924; }

.n2_slide_generator_box__title_label {
  flex: 1 1 auto;
  padding: 0 5px;
  font-size: 14px;
  line-height: 20px;
  color: #BDCFD9;
  display: flex;
  align-items: center; }

.n2_slide_generator_box__title_label_inner {
  margin-right: 5px; }
  html[dir="rtl"] .n2_slide_generator_box__title_label_inner {
    margin-right: 0;
    margin-left: 5px; }

.n2_slide_generator_box__title_button {
  padding: 0 10px;
  background-color: #1D81F9;
  border-radius: 3px;
  font-size: 11px;
  line-height: 30px;
  text-align: center;
  text-transform: uppercase; }
  .n2_slide_generator_box__title_button:HOVER {
    background-color: #338EF9; }
  .n2_slide_generator_box__title_button, .n2_slide_generator_box__title_button:HOVER, .n2_slide_generator_box__title_button:FOCUS {
    color: #fff; }

.n2_slide_generator_step1__installed_generators {
  padding: 40px;
  display: grid;
  grid-gap: 32px;
  grid-template-columns: repeat(auto-fill, 270px); }

.n2_slide_generator_step1__not_installed {
  padding: 10px 40px 40px 40px; }

.n2_slide_generator_step1__not_installed_label {
  font-size: 22px;
  line-height: 32px;
  color: #283F4D; }

.n2_slide_generator_step1__not_installed_generators {
  padding-top: 20px;
  display: grid;
  grid-gap: 32px;
  grid-template-columns: repeat(auto-fill, 270px); }

.n2_slide_generator_step3 {
  padding: 40px;
  display: grid;
  grid-gap: 32px;
  grid-template-columns: repeat(auto-fill, 270px); }

.n2_generator_records_table {
  margin: 20px 0;
  display: grid;
  overflow: auto;
  background: #fff;
  grid-gap: 2px; }

.n2_generator_records_table__heading {
  padding: 0 10px;
  background-color: #F0F4F7;
  color: #325C77;
  font-size: 12px;
  line-height: 30px;
  font-weight: bold; }

.n2_generator_records_table__cell {
  padding: 0 10px;
  background-color: #F0F4F7;
  color: #325C77;
  font-size: 12px;
  line-height: 30px;
  max-height: 100px;
  min-width: 150px;
  overflow: auto; }

.n2_slider_preview_area {
  margin-top: 20px;
  display: flex;
  justify-content: center;
  min-height: 150vh; }

.n2_slider_preview_area__inner {
  position: relative;
  background-color: #FFFFFF;
  box-shadow: 0 2px 20px 0 rgba(0, 0, 0, 0.2); }

.n2_preview {
  display: flex;
  flex-flow: column;
  align-items: center;
  height: calc(100vh - 60px); }

.n2_preview__ruler {
  width: 100%;
  position: relative;
  flex: 0 0 auto;
  height: 20px;
  background-color: #94B2C1;
  overflow: hidden; }

.n2_preview__ruler_device {
  position: absolute;
  left: 50%;
  top: 0;
  height: 100%;
  cursor: pointer; }
  .n2_preview__ruler_device div {
    border-left: 1px solid #fff;
    border-right: 1px solid #fff;
    padding: 0 5px;
    height: 100%; }
  .n2_preview__ruler_device:HOVER div {
    background-color: #1D81F9; }

.n2_preview__ruler--ready .n2_preview__ruler_device {
  transition: width 0.5s, margin-left 0.5s; }

.n2_preview__ruler_label {
  position: absolute;
  left: 50%;
  top: 0;
  z-index: 10;
  width: 200px;
  margin-left: -100px;
  pointer-events: none;
  text-align: center;
  font-size: 12px;
  line-height: 20px;
  color: #FFFFFF; }

.n2_preview__device_screen {
  position: relative;
  flex: 1 1 auto;
  width: 100%;
  height: 100%;
  display: flex;
  justify-content: center;
  padding: 0 20px 20px;
  box-sizing: border-box;
  overflow: hidden; }

.n2_preview__device_info {
  margin-top: 13px;
  position: relative;
  flex: 0 0 auto;
  width: 100%;
  height: 26px;
  display: flex;
  align-items: center;
  justify-content: center;
  font-size: 13px;
  line-height: 26px;
  color: #325C77; }
  .n2_preview__device_info .ssi_16 {
    margin: 0 5px;
    color: #94B2C1; }

.n2_preview__device_info_state {
  font-weight: bold; }

.n2_preview__notification_scale {
  pointer-events: none;
  position: absolute;
  left: 50%;
  top: 30px;
  z-index: 10;
  background: RGBA(0, 0, 0, 0.5);
  width: 90px;
  margin-left: -45px;
  color: #fff;
  text-align: center;
  border-radius: 5px;
  line-height: 48px;
  font-size: 16px;
  transition: opacity 0.5s ease 0s;
  opacity: 0; }

.n2_preview__notification_scale--visible {
  opacity: 1; }

.n2_preview__device_screen_inner {
  position: relative;
  flex: 1 1 auto;
  width: 100%;
  height: 100%;
  max-width: 100%;
  max-height: 100%; }
  .n2_preview__device_screen_inner iframe {
    border: 0;
    max-width: none;
    width: 100%;
    height: 100%;
    box-shadow: 0 2px 20px rgba(0, 0, 0, 0.2);
    transform-origin: 50% 0;
    transition: transform 0.5s; }

.n2_preview__frame_overlay {
  display: none;
  position: absolute;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%; }
  .n2_body--resize-horizontal .n2_preview__frame_overlay,
  .n2_body--resize-vertical .n2_preview__frame_overlay {
    display: block; }

.n2_preview__resize_width {
  position: absolute;
  top: 0;
  right: -8px;
  width: 8px;
  height: 100%;
  background: #1d81f9;
  opacity: 0;
  cursor: ew-resize;
  transition: opacity 0.3s; }
  .n2_preview__device_screen:HOVER .n2_preview__resize_width {
    opacity: 0.5; }
  .n2_preview__device_screen .n2_preview__resize_width:HOVER,
  .n2_body--resize-horizontal .n2_preview__device_screen .n2_preview__resize_width {
    opacity: 1; }
  .n2_body--scale-preview .n2_preview__resize_width {
    opacity: 0 !important; }

.n2_preview__resize_height {
  position: absolute;
  left: 0;
  bottom: -8px;
  width: 100%;
  flex: 0 0 auto;
  height: 8px;
  background: #1d81f9;
  opacity: 0;
  cursor: ns-resize;
  transition: opacity 0.3s; }
  .n2_preview__device_screen:HOVER .n2_preview__resize_height {
    opacity: 0.5; }
  .n2_preview__device_screen .n2_preview__resize_height:HOVER,
  .n2_body--resize-vertical .n2_preview__device_screen .n2_preview__resize_height {
    opacity: 1; }
  .n2_body--scale-preview .n2_preview__resize_height {
    opacity: 0 !important; }

#n2_preview_frame {
  display: block;
  width: 100%;
  height: 100%; }

.n2_preview_toolbar {
  display: flex;
  align-items: center; }

.n2_preview_toolbar__size {
  margin: 0 10px;
  display: flex; }

.n2_preview_toolbar__editable {
  width: 46px;
  height: 28px;
  background-color: #2C3A45;
  border-radius: 3px;
  font-size: 12px;
  line-height: 28px;
  color: #BDCFD9;
  text-align: center; }

.n2_preview_toolbar__x {
  margin: 0 10px;
  font-size: 12px;
  line-height: 28px;
  color: #94B2C1; }

select.n2_preview_toolbar__scale {
  margin: 0;
  padding: 0 10px;
  max-width: initial;
  width: auto;
  height: 28px;
  min-height: 28px;
  font-family: inherit;
  -webkit-appearance: menulist;
  -moz-appearance: menulist;
  background: #2c3a45;
  font-size: 12px;
  line-height: 28px; }
  select.n2_preview_toolbar__scale, select.n2_preview_toolbar__scale:FOCUS, select.n2_preview_toolbar__scale:HOVER {
    color: #BDCFD9;
    box-shadow: none;
    border: none; }

.n2_html--slider-preview {
  background: #fff; }
  .n2_html--slider-preview body {
    width: 100%;
    overflow-x: hidden;
    overflow-y: scroll;
    background: #fff; }
  @media only screen and (max-width: 700px) {
    .n2_html--slider-preview::-webkit-scrollbar {
      width: 0;
      /* Chrome */ }
    .n2_html--slider-preview {
      -ms-overflow-style: none;
      /* Internet Explorer 10+ */
      scrollbar-width: none;
      /* Firefox */ } }

.n2_getting_started {
  display: flex;
  flex-flow: column;
  align-items: center;
  padding: 60px 0 120px; }

.n2_getting_started__heading {
  font-size: 32px;
  line-height: 32px;
  color: #283F4D; }

.n2_getting_started__subheading {
  font-size: 14px;
  line-height: 28px;
  color: #325C77; }

.n2_getting_started__video {
  margin-top: 20px;
  position: relative;
  width: 100%;
  max-width: calc(100vh - 100px); }
  .n2_getting_started__video .n2_getting_started__video_placeholder {
    padding-top: 56.25%;
    height: 0; }
  .n2_getting_started__video iframe,
  .n2_getting_started__video img {
    position: absolute;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%;
    border: 0; }

.n2_getting_started__buttons {
  margin-top: 20px;
  display: flex;
  width: 100%; }
  .n2_getting_started__buttons > div {
    width: 50%; }

.n2_getting_started__button_dont_show {
  text-align: right;
  padding: 0 10px; }
  .n2_getting_started__button_dont_show a {
    display: inline-block;
    padding: 0 20px;
    font-size: 14px;
    line-height: 36px; }
    .n2_getting_started__button_dont_show a, .n2_getting_started__button_dont_show a:HOVER, .n2_getting_started__button_dont_show a:FOCUS {
      color: #1375E9; }
  html[dir="rtl"] .n2_getting_started__button_dont_show {
    text-align: left; }

.n2_getting_started__button_dashboard {
  text-align: left;
  padding: 0 10px; }
  .n2_getting_started__button_dashboard a {
    display: inline-block;
    padding: 0 20px;
    background-color: #04C018;
    border-radius: 3px;
    font-size: 12px;
    line-height: 36px;
    font-weight: bold;
    text-align: center;
    text-transform: uppercase; }
    .n2_getting_started__button_dashboard a:HOVER {
      background-color: #07CA1C; }
    .n2_getting_started__button_dashboard a, .n2_getting_started__button_dashboard a:HOVER, .n2_getting_started__button_dashboard a:FOCUS {
      color: #FFFFFF; }
  html[dir="rtl"] .n2_getting_started__button_dashboard {
    text-align: right; }

.n2_page_activate {
  display: flex;
  flex-flow: column;
  align-items: center;
  padding: 60px 0 120px; }

.n2_page_activate__heading {
  font-size: 32px;
  line-height: 32px;
  color: #283F4D; }

.n2_page_activate__subheading {
  font-size: 14px;
  line-height: 28px;
  color: #325C77; }

.n2_page_activate__video {
  margin-top: 20px;
  position: relative;
  width: 100%;
  max-width: calc(100vh - 100px); }
  .n2_page_activate__video .n2_page_activate__video_placeholder {
    padding-top: 56.25%;
    height: 0; }
  .n2_page_activate__video iframe {
    position: absolute;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%; }

.n2_page_activate__buttons {
  margin-top: 20px;
  display: flex;
  width: 100%; }
  .n2_page_activate__buttons > div {
    width: 50%; }

.n2_page_activate__button_dont_show {
  text-align: right;
  padding: 0 10px; }
  .n2_page_activate__button_dont_show a {
    display: inline-block;
    padding: 0 20px;
    font-size: 14px;
    line-height: 36px; }
    .n2_page_activate__button_dont_show a, .n2_page_activate__button_dont_show a:HOVER, .n2_page_activate__button_dont_show a:FOCUS {
      color: #1375E9; }

.n2_page_activate__button_dashboard {
  text-align: left;
  padding: 0 10px; }
  .n2_page_activate__button_dashboard a {
    display: inline-block;
    padding: 0 20px;
    background-color: #04C018;
    border-radius: 3px;
    font-size: 12px;
    line-height: 36px;
    font-weight: bold;
    text-align: center;
    text-transform: uppercase; }
    .n2_page_activate__button_dashboard a:HOVER {
      background-color: #07CA1C; }
    .n2_page_activate__button_dashboard a, .n2_page_activate__button_dashboard a:HOVER, .n2_page_activate__button_dashboard a:FOCUS {
      color: #FFFFFF; }

.n2_page_free_go_pro {
  display: flex;
  padding: 30px 0 90px;
  flex-wrap: wrap;
  justify-content: center; }

.n2_page_free_go_pro__col {
  display: flex;
  flex-flow: column;
  align-items: center;
  padding: 30px; }

.n2_page_free_go_pro__heading {
  font-size: 32px;
  line-height: 32px;
  color: #283F4D; }

.n2_page_free_go_pro__subheading {
  margin-bottom: 20px;
  font-size: 14px;
  line-height: 28px;
  color: #325C77; }

.n2_page_free_go_pro_already_purchased {
  position: relative;
  display: flex;
  flex-flow: column;
  align-items: center;
  width: 572px;
  height: 392px;
  background-color: #FFFFFF;
  border-radius: 5px;
  box-shadow: 0 10px 8px -10px rgba(0, 0, 0, 0.1); }
  .n2_page_free_go_pro_already_purchased:HOVER {
    box-shadow: 0 10px 8px -10px rgba(0, 0, 0, 0.2); }

.n2_page_free_go_pro_already_purchased__logo {
  margin-top: 44px;
  display: flex;
  align-items: center;
  justify-content: center;
  width: 100px;
  height: 100px;
  background-color: rgba(4, 192, 24, 0.1);
  border-radius: 50px;
  color: #04C018; }

.n2_page_free_go_pro_already_purchased__heading {
  margin-top: 9px;
  font-size: 18px;
  line-height: 30px;
  color: #283F4D;
  font-weight: bold; }

.n2_page_free_go_pro_already_purchased__paragraph {
  width: 380px;
  height: 78px;
  color: #325C77;
  font-size: 14px;
  line-height: 26px;
  text-align: center; }
  .n2_page_free_go_pro_already_purchased__paragraph a, .n2_page_free_go_pro_already_purchased__paragraph a:HOVER, .n2_page_free_go_pro_already_purchased__paragraph a:FOCUS {
    color: #1375e9; }

.n2_page_free_go_pro_already_purchased__button {
  margin: 20px 0 10px;
  padding: 0 20px;
  min-width: 260px;
  background-color: #04C018;
  border-radius: 3px;
  text-align: center;
  font-size: 12px;
  line-height: 36px;
  text-transform: uppercase;
  font-weight: bold; }
  .n2_page_free_go_pro_already_purchased__button, .n2_page_free_go_pro_already_purchased__button:HOVER, .n2_page_free_go_pro_already_purchased__button:FOCUS {
    color: #FFFFFF; }
  .n2_page_free_go_pro_already_purchased__button:HOVER {
    background-color: #07ca1c; }

.n2_help_center {
  display: flex;
  flex-flow: column;
  align-items: center;
  background-color: #f0f4f7;
  text-align: center;
  padding: 0 40px; }
  .n2_help_center a:HOVER {
    color: #005BC6; }
  .n2_help_center a, .n2_help_center a:FOCUS {
    color: #1375E9; }

.n2_help_center__getting_started {
  width: 100%;
  max-width: 1140px;
  margin-top: 44px; }

.n2_help_center__getting_started__heading {
  font-size: 32px;
  line-height: 32px;
  color: #283F4D; }

.n2_help_center__getting_started__subheading {
  font-size: 14px;
  line-height: 28px;
  color: #325C77; }

.n2_help_center__getting_started__video {
  margin-top: 20px;
  position: relative;
  width: 100%;
  max-width: 1140px; }
  .n2_help_center__getting_started__video .n2_help_center__getting_started__video_placeholder {
    padding-top: 56.25%;
    height: 0; }
  .n2_help_center__getting_started__video iframe,
  .n2_help_center__getting_started__video img {
    position: absolute;
    left: 0;
    top: 0;
    width: 100%;
    height: 100%; }

.n2_help_center__conflicts {
  max-width: 1140px;
  width: 100%;
  box-sizing: border-box;
  border-radius: 3px 3px 0 0;
  background-color: #FFFFFF;
  box-shadow: 0 1px 5px 1px rgba(55, 77, 88, 0.2);
  padding: 48px 20px 25px;
  margin-top: 60px; }

.n2_help_center__conflicts_test_api {
  margin-bottom: 20px; }

.n2_help_center__search {
  width: 100%;
  box-sizing: border-box;
  padding: 60px 20px 0; }

.n2_help_center__search_heading {
  color: #283F4D;
  font-size: 22px;
  line-height: 32px; }

.n2_help_center__search_field {
  margin-top: 20px; }
  .n2_help_center__search_field form {
    display: inline-flex;
    width: 100%;
    max-width: 600px; }
    .n2_help_center__search_field form input {
      flex: 1 1 auto;
      margin: 0;
      padding: 0 20px;
      border: 2px solid #94B2C1;
      border-right: 0;
      border-radius: 3px 0 0 3px;
      background-color: #FFFFFF;
      color: #325C77;
      font-size: 14px;
      line-height: 46px;
      height: auto; }
      .n2_help_center__search_field form input, .n2_help_center__search_field form input:FOCUS {
        box-shadow: none;
        outline: 0; }
      .n2_help_center__search_field form input:FOCUS {
        border-color: #1D81F9; }
      html[dir="rtl"] .n2_help_center__search_field form input {
        border: 2px solid #94B2C1;
        border-left: 0;
        border-radius: 0 3px 3px 0; }
    .n2_help_center__search_field form button {
      padding: 0 35px;
      background-color: #1D81F9;
      border: 0;
      border-top-right-radius: 3px;
      border-bottom-right-radius: 3px;
      color: #FFFFFF;
      font-size: 12px;
      line-height: 50px;
      text-transform: uppercase; }
      .n2_help_center__search_field form button:HOVER {
        background-color: #338EF9; }
      .n2_help_center__search_field form button, .n2_help_center__search_field form button:FOCUS {
        box-shadow: none;
        outline: 0; }
      html[dir="rtl"] .n2_help_center__search_field form button {
        border-radius: 3px 0 0 3px; }

.n2_help_center__actions {
  margin-top: 60px;
  max-width: 1140px;
  width: 100%;
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  grid-gap: 10px 60px; }

.n2_help_center__action {
  position: relative;
  padding: 20px;
  background-color: #FFFFFF;
  border-radius: 3px;
  box-shadow: 0 1px 5px 1px rgba(55, 77, 88, 0.2);
  text-align: center; }

.n2_help_center__action_link {
  position: absolute;
  z-index: 2;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%; }

.n2_help_center__action_icon {
  margin-top: 30px;
  text-align: center;
  color: #1375E9; }

.n2_help_center__conflicts_icon {
  color: #1375E9; }

.n2_help_center__action_label, .n2_help_center__conflicts_label {
  margin-top: 16px;
  color: #283F4D;
  font-size: 18px;
  line-height: 28px; }

.n2_help_center__conflicts_description, .n2_help_center__action_description {
  margin: 5px 0 15px;
  color: #325C77;
  font-size: 14px;
  line-height: 24px; }

.n2_help_center__articles {
  margin-top: 20px;
  max-width: 1140px;
  width: 100%;
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  grid-gap: 10px 60px; }

.n2_help_center__articles_heading {
  color: #283F4D;
  font-size: 22px;
  line-height: 32px;
  margin-top: 60px;
  max-width: 1140px;
  width: 100%; }

.n2_help_center__article {
  position: relative;
  padding: 20px 20px;
  background-color: #FFFFFF;
  border-radius: 3px;
  box-shadow: 0 1px 5px 1px rgba(55, 77, 88, 0.2);
  display: flex;
  align-items: center;
  color: #325C77;
  font-size: 14px;
  line-height: 20px; }
  .n2_help_center__article:HOVER {
    color: #1375E9; }

.n2_help_center__article_link {
  position: absolute;
  z-index: 2;
  left: 0;
  top: 0;
  width: 100%;
  height: 100%; }

.n2_help_center__article_label {
  flex: 1 1 auto;
  text-align: left; }
  html[dir="rtl"] .n2_help_center__article_label {
    text-align: right; }

.n2_help_center__article_icon {
  font-size: 16px; }
  html[dir="rtl"] .n2_help_center__article_icon {
    transform: rotate(180deg); }

.n2_help_center__system_information {
  margin-top: 60px;
  max-width: 1140px;
  width: 100%; }

.n2_help_center__system_information_label, .n2_help_center__articles_label {
  color: #283F4D;
  font-size: 22px;
  line-height: 32px; }

.n2_help_center__system_information_form textarea {
  display: block;
  margin-top: 30px;
  height: 300px;
  background-color: #FFFFFF;
  border: 2px solid #94B2C1;
  border-radius: 3px;
  padding: 15px 20px;
  color: #325C77;
  font-size: 14px;
  line-height: 24px; }

.n2_loading_screen {
  display: none;
  position: fixed;
  z-index: 2147483647;
  width: 100%;
  height: 100%;
  left: 0;
  top: 0;
  background: RGBA(32, 41, 52, 0.95); }

.n2_loading_screen--visible {
  display: flex;
  align-items: center;
  justify-content: center; }

.n2_loading_screen__circle {
  border: 10px solid #6B7986;
  border-left-color: #fff;
  border-radius: 50%;
  width: 40px;
  height: 40px;
  animation: n2_loading_screen__circle_animation 1.1s infinite linear; }

@keyframes n2_loading_screen__circle_animation {
  0% {
    transform: rotate(0deg); }
  100% {
    transform: rotate(360deg); } }
.n2_ss_background_animation_preview {
  overflow: hidden; }
  .n2_ss_background_animation_preview .n2-bganim-side {
    position: absolute;
    left: 0;
    top: 0;
    overflow: hidden; }
  .n2_ss_background_animation_preview .n2-bganim-tile-overlay-colored {
    z-index: 100000; }

.n2_ss_background_animation_preview__slider {
  position: relative;
  width: 800px;
  height: 500px;
  margin: 20px;
  z-index: 3; }

.n2_ss_background_animation_preview__animation_container,
.n2_ss_background_animation_preview__slide {
  position: absolute;
  left: 0;
  top: 0;
  width: 800px;
  height: 500px; }

.n2_ss_background_animation_preview__slide {
  z-index: 2; }

.n2_ss_background_animation_preview__slide_background {
  height: 100%; }

.n2_ss_background_animation_preview__slide_background_image {
  height: 100%;
  background-size: cover;
  background-position: 50% 50%; }
